# -*- Mode: rpm-spec -*-
#
# This Specfile is based on kernel-tmb spec done by
# Thomas Backlund <tmb@mandriva.org>
# 
# The mkflavour() macroization done by Anssi Hannula <anssi@mandriva.org>
#
# Manbo kernels now use kernel.org versioning
#
%define kernelversion	2
%define patchlevel	6
%define sublevel	39

# Package release
%define mnbrel		4

# kernel Makefile extraversion is substituted by 
# kpatch/kgit/kstable wich are either 0 (empty), rc (kpatch), git (kgit) 
# or stable release (kstable)
%define kpatch		0
%define kstable		4
# kernel.org -gitX patch (only the number after "git")
%define kgit		0

# kernel base name (also name of srpm)
%define kname 		kernel

# Patch tarball tag
%define ktag		mnb

# Handle manbo release
%if "%{?manbo_mkrel:has_manbo}" == "has_manbo"

%define rpmtag		mnb2
%if %kpatch
%if %kgit
%define rpmrel		%manbo_mkrel 0.%{kpatch}.%{kgit}.%{mnbrel}%{?uclevel:.%{uclevel}}
%else
%define rpmrel		%manbo_mkrel 0.%{kpatch}.%{mnbrel}%{?uclevel:.%{uclevel}}
%endif
%else
%define rpmrel		%manbo_mkrel %{mnbrel}%{?uclevel:.%{uclevel}}
%endif
%define fakerel 	%manbo_mkrel 1

%else

%define rpmtag		%distsuffix
%if %kpatch
%if %kgit
%define rpmrel		%mkrel 0.%{kpatch}.%{kgit}.%{mnbrel}%{?uclevel:.%{uclevel}}
%else
%define rpmrel		%mkrel 0.%{kpatch}.%{mnbrel}%{?uclevel:.%{uclevel}}
%endif
%else
%define rpmrel		%mkrel %{mnbrel}%{?uclevel:.%{uclevel}}
%endif
%define fakerel 	%mkrel 1

%endif

# fakerel above and fakever below never change, they are used to fool
# rpm/urpmi/smart
%define fakever		1

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %kpatch
%if %kstable
%define tar_ver	  	%{kernelversion}.%{patchlevel}.%{sublevel}
%else
%define tar_ver	  	%{kernelversion}.%{patchlevel}.%(expr %{sublevel} - 1)
%endif
%define patch_ver 	%{kversion}-%{kpatch}-%{ktag}%{mnbrel}
%else
%define tar_ver   	%{kernelversion}.%{patchlevel}.%{sublevel}
%define patch_ver 	%{kversion}-%{ktag}%{mnbrel}
%endif
%if %kstable
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}.%{kstable}
%else
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%endif
%define kverrel   	%{kversion}-%{rpmrel}

# Used for not making too long names for rpms or search paths
%if %kpatch
%if %kgit
%define buildrpmrel     0.%{kpatch}.%{kgit}.%{mnbrel}%{?uclevel:.%{uclevel}}%{rpmtag}
%else
%define buildrpmrel     0.%{kpatch}.%{mnbrel}%{?uclevel:.%{uclevel}}%{rpmtag}
%endif
%else
%define buildrpmrel     %{mnbrel}%{?uclevel:.%{uclevel}}%{rpmtag}
%endif
%define buildrel     	%{kversion}-%{buildrpmrel}

# Having different top level names for packges means that you have to remove
# them by hard :(
%define top_dir_name 	%{kname}-%{_arch}

# Build defines
%define build_doc 		1
%define build_source 		1
%define build_devel 		1

%define build_debug 		1

# Build desktop i586 / 4GB
%ifarch %{ix86}
%define build_desktop586	1
%endif

# Build desktop (i686 / 4GB) / x86_64 / sparc64 sets
%define build_desktop		1

# Build server (i686 / 64GB)/x86_64 / sparc64 sets
%define build_server		1

# End of user definitions
%{?_without_desktop586: %global build_desktop586 0}
%{?_without_desktop: %global build_desktop 0}
%{?_without_server: %global build_server 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}
%{?_without_devel: %global build_devel 0}
%{?_without_debug: %global build_debug 0}

%{?_with_desktop586: %global build_desktop586 1}
%{?_with_desktop: %global build_desktop 1}
%{?_with_server: %global build_server 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}
%{?_with_devel: %global build_devel 1}
%{?_with_debug: %global build_debug 1}

# For the .nosrc.rpm
%define build_nosrc 	0
%{?_with_nosrc: %global build_nosrc 1}


#
# SRC RPM description
#
Summary: 	Linux kernel built for Manbo
Name:		%{kname}
Version: 	%{kversion}
Release: 	%{rpmrel}
License: 	GPLv2
Group: 	 	System/Kernel and hardware
ExclusiveArch: %{ix86} ppc powerpc x86_64 amd64 sparc sparc64
ExclusiveOS: 	Linux
URL:            http://wiki.mandriva.com/en/Manbo_Core2_kernel
BuildRoot: 	%{_tmppath}/%{kname}-%{kversion}-%{_arch}-build
Autoreqprov: 	no
BuildRequires: 	gcc module-init-tools

%define common_description_info For instructions for update, see:	\
http://www.mandriva.com/en/security/kernelupdate

%description
The kernel package contains the Linux kernel (vmlinuz), the core of
your Manbo Linux operating system. The kernel handles the basic
functions of the operating system: memory allocation, process
allocation, device input and output, etc.

%common_description_info

# mkflavour() name flavour processor
# name: the flavour name in the package name
# flavour: first parameter of CreateKernel()
%define mkflavour(R:)					\
%package -n %{kname}-%{1}-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}	\
Group:		System/Kernel and hardware		\
Requires:	kernel-%{2}%{-R:-%{-R*}}		\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
							\
%description -n %{kname}-%{1}-latest			\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1} installed...			\
							\
%common_description_info				\
							\
%if %build_devel					\
%package -n %{kname}-%{1}-devel-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}-devel \
Group:		Development/Kernel			\
Requires:	%{kname}-%{2}-devel%{-R:-%{-R*}}	\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
Provides:	%{kname}-devel-latest			\
							\
%description -n %{kname}-%{1}-devel-latest		\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1}-devel installed...			\
							\
%common_description_info				\
%endif							\
							\
%if %build_debug					\
%package -n %{kname}-%{1}-debug-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}-debug \
Group:		Development/Debug			\
Requires:	%{kname}-%{2}-%{-R:debug-%{-R*}}%{!-R:debuginfo}	\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
Provides:	%{kname}-debug-latest			\
							\
%description -n %{kname}-%{1}-debug-latest		\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1}-debug installed...			\
							\
%common_description_info				\
%endif							\
							\
%files -n %{kname}-%{1}-latest				\
%defattr(-,root,root)					\
							\
%if %build_devel					\
%files -n %{kname}-%{1}-devel-latest			\
%defattr(-,root,root)					\
%endif							\
							\
%if %build_debug					\
%files -n %{kname}-%{1}-debug-latest			\
%defattr(-,root,root)					\
%endif

#
# kernel-desktop586: i586, smp-alternatives, 4GB
#
%ifarch %{ix86}
%if %build_desktop586
%mkflavour desktop586 generic
%endif
%endif

#
# kernel-desktop: i686, smp-alternatives, 4 GB / x86_64
#

%if %build_desktop
%mkflavour desktop desktop
%endif

#
# kernel-server: i686, smp-alternatives, 64 GB / x86_64
#

%if %build_server
%ifarch %{ix86}
%mkflavour -R 2.6.38.7-1mnb2 server server
%else
%mkflavour server server
%endif
%endif

#
# kernel-source-latest: virtual rpm
#
%if %build_source

%package -n %{kname}-source-latest
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-source
Group:   	Development/Kernel
Requires: 	%{kname}-source >= %{kversion}
%ifarch %{ix86}
Conflicts:	arch(x86_64)
%endif

%description -n %{kname}-source-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-source installed...

%common_description_info

%files -n %{kname}-source-latest
%defattr(-,root,root)

%endif


%changelog
* Wed Nov 02 2011 Franck Bui <franck.bui@mandriva.com> 2.6.39.4-4mnb2
+ Revision: 712194
- fix desktopi586 package to point to kernel-generic one
- Remove virtual kernel rpm package. ie kernel-<version>.
- Allow kernel-source-latest to pull the latest kernel-source package
- 2.6.39.4-2mnb2-1-1mnb2: more tunes for new package transition: x86-32 server packages are no more supported
- The end: make kernel-latest-* point to the new kernel packages (see kernel-{desktop,server,generic} ones)

* Sun May 22 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.7-1mnb2
+ Revision: 677434
- rollback unionfs to a known working 2.5.8
- drop merged patches
- update to 2.6.38.7 (CVE-2011-1770, CVE-2011-1776, CVE-2011-1927)
- revert linker changes _NOT_ belonging in 2011.0 release kernels
- fix Makefile for removed readme

  + Alexandre Felipe Muller de Souza <alexandrefm@mandriva.com>
    - Adding two patches that solves hw problems, reported by MDV OEM
    - Adding flags to kernel compile, that peroyivind requested for

* Tue May 10 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.6-1mnb2
+ Revision: 673317
- fix version-release
- update to 2.6.38.6
- clean /lib/modules on kernel removal (#42962)
- fix kstable version

  + Franck Bui <franck.bui@mandriva.com>
    - bump package release version since a rebuild is needed due to binutils wreckage

* Thu May 05 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.5-1mnb2
+ Revision: 669488
- samsung-laptop: add support for N230 and R410P models
- update unionfs to 2.5.9.1
  drop fs-unionfs-buildfix.patch (merged)
  drop fs-unionfs-2.5.3-oops.patch (fixed differently)
- update to 2.6.38.5
- drm/i915: Fix tiling corruption from pipelined fencing
- endable radeon kernel modesetting by default

* Sun Apr 24 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.4-1mnb2
+ Revision: 658354
- update defconfigs, and fix changelog
- update ipset to 6.4 (includes ipv6 support) (#62965)
- update aufs to aufs2.1-38 stable branch
- update to 2.6.38.4

* Sun Apr 17 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.3-1mnb2
+ Revision: 654767
- update to 2.6.38.3
- rediff HP Compaq DC7900 alsa patch

* Mon Mar 28 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.2-1mnb2
+ Revision: 648688
- restore framebuffer oops and deadlock fixes by Herton as
  they seem to work better than the Ubuntu one (#62864)
- update to 2.6.38.2 (CVE-2011-0726)
- update to 2.6.38.1 final

* Tue Mar 22 2011 Thomas Backlund <tmb@mandriva.org> 2.6.38.1-0.rc1.1mnb2
+ Revision: 647533
- prepare to release
- fix changelog
- ahci: AHCI mode SATA patch for Intel Patsburg SATA RAID controller
- ahci: recognize Marvell 88se9125 PCIe SATA 6.0 Gb/s controller
- drm: Hold the mode mutex whilst probing for sysfs status
- drm/i915: Replace vblank PM QoS with "Interrupt-Based AGPBUSY#"
- drm/radeon/kms: fix typo in atom overscan setup
- x86, quirk: Fix SB600 revision check
- rediff S2 to apply cleanly
- update defconfigs
- disable broken docomo patches
- add buildfixes for acerhk and ndiswrapper
- rediff patches:
    3rd-3rdparty-merge.patch
    acpi-add-proc-event-regs.patch
    acpi-video-add-blacklist-to-use-vendor-driver.patch
    char-agp-intel-new-Q57-id.patch
    platform-x86-add-shuttle-wmi-driver.patch
    x86-pci-toshiba-equium-a60-assign-busses.patch
- update plymouth framebuffer oops fix (Ubuntu, suggested by Herton on LKML)
- replace samsung-backlight driver with the samsung-laptop driver
  that will be integrated in 2.6.39
- update unionfs to 2.5.8
- update aufs2 to 2.6.38-rc
- * drop merged patches:
    dm-crypt-scale-to-multiple-CPUs-v5-2.6.36.patch
    fs-squashfs-add-XZ-compression-configuration-option.patch
    fs-squashfs-add-XZ-compression-support.patch
    fs-squashfs-fix-use-of-uninitialised-variable-in-zlib-and-xz-decompressors.patch
    kbuild-do-not-remove-a.out-kvm.h-and-kvm_para.h-on-headers_install_all.patch
    kernel-sched-autogroup-Fix-reference-leak.patch
    kernel-sched-automated-per-session-task-groups-20101130.patch
    kernel-sched-fix-potential-access-to-freed-memory.patch
    kernel-sched-Fix-struct-autogroup-memory-leak.patch
    kernel-sched-Mark-autogroup_init-__init.patch
    kernel-sched-sched-Move-sched_autogroup_exit-to-free_signal_struct.patch
    lib-decompressors-add-boot-time-XZ-support.patch
    lib-decompressors-add-XZ-decompressor-module.patch
    net-wireless-rtl8187-avoid-redundant-write-to-register-FF72.patch
    net-wireless-rtl8187-consolidate-anaparam-on-off-write-sequences.patch
    net-wireless-rtl8187-do-not-do-per-packet-TX-AGC.patch
    net-wireless-rtl8187-don-t-set-RTL818X_CONFIG3_GNT_SELECT.patch
    net-wireless-rtl8187-fix-wrong-register-initialization-in-8187B.patch
    net-wireless-rtl8187-move-pll-reset-at-start-out-of-ANAPARAM-write.patch
    net-wireless-rtl8187-remove-redundant-initialization-of-ARFR.patch
    net-wireless-rtl8187-remove-setting-of-beacon-atim-regs-from-init.patch
    net-wireless-rtl8187-remove-uneeded-setting-of-anaparam-write.patch
    net-wireless-rtl8187-restore-anaparam-registers-after-reset.patch
    net-wireless-zd1201-add-id.patch
    net-wireless-zd1211rw-add-id.patch
    x86-support-XZ-compressed-kernel.patch
- update to 2.6.38

* Fri Feb 25 2011 Thomas Backlund <tmb@mandriva.org> 2.6.37.2-1mnb2
+ Revision: 639813
- prepare to release
- i586 server kernel and x86_64 kernels needs to be compressed with gzip
  so they work with xen (got broken during lzma -> xz update, noted by
  Guillaume Rousse on kernel-discuss ml)
- fix series file
- update to 2.6.37.2
   * drop merged patch
     fs-xfs-fix-dquot-shaker-deadlock.patch

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Update to 2.6.37.1.
      Drop merged patches.
      Rediff kernel-sched-automated-per-session-task-groups-20101130.patch.

  + Alexandre Felipe Muller de Souza <alexandrefm@mandriva.com>
    - Adding a fix for an ops kernel problem

* Sun Feb 13 2011 Thomas Backlund <tmb@mandriva.org> 2.6.37-3mnb2
+ Revision: 637604
- add aufs2 support
- revert: "sched, autogroup: Fix CONFIG_RT_GROUP_SCHED sched_setscheduler()
  failure" for now as it breaks on boot on both i586 and x86_64
- sched: Move sched_autogroup_exit() to free_signal_struct()
- sched: Mark autogroup_init() __init
- sched: Fix update_curr_rt()
- sched, cgroup: Use exit hook to avoid use-after-free crash

* Thu Feb 10 2011 Thomas Backlund <tmb@mandriva.org> 2.6.37-2mnb2
+ Revision: 637124
- prepare for release
- fix typo
- xfs: fix dquot shaker deadlock
- libata: set queue DMA alignment to sector size for ATAPI too
- sched, autogroup: Fix CONFIG_RT_GROUP_SCHED sched_setscheduler()
  failure (reported on Cooker by Andrey Borzenkov)
- add xz support for kernel, initrd and squashfs
   (from upstream 2.6.38-rc1)
- drop lzma support (obsoleted by xz support)
- drop S5 (not needed anymore, since we now ship an unprepared kernel-source)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Apply upstream fixes "sched, autogroup: Fix reference leak",
      "sched: Fix struct autogroup memory leak"
    - Fix additional oops that can happen with remove_conflicting_framebuffers
      inside framebuffer code, and fix possible deadlock caused by
      fb_set_suspend. Drop original patch for MDV #59260 as this supersedes
      it. Submitted at https://bugzilla.kernel.org/show_bug.cgi?id=26232

* Wed Jan 05 2011 Thomas Backlund <tmb@mandriva.org> 2.6.37-1mnb2
+ Revision: 628748
- upgrade to 2.6.37 final
- drivers/ieee1394 does not exist anymore
- * rediff patches:
  disable-mrproper-prepare-scripts-configs-in-devel-rpms.patch
  * update filelists
  * remove code disabling new firewire stack for backports
  as its now the only firewire stack in the kernel
- * add patches:
  gpu/drm/mach64: 2.6.37 buildfix
   netfilter/IFWLOG: 2.6.37 buildfix
   usb/storage: unusual_devs 2.6.37 buildfix
  * update defconfigs
- * drop merged patches:
  kbuild-really-dont-remove-bounds-asm-offsets-headers.patch
  net-mac80211-avoid-calling-ieee80211_work_work-unconditionally.patch
  * rediff patches:
  3rd-3rdparty-merge.patch
  acpi-dsdt-initrd-v0.9c-2.6.28.patch
   acpi-dsdt-initrd-v0.9c-fixes.patch
   char-agp-intel-new-Q57-id.patch
   hid-usbhid-IBM-BladeCenterHS20-quirk.patch
   kbuild-compress-kernel-modules-on-installation.patch
   kernel-sched-automated-per-session-task-groups-20101130.patch
   platform-x86-add-shuttle-wmi-driver.patch
   sound-bluetooth-SCO-support.patch
   usb-storage-unusual_devs-add-id.patch
- * drop unneeded patch:
   fs-dynamic-nls-default.patch (smbfs support is removed)
- upgrade to 2.6.37-rc8-git1
  * drop merged patches:
    block-cfq-improve-fsync-performance-for-small-files.patch
    firewire-ohci-avoid-reallocation-of-AR-buffers.patch
    firewire-ohci-fix-race-when-reading-count-in-AR-descriptor.patch
    firewire-ohci-fix-regression-with-Agere-FW643-rev-06-disable-MSI.patch
    firewire-ohci-fix-regression-with-VIA-VT6315-disable-MSI.patch
    gpu-drm-i915-always-set-the-dp-transcoder-config-to-8bpc.patch
    gpu-drm-kms-remove-spaces-from-connector-names-v2.patch
    gpu-drm-radeon-kms-don-t-apply-7xx-hdp-flush-workaround-on-agp.patch
    gpu-drm-radeon-kms-fix-vram-base-calculation-on-rs780-rs880.patch
    idle-release-2.6.36.patch
    kernel-cgroup-fixup-broken-cgroup-movement.patch
    kernel-rcu-git.patch
    kernel-sched-Cure-more-NO_HZ-load-average-woes.patch
    kernel-sched-fix-skip_clock_update-optimization.patch
    md-fix-bug-with-re-adding-of-partially-recovered-device.patch
    md-protect-against-NULL-reference-when-waiting-to-start-a-raid10.patch
    net-af_unix-limit-recursion-level.patch
    net-af_unix-limit-unix_tot_inflight.patch
    net-bonding-fix-slave-selection-bug.patch
    net-r8169-fix-sleeping-while-holding-spinlock.patch
    net-wireless-rtl8187-consolidate-MSR-writes-in-bss-info-changed.patch
    security-TOMOYO-Print-URL-information-before-panic.patch
    sound-alsa-hda-sigmatel-work-around-incorrect-master-muting.patch
    sound-alsa-hda-sigmatel-Fix-wrong-TLV-mute-bit-for-STAC_IDT-codecs.patch
    sound-alsa-tlv-Define-numbers-in-sound-tlv.h.patch

* Tue Dec 21 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36.2-2mnb2
+ Revision: 623741
- prepare to release
- r8169: fix sleeping while holding spinlock
- bonding: Fix slave selection bug
- drm/i915: Always set the DP transcoder config to 8BPC
- fix patch names
- sched: Cure more NO_HZ load average woes
- drop bogus WARN_ON_ONCE(test_tsk_need_resched(next)) (LKML, Linus & Ingo)
- md: fix bug with re-adding of partially recovered device
- md: protect against NULL reference when waiting to start a raid10
- drm/kms: remove spaces from connector names
- drm/radeon/kms: fix vram base calculation on rs780/rs880
- drm/radeon/kms: don't apply 7xx HDP flush workaround on AGP
- sched: fix skip_clock_update optimization to be more robust
- sched: fix autogroup proc interface potential access to freed memory
- update "sched: automated per session task groups" patch to
  the final code merged upstream in -tip

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Fix/rename to patch name used in series
    - Add back fix for oops with plymouthd quiting on vesafb after i915
      with modesetting is loaded, fix should be "upstreamed", on todo
      (MDV #59260).
    - Ops, update KernelVersion in platform-x86-add-shuttle-wmi-driver.patch
    - mac80211: avoid calling ieee80211_work_work unconditionally
    - Add new shuttle-wmi x86 platform driver. Blacklist backlight
      controls for some shuttle devices in acpi video driver for them
      to work properly with quirk in shuttle-wmi.

* Fri Dec 10 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36.2-1mnb2
+ Revision: 620323
- fix changelog
- add CVEs to Unix socket fixes
- add CVEs
- prepare to release
- af_unix: limit recursion level (fixes unix socket OOM with NMI watchdog)
- af_unix: limit unix_tot_inflight (fixes unix socket OOM)
- update to 2.6.36.2
- firewire-ohci: disable MSI on Agere FW643 rev 06 controller
- firewire: disable MSI on all VIA firewire controllers
- update to 2.6.36.2-rc1
  * drop merged patches:
    microblaze-fix-build-with-make-3.82.patch
    fs-ext4-fix-NULL-pointer-dereference-in-print_daily_error_info.patch
    firewire-ohci-fix-buffer-overflow-in-AR-split-packet-handling.patch
    firewire-ohci-fix-race-in-AR-split-packet-handling.patch
    gpu-drm-radeon-kms-make-sure-blit-addr-masks-are-64-bit.patch
    gpu-drm-radeon-kms-fix-2D-tile-height-alignment-in-the-r600-CS-checker.patch
    gpu-drm-radeon-kms-MC-vram-map-needs-to-be-bigger-than-pci-aperture-size.patch
    gpu-drm-radeon-kms-properly-compute-group_size-on-6xx-7xx.patch
    gpu-drm-radeon-kms-fix-handling-of-tex-lookup-disable-in-cs-checker-on-r2xx.patch
    sound-alsa-hda-Disable-sticky-PCM-stream-assignment-for-AD-codecs.patch
    sound-alsa-OSS-mixer-emulation-fix-locking.patch
    sound-alsa-hda-add-Vortex86MX-PCI-ids.patch
    sound-alsa-hda-Fix-codec-muted-after-rebooting-from-Windows.patch
    sound-alsa-hda-Add-workarounds-for-CT-IBG-controllers.patch
    sound-alsa-hda-Add-some-workarounds-for-Creative-IBG.patch
    sound-alsa-hda-Fix-wrong-SPDIF-NID-assignment-for-CA0110.patch
    sound-alsa-hda-Fix-ALC660-ALC861-VD-capture-playback-mixers.patch

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - If building a backport of 2.6.36 for older distros (like 2010.1),
      don't enable new firewire stack, thus avoiding requirement on
      newer module-init-tools, as we enable both stacks for now and
      blacklist the old one in module-init-tools.

* Tue Nov 30 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36.1-2mnb2
+ Revision: 603744
- prepare to release
- dm-crypt: scale to multiple CPUs v5
- sched, cgroup: Fixup broken cgroup movement (Peter Zijlstra, LKML)
- sched: automated per session task groups v4 (Mike Galbraith, LKML)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - rtl8187: miscellaneous cleanups and bug fixes.
    - ALSA, hda: fix wrong mixer nids given to alc_auto_create_input_ctls
      for ALC660-VD/ALC861-VD hda codecs (MDV #61159)
    - Updated ipset to version 4.4

* Mon Nov 22 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36.1-1mnb2
+ Revision: 599847
- really prepare for release
- ext4: fix NULL pointer dereference in print_daily_error_info()
- add intel_idle fixes (Len Brown, LKML)
- prepare to release
- update to 2.6.36.1
- make kernel-source require diffutils as it uses both diff and cmp
  during build (mdv #61719)
- update unionfs to v 2.5.7

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Revert change in previous test, please ignore.
    - Commit test, please ignore.

* Thu Oct 28 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36-2mnb2
+ Revision: 589848
- prepare to release
- firewire (JuJu) fixes from upstream (Clemens Ladisch):
  * firewire: ohci: fix buffer overflow in AR split packet handling
  * firewire: ohci: fix race in AR split packet handling
  * firewire: ohci: avoid reallocation of AR buffers
  * firewire: ohci: fix race when reading count in AR descriptor
- drm/radeon/kms fixes from upstream (Alex Deucher):
  * make sure blit addr masks are 64 bit
  * MC vram map needs to be >= pci aperture size
  * properly compute group_size on 6xx/7xx
  * fix handling of tex lookup disable in cs checker on r2xx
- kbuild: do not remove a.out kvm.h and kvm_para.h on headers_install_all
  (Kirill A. Shutemov, LKML)
- fixes so we dont need to patch linux-userspace-headers anymore
- ALSA: hda - Add Vortex86MX PCI ids (Otavio Salvador)
- fix alsa patches attribution
- ALSA: OSS mixer emulation - fix locking (Takashi Iwai)
- ALSA: hda - Fix codec muted after rebooting from Windows (Takashi Iwai)
- ALSA: hda - Add workarounds for CT-IBG controllers (Takashi Iwai)
- ALSA: hda - Add some workarounds for Creative IBG (Takashi Iwai)
- ALSA: hda - Fix wrong SPDIF NID assignment for CA0110 (Takashi Iwai)
- ALSA: hda - Disable sticky PCM stream assignment for AD codecs
  (Patch by Takashi Iwai, requested by Colin Guthrie)
- cfq: improve fsync performance for small files
- ALSA: tlv - Define numbers in sound/tlv.h (Takashi Iwai)
- ALSA: hda - Fix wrong TLV mute bit for STAC/IDT codecs
  (Patch by Takashi Iwai,  requested by Colin Guthrie)
- TOMOYO: Print URL information before panic() (mdv #61723)
- microblaze: fix build with make 3.82

* Thu Oct 21 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36-1mnb2
+ Revision: 587060
- update to 2.6.36 final
- make squashfs lzma support coexist with lzo
- make doc subpackage noarch
- update patch:
  ALSA: HDA: Sigmatel: work around incorrect master muting
  (patch by Clemens Ladisch, requested by Colin Guthrie)

* Fri Oct 15 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36-0.rc8.1.1mnb2
+ Revision: 585827
- update to 2.6.36-rc8-git1
- Update to 2.6.36-rc8
  * drop merged patches:
    block-elevator-git.patch
    fs-xfs-git.patch
    gpu-drm-git.patch
- alsa: patch_sigmatel: fix master playback volume mute
  (patch by Clemens Ladisch, requested by Colin Guthrie)
   http://lists.mandriva.com/kernel-discuss/2010-10/msg00001.php
- fix defconfig creation when enabling debug

* Thu Oct 07 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36-0.rc7.1mnb2
+ Revision: 584028
- Prepare to release
- add fixes queued for 2.6.36 final:
  elevator: fix oops on early call to elevator_change() (upstream git)
  drm: don't drop handle reference on unload (upstream git)
  drm/ttm: Fix two race conditions + fix busy codepaths (upstream git)
  rcu: move check from rcu_dereference_bh to rcu_read_lock_bh_held (upstream git)
  xfs: properly account for reclaimed inodes (upstream git)
- update to 2.6.36-rc7
  * drop merged patch:
    gpu-drm-intel-git-fixes.patch
- enable the new firewire stack (juju) so we can start testing apps
  against it (old stack is scheduled for removal around 2.6.37-39)
  (module-init-tools >= 3.6-12 have the new core blacklisted for
   now to avoid breakage)

* Sun Oct 03 2010 Thomas Backlund <tmb@mandriva.org> 2.6.36-0.rc6.2.1mnb2
+ Revision: 582718
- add acerhk buildfix
- prepare to release
- add heci and  mach64 buildfixes for 2.6.36
- add intel drm fixes from upsteam heading for 2.6.36 final
- update defconfigs
- remove tile arch from source/devel rpms
- * rediff patches:
    3rd-3rdparty-merge.patch
    char-agp-intel-new-Q57-id.patch
    fs-dynamic-nls-default.patch
    include-kbuild-export-pci_ids.patch
    net-netfilter-IFWLOG-mdv.patch
    net-netfilter-psd-mdv.patch
    platform-x86-add-samsung-backlight-driver.patch
    serial-docomo-F2402.patch
- add ndiswrapper buildfix for 2.6.36
- update unionfs to 2.5.6
- revert squashfs lzo support (conflicts with lzma support)
- * drop merged patches:
  fs-nfs-fix-the-return-value-of-nfs_file_fsync.patch
  mm-vmscan-raise-the-bar-to-PAGEOUT_IO_SYNC-stalls.patch
  mm-vmscan-synchronous-lumpy-reclaim-dont-call-congestion_wait.patch
  pci-fix-type-warnings-in-intr_remapping.c.patch
  pci-intel-iommu-Fix-32-bit-build-warning-with-__cmpxchg.patch
  platform-x86-add-lenovo-ideapad.patch
  platform-lenovo-ideapad-Only-allow-camera-state-to-be-set-to-0-or-1.patch
  platform-lenovo-ideapad-Stop-using-global-variables.patch
  staging-dt3155v4l-correcting-a-pointer-mismatch-bug.patch
  staging-update-ramzswap-to-zram-hg193.patch
  um-x86-Cast-to-u64-inside-set_64bit.patch
  video-via-via-gpio.c-fix-warning.patch
  x86-asm-Clean-up-and-simplify-asm-cmpxchg.h.patch
  x86-kvm-Remove-cast-obsoleted-by-set_64bit-prototype.patch
- update to 2.6.36-rc6-git2

* Mon Sep 27 2010 Thomas Backlund <tmb@mandriva.org> 2.6.35.6-1mnb2
+ Revision: 581410
- prepare to release
- update to 2.6.35.6 (CVE-2010-2960)
  * rediff char-agp-intel-new-Q57-id.patch

* Tue Sep 21 2010 Thomas Backlund <tmb@mandriva.org> 2.6.35.5-1mnb2
+ Revision: 580422
- Prepare to release
- update to 2.6.35.5 (CVE-2010-3081, CVE-2010-3301)
- raise CONFIG_NR_CPUS to 128 on server kernels
- raise CONFIG_NR_CPUS to 64 (mdv #60928)

* Sat Aug 28 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.35.4-1mnb2
+ Revision: 573618
- Merge following upstream fixes:
  pci: fix type warnings in intr_remapping.c
  intel-iommu: Fix 32-bit build warning with __cmpxchg()
  Staging: dt3155v4l: correcting a pointer mismatch bug and cleanups
  drivers/video/via/via-gpio.c: fix warning
  x86, kvm: Remove cast obsoleted by set_64bit() prototype cleanup
  um, x86: Cast to (u64 *) inside set_64bit()
- Prepare to release.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.35.4 (CVE-2010-2803)
      * drop merged patches:
        fs-nfs-fix-an-oops-in-the-NFSv4-atomic-open-code.patch
        x86-asm-Clean-up-and-simplify-set_64bit.patch
    - fix 2.6.35.2 regression: Kernel panic or instant reboot on udev
      modules loading (intel-agp, i915) (kbz #16612)
    - update to 2.6.35.3
      * drop merged patches:
        mm-fix-page-table-unmap-for-stack-guard-page-properly.patch
        mm-fix-up-some-user-visible-effects-of-the-stack-guard-page.patch
    - add CVE to changelog

* Wed Aug 18 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.35.2-1mnb2
+ Revision: 571119
- Prepare to release.
- Replace nfs oops fix with correct patch.
- nfs: fix fsync error with nfs (upstream commit "NFS: fix the
  return value of nfs_file_fsync()")
- Update to 2.6.35.2, dropped merged patches:
  arch-powerpc-fix-build-with-make-3.82.patch
  kernel-sched-Revert-nohz_ratelimit.patch
  pci-disable-MSI-on-Via-K8M800.patch
  md-raid10-avoid-deadlock-on-resync.patch
- Updated ramzswap staging module to latest zram, (hg 193, see
  http://code.google.com/p/compcache/issues/detail?id=68)

  + Thomas Backlund <tmb@mandriva.org>
    - nfs: fix kernel oops when positive file is opened with O_EXCL
      but not with O_CREAT
    - mm: fix up some user-visible effects of the stack guard page (kbz #16588)
    - mm: fix page table unmap for stack guard page properly
      (fixes 2.6.35.2 breakage (mostly triggered with PAE / HIGHPTE))
    - ideapad: Only allow camera state to be set to 0 or 1
    - ideapad: Stop using global variables
    - Revert: merge samsung-backlight with samsung-laptop that got merged upstream (for now, needs more work)
    - merge samsung-backlight with samsung-laptop that got merged upstream
    - add Lenovo IdeaPad ACPI Laptop Extras support

* Tue Aug 10 2010 Thomas Backlund <tmb@mandriva.org> 2.6.35.1-1mnb2
+ Revision: 568861
- update to 2.6.35.1 and prepare for release
- md: fix deadlock on raid10 during resync
- restore powerpc support
- powerpc: fix build breakage with make 3.82 (Sam Ravnborg)
- sched: Revert nohz_ratelimit(), as it causes excessive wakeups

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Backport "vmscan: raise the bar to PAGEOUT_IO_SYNC stalls" and
      "vmscan: synchronous lumpy reclaim don't call congestion_wait()"
      changes (should fix behaviour reported at
      http://lkml.org/lkml/2010/4/4/86).

* Mon Aug 02 2010 Thomas Backlund <tmb@mandriva.org> 2.6.35-1mnb
+ Revision: 564941
- disable powerpc due to broken make-3.82
- release 2.6.35 final
- disable powerpc build, broken with make the updated make-3.82 :(
- update alsa version, drop old backport config changes
- add buildfixes for 2.6.35 for ndiswrapper, viahss, samsung-backlight,
  and netfilter IFWLOG, ipset and psd modules
- enable CGROUPS for all kernels, update defconfigs
- merge source2 and source3 into one patch
- drop ipset-2.4.9 patches (used for backporting 2010.1 kernel to 2010.0)
- drop ununsed apparmor stuff, a rewritten version will be merged in 2.6.36
- * drop merged patches:
  media-dvb-saa7134-avr-m135a-more-remotes.patch
  media-dvb-saa7134-add-support-for-m733a.patch
  media-video-revert-V4L-DVB-11906-saa7134-Use-v4l-bounding-alignment.patch
  video-fb-fix-unregister_framebuffer-fb_destroy.patch
  * rediff patches:
  3rd-3rdparty-merge.patch
- * drop merged patches:
  hid-Support-for-3M-multitouch-panel.patch
  hid-add-support-for-Stantum-multitouch-panel.patch
  hid-fixed-bug-in-single-touch-emulation-on-the-stant.patch
  hid-add-pressure-support-for-the-Stantum-multitouch-.patch
  hid-add-support-for-Acer-T230H-multitouch.patch
  hid-add-support-for-Pixart-Imaging-Optical-Touch-Scr.patch
  hid-let-hid-input-accept-digitizers.patch
  hid-Support-for-MosArt-multitouch-panel.patch
  hid-remove-MODULE_VERSION-from-new-drivers.patch
  hid-ntrig-add-multi-input-quirk-and-clean-up.patch
  hid-n-trig-remove-unnecessary-tool-switching.patch
  hid-ntrig-multitouch-cleanup-and-fix.patch
  hid-ntrig-Single-touch-mode-tap.patch
  hid-ntrig-fix-touch-events.patch
  sound-alsa-hda-add-ideapad-model-for-conexant-5051.patch
  * rediff patches:
  sound-alsa-hda_intel-prealloc-4mb-dmabuffer.patch
- * drop merged patches:
  net-atl1c-add-support-for-AR8151-AR8152.patch
  net-phylib-Support-phy-module-autoloading.patch
  net-phylib-Add-module-table-to-all-existing-phy-drivers.patch
  net-phylib-fix-typo-in-bcm6xx-PHY-driver-table.patch
  net-r8169-Fix-rtl8169_rx_interrupt.patch
  net-r8169-fix-random-mdio_write-failures.patch
  net-r8169-fix-mdio_read-and-update-mdio_write-according-to-hw-specs.patch
  net-sis190-link-status-poll.patch
  net-wireless-Add-USB-ID-for-Thomson-SpeedTouch-120g-to-p54usb-id-.patch
  net-wireless-ar9170-add-support-for-NEC-WL300NU-G-USB-dongle.patch
  sound-alsa-hda-via-fix-master-mute-and-automute-with-VT1812_VT2002P.patch
  sound-alsa-pcm_lib.c-convert-second-xrun_debug-parameter.patch
  sound-alsa-pcm_lib-add-possibility-to-log-last-10-DMA-ring.patch
  sound-alsa-pcm_lib-cleanup-merge-hw_ptr-update-functions.patch
  sound-alsa-pcm_lib-optimize-wake_up-calls-for-PCM-I-O.patch
  sound-alsa-pcm_lib-fix-something-must-be-really-wrong-condition.patch
  sound-alsa-pcm_lib-fix-wrong-delta-print-for-jiffies-check.patch
  sound-alsa-pcm_core-Fix-wake_up-optimization.patch
  sound-alsa-pcm_lib-return-back-hw_ptr_interrupt.patch
  sound-alsa-pcm_native-fix-runtime-boundary-calculation.patch
  sound-alsa-pcm_lib-fix-xrun-functionality.patch
  sound-alsa-pcm-fix-the-fix-of-the-runtime-boundary-calculation.patch
  sound-alsa-pcm-fix-delta-calculation-at-boundary-wraparound.patch
  * rediff patches:
  include-kbuild-export-pci_ids.patch
  platform-x86-add-samsung-backlight-driver.patch
- * drop merged patches:
  fs-btrfs-fix-memory-corruption-on-mount.patch
  fs-cifs-fix-a-malicious-redirect-problem-in-the-DNS-lookup-code_CVE-2010-2524.patch
  fs-ext4-Prevent-creation-of-files-larger-than-RLIMIT_FSIZE-using-fallocate.patch
  gpu-drm-i915-stop-trying-to-use-ACPI-lid-status.patch
  gpu-drm-edid-fix-typo-in-1600x1200-75-mode.patch
  hwmon-coretemp-update.patch
  input-add-an-option-to-force-the-use-of-the-elantech-extension.patch
  input-atkbd-philco-i4xsi-release-keys.patch
  input-atkbd-positivo-i30-release-keys.patch
  input-elantech-firmware-versions-ge-2.48-use-6-byte-packets.patch
  input-elantech-ignore-high-bits-in-the-position-coordinates.patch
  input-elantech-update-elantech-documentation.patch
  input-elantech-whitelist-new-models-with-firmware-version-4.1.patch
  input-hid-extend-mask-for-BUTTON-usage-page.patch
  input-hid-handle-joysticks-with-large-number-of-buttons.patch
  input-tablet-linuxwacom-0.8.5-12.patch
  * rediff patches:
  char-agp-intel-new-Q57-id.patch
- drop patch merged in squashfs lzma rebase
- rebase squashfs lzma support
- rebase unionfs 2.5.4 for 2.6.35
- adapt unionfs for vfs changes in 2.6.35
- * drop merged patches:
  pci-no-dmar.patch
  acpi-video-Be-more-liberal-in-validating-_BQC-behaviour.patch
  scsi-advansys-fix-regression-with-request_firmware-change.patch
  scsi-advansys-fix-narrow-board-error-path.patch
  ata-ahci-add-missing-nv-IDs.patch
  ata-pata_marvell-CONFIG_AHCI-is-really-CONFIG_SATA_AHCI.patch
  * rediff patches:
  acpi-add-proc-event-regs.patch
- * drop merged patches:
  x86-powernow-k8-Add-core-performance-boost-support.patch
  x86-cpu-Add-AMD-core-boosting-feature-flag-to-proc-cpuinfo.patch
  x86-kernel-set_bios_reboot-is-needed-for-Dell-Precision-WorkStation-T7400.patch
  x86-kernel-Send-a-SIGTRAP-for-user-icebp-traps.patch
  base-firmware_class-fix-memory-leak-free-allocated-pages.patch
  kernel-Prioritize-synchronous-signals-over-normal-signals.patch
  kernel-panic-call-console_verbose-in-panic.patch
- * drop merged patches:
  gpu-drm-nouveau-add-nv50-nv8x-nv9x-ctxprogs-generator.patch
  gpu-drm-nouveau-fix-missing-locking.patch
  gpu-drm-nouveau-git-20100316.patch
- start upgrade to 2.6.35
- add back missing Kconfig option so samsung-backlight is built (mdv #60386)

* Tue Jul 27 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33.6-2mnb
+ Revision: 562086
- fix changelog date
- prepare for release
- x86: Send a SIGTRAP for user icebp traps, fixes Wine apps breakage (mdv #60067)
- CIFS: Fix a malicious redirect problem in the DNS lookup code (CVE-2010-2524)
- update to 2.6.33.6
  * drop merged patches (since 2.6.33.5-2mnb):
    ata-libata-disable-atapi-an-by-default.patch
    fs-btrfs-should-add-a-permission-check-for-setfacl.patch
    fs-gfs2-fix-permissions-checking-for-setflags-ioctl.patch
    gpu-drm_edid-Fix-1024x768-at-85Hz.patch
    gpu-drm-i915-fix-82854-pci-id-and-treat-it-like-other-85x.patch
    gpu-drm_radeon_kms_atom-fix-typo-in-LVDS-panel-info-parsing.patch
    gpu-drm_radeon_kms-reset-ddc_bus-in-object-header-parsing.patch
    kernel-posix_timer-Fix-error-path-in-timer_create.patch
    md-Fix-read-balancing-in-RAID1-and-RAID10-on-drives-bigger-than-2TB.patch
    md-linear-avoid-possible-oops-and-array-stop.patch
    md-raid1-fix-counting-of-write-targets.patch
    media-v4l-dvb-gspca-stv06xx-remove-the-046d-08da-from-the-stv06xx-driver.patch
    net-sctp-Fix-skb_over_panic-resulting-from-multiple-invalid-parameter-errors_CVE-2010-1173.patch
    pci-disable-msi-for-MCP55-on-P5N32-E-SLI.patch
    rtc-cmos-do-dev_set_drvdata-earlier-in-the-initialization.patch
    staging-vt6655-fix-kernel-bug-on-driver-wpa-initialization.patch
  * drop merged patches (added to svn after 2.6.33.5-2mnb but not released):
    acpi-video-fix-acpi_backlight-video.patch
    ata-ahci-add-pci-quirk-for-jmb362.patch
    ata-sata_nv-don-t-diddle-with-nien-on-mcp55.patch
    ata-sata_nv-use-ata_pci_sff_activate_host-instead-of-ata_host_activate.patch
    ata-sata_via-magic-vt6421-fix-for-transmission-problems-w-wd-drives.patch
    fs-ext4-check-s_log_groups_per_flex-in-online-resize-code.patch
    fs-ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files.patch
    fs-nfsd-don-t-report-compiled-out-versions-as-present.patch
    fs-tmpfs-insert-tmpfs-cache-pages-to-inactive-list-at-first.patch
    gpu-drm-i915-rebind-bo-if-currently-bound-with-incorrect-alignment.patch
    gpu-drm-i915-reject-bind_to_gtt-early-if-object-aperture.patch
    gpu-drm-radeon-fix-the-r100-r200-ums-block-0-page-fix.patch
    gpu-drm-radeon-r100-r200-ums-block-ability-for-userspace-app-to-trash-0-page-and-beyond.patch
    net-wireless-ar9170usb-add-a-couple-more-usb-ids.patch
    net-wireless-ar9170usb-fix-panic-triggered-by-undersized-rxstream-buffer.patch
    net-wireless-p54usb-add-device-id-for-dell-wla3310-usb.patch
    pci-quirk-disable-msi-on-via-k8t890-systems.patch
    pci-quirks-disable-msi-on-amd-rs4xx-internal-gfx-bridges.patch
    staging-add-add-sitecom-wl-349-to-rtl8192su.patch
    staging-rt2870-add-device-id-of-melco.-inc.-wli-uc-g301n.patch
    usb-option-add-pid-for-zte-product.patch
    usb-option.c-add-pirelli-vid-pid-and-indicate-pirelli-s-modem-interface-is-0xff.patch
    usb-option.c-olivetti-olicard100-support.patch
    usb-serial-option-add-cinterion-device-id.patch
    x86-amd-iommu-fall-back-to-gart-if-initialization-fails.patch
    x86-amd-iommu-fix-crash-when-request_mem_region-fails.patch
- staging: rt2870: add MelCo.,Inc. WLI-UC-G301N device ID
- staging: add Add Sitecom WL-349 to rtl8192su
- ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only files
- ext4: check s_log_groups_per_flex in online resize code
- nfsd: don't report compiled-out versions as present
- x86/amd-iommu: Fall back to GART if initialization fails
- drm/radeon: r100/r200 ums: block ability for userspace app to
  trash 0 page and beyond
- drm/i915: Rebind bo if currently bound with incorrect alignment
- drm/i915: Reject bind_to_gtt() early if object > aperture, before
  evicting everything in a vain attempt to find space
- option: add support for ZTE, Pirelli, Cinteron and Olicard100 products
- x86/amd-iommu: Fix crash when request_mem_region fails
- tmpfs: insert tmpfs cache pages to inactive list at first
  (fixes OOM killer triggering on parallel file copy on tmpfs)
- sata_via: magic vt6421 fix for transmission problems with recent WD drives
- sata_nv: use ata_pci_sff_activate_host() instead of ata_host_activate()
  (fixes IRQ assignment failure in legacy mode)
- sata_nv: don't diddle with nIEN on mcp55, as it gets stuck once set,
  and mcp55 has its own IRQ masking mechanism so there's no reason to
  mess with nIEN in the first place.v(fixes liteon bluray iHOS104-08 error)
- pci: disable msi on AMD rs4xx internal gfx bridges
- pci: Disable MSI on VIA K8T890 systems
- p54usb: Add device ID for Dell WLA3310 USB
- ar9170usb: fix panic triggered by undersized rxstream buffer
- ar9170usb: add support for more devices:
  * Netgear WNA1000
  * Proxim ORiNOCO Dual Band 802.11n USB Adapter
  * 3Com Dual Band 802.11n USB Adapter
  * H3C Dual Band 802.11n USB Adapter
  * WNC Generic 11n USB dongle
- ahci: add pci quirk for JMicron JMB362
- acpi/video: be more liberal in validating _BQC behaviour
- acpi/video: fix acpi_backlight=video parameter to correctly enable
  ACPI_VIDEO_BACKLIGHT_FORCE_VIDEO
- Fix rebooting on Dell Precision WorkStation T7400 (#58017)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - backport coretemp fixes/updates (new hardware support):
      hwmon: (coretemp) Fix cpu model output
      drivers/hwmon/coretemp.c: detect the thermal sensors by CPUID
      drivers/hwmon/coretemp.c: get TjMax value from MSR
      hwmon: (coretemp) Skip duplicate CPU entries
      hwmon: (coretemp) Properly label the sensors
    - agp/intel: add new host bridge id for Q57 system

* Thu Jun 17 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.5-2mnb2
+ Revision: 548285
- Prepare to release 2.6.33.5-2mnb
- Patch for CVE-2010-2071
- ALSA: hda-intel: add ideapad model for Conexant 5051

  + Thomas Backlund <tmb@mandriva.org>
    - add description for CVE-2010-2071
    - sctp: Fix skb_over_panic resulting from multiple invalid parameter
      errors (CVE-2010-1173)
    - ext4: Prevent creation of files larger than RLIMIT_FSIZE using fallocate
      (fixes Ext4 Security Bypass Vulnerability)
    - staging: vt6655: Fix kernel BUG on driver wpa initialization
    - libata: disable ATAPI AN by default
      (Fixes issue with ATAPI devices which raise AN when hit by commands issued
       by open(). This leads to infinite loop of AN -> MEDIA_CHANGE uevent ->
       udev open() to check media -> AN)
    - V4L/DVB: gspca - stv06xx: Remove the 046d:08da from the stv06xx driver
      (fixes nonworking QuickCam Messenger)
    - drm/i915: Fix 82854 PCI ID, and treat it like other 85X
    - reset changelog to unreleased
    - add upstream fixes for r8169: (fixes #59723)
      	- fix rtl8169_rx_interrupt()
      	- fix random mdio_write failures
      	- fix mdio_read and update mdio_write according to hw specs

* Wed Jun 02 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.5-1mnb2
+ Revision: 547004
- Apply change "ALSA: pcm: fix delta calculation at boundary
  wraparound" from upstream kernel, bug fix to previously added
  sound-alsa-pcm_lib-cleanup-merge-hw_ptr-update-functions.patch
- Apply change "ALSA: pcm: fix the fix of the runtime->boundary
  calculation" from upstream kernel, bug fix to previously added
  patch sound-alsa-pcm_native-fix-runtime-boundary-calculation.patch
- Changelog cosmetics.
- Include fix for CVE-2010-1641 (kernel: GFS2: The setflags ioctl()
  doesn't check file ownership).

  + Thomas Backlund <tmb@mandriva.org>
    - x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo
    - powernow-k8: Add core performance boost suppor
    - posix_timer: Fix error path in timer_create
    - panic: call console_verbose() in panic to ensure a directly
      called panic will print a backtrace.
    - Prioritize synchronous signals over 'normal' signals
      (fixes Wine deadlocking the kernel (#59545))
    - drop patch (it got reverted upstream in commit d4b74bf07873da2e94219a7b67a334fc1c3ce649):
      gpu-drm_i915-Configure-the-TV-sense-state-correctly-on-GM45-to-make-TV-detection-reliable.patch
    - update to 2.6.33.5
      * Drop merged patches:
        fs-cifs-guard-against-hardlinking-directories.patch
        gpu-drm-i915-disable-fbc-on-915gm-and-945gm.patch
        gpu-drm-i915-fix-non-ironlake-965-class-crashes.patch
        gpu-drm-i915-use-pipe_control-instruction-on-ironlake-and-sandy-bridge.patch
        net-ipv4-udp-fix-short-packet-and-bad-checksum-logging.patch
        net-wireless-REVERT-ath9k-fix-lockdep-warning-when-unloading-module.patch
        sound-alsa-hda-Fix-0-dB-for-Lenovo-models-using-Conexant-C.patch
        sound-alsa-hda-fix-dg45id-spdif-output.patch
        sound-alsa-hda-new-intel-hda-controller.patch
        sound-alsa-ice1724-Fix-ESI-Maya44-capture-source-control.patch
        sound-alsa-revert-alsa-hda-realtek-quirk-for-d945gclf2-mainboard.patch
        sound-alsa-virtuoso-fix-Xonar-D1-DX-front-panel-microphone.patch
        x86-amd-check-x86_feature_osvw-bit-before-accessing-osvw-msrs.patch
        x86-cacheinfo-turn-off-l3-cache-index-disable-feature-in-virtualized-environments.patch

* Tue May 25 2010 Pascal Terjan <pterjan@mandriva.org> 2.6.33.4-3mnb2
+ Revision: 545944
- prepare to release
- Add patches to support phy module autoloading (#57958)

  + Thomas Backlund <tmb@mandriva.org>
    - fix typo
    - pci: disable MSI for MCP55 on P5N32-E SLI (fixes NIC problems)
    - pci: disable MSI on Via K8M800 (fixes problems with AHCI)
    - md: avoid possible-oops and array stop on linear layout
    - md: fix counting of write targets on raid1
    - md: Fix read balancing in RAID1 and RAID10 on drives > 2TB
    - fix patch names
    - drm/edid: fix 1600x1200@75Hz
    - drm/i915: Configure the TV sense state correctly on GM45 to make TV
      detection reliable
    - drm/radeon/kms: reset ddc_bus in object header parsing
    - drm/radeon/kms/atom: fix typo in LVDS panel info parsing
    - drm/edid: Fix 1024x768@85Hz
    - firmware_class: fix memory leak introduced by the patch 6e03a201bbe:
      firmware: speed up request_firmware()

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Add missing bug number to changelog.

* Fri May 21 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.4-2mnb2
+ Revision: 545556
- Prepare to release.
- Replace "dev_set_drvdata before rtc_device_register in rtc_cmos"
  fix with same solution applied upstream.
- Apply "drm/i915: Stop trying to use ACPI lid status to determine
  LVDS connection.", fixes lost display after closing lid on some
  laptops (#59133)
- Fix oops with plymouthd quiting on vesafb after i915 with
  modesetting is loaded.

  + Thomas Backlund <tmb@mandriva.org>
    - ath9k: revert: "ath9k: fix lockdep warning when unloading module" introduced
      in 2.6.33.2, as it wasn't meant for kernels <=2.6.34 (fixes warning in #56614)
      (Reference: http://marc.info/?l=linux-kernel&m=127430485607989&w=2)
    - x86, amd: Check X86_FEATURE_OSVW bit before accessing OSVW MSRs, prevents
      GP fault
    - x86: cacheinfo: Turn off L3 cache index disable feature in virtualized
      environments, fixes crash on boot on xen.
    - alsa: hda-intel: Add a PCI controller id found on new Dell laptops
    - drm/i915: Disable FBC on 915GM and 945GM as it causes hangs after suspend/resume
    - drm/i915: fix non-Ironlake 965 class PIPE_CONTROL crashes
    - drm/i915: use PIPE_CONTROL instruction on Ironlake and Sandy Bridge

* Sat May 15 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.4-1mnb2
+ Revision: 544839
- Prepare to release.
- Updated to 2.6.33.4
  * Drop following merged patches:
    scsi-retry-commands-with-UNIT_ATTENTION-sense-codes-to-fix-ext3-ext4-io-error.patch
    gpu-drm-i915-fix-tiling-limits-for-i915-class-hw-v2.patch
    gpu-drm-i915-build-fix-for-fix-tiling-limits-change.patch
    net-bnx2-Fix-lost-MSI-X-problem-on-5709-NICs.patch

  + Thomas Backlund <tmb@mandriva.org>
    - cifs: guard against hardlinking directories
    - pata_marvell: fix sata port ahci fallback
    - ahci: add missing nVidia mcp64-73 ids
    - ar9170: add support for NEC WL300NU-G USB dongle
    - p54usb: add USB ID for Thomson SpeedTouch 120g
    - ipv4: udp: fix short packet and bad checksum logging
    - ALSA: virtuoso: fix Xonar D1/DX front panel microphone
    - ALSA: ice1724 - Fix ESI Maya44 capture source control
    - ALSA: hda: Fix 0 dB for Lenovo models using Conexant CX20549 (Venice)
    - ALSA: hda - fix DG45ID SPDIF output
    - Revert "ALSA: hda/realtek: quirk for D945GCLF2 mainboard" as it's not
      valid for all revisions of the D945GCLF2 mainboard

  + Pascal Terjan <pterjan@mandriva.org>
    - Add upstream patch to retry commands with UNIT_ATTENTION sense codes to fix ext3/ext4 I/O error

* Tue May 04 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.3-1mnb2
+ Revision: 542080
- Prepare to release.
- Sync advansys fix for MDV #53220 with upstream applied patches.
- Replace previously added synce 'dirty patch' from John Carr, by
  upstream sent fix "rndis_host: Poll status channel before control
  channel" from Ben Hutchings.
- Add upstream bug fix for bnx2 timeout with MSI enabled, requested
  on http://lists.mandriva.com/kernel-discuss/2010-04/msg00015.php
- Add elantech patch series for new touchpad versions (found mainly
  on Asus UL{2,3,5,8}0, Asus P-Series, new Dell machines), from
  linux-input ML.

  + Pascal Terjan <pterjan@mandriva.org>
    - Replace fs-btrfs-fix-memory-corruption-on-mount.patch with correct one (#59051)
    - Add ispnp async init patch from Ubuntu (requested by fcrozat)

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - use CURDIR instead of PWD, to allow using -C
    - oops, typo
    - allow using repsys target to prepare for srpms generation (still being
      tested)

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.33.3
      * drop merged patches:
        x86-Erratum-workaround-for-read-after-write-of-HPET-comparator.patch
        net-wireless-b43-allow-pio-at-runtime.patch
        sound-alsa-hda-Add-position_fix-quirk-for-Biostar-mobo.patch

* Thu Apr 22 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.2-3mnb2
+ Revision: 537957
- Fix building after the patch
  gpu-drm-i915-fix-tiling-limits-for-i915-class-hw-v2.patch
  was added.
- Revert new signature for alps touchpad, it doesn't suffice to make new
  alps touchpad to work, see thread at
  http://www.spinics.net/lists/linux-input/msg07729.html
- Add new alps signature for touchpad found on Acer 7740G
  (MDV #58811). See https://bugzilla.kernel.org/show_bug.cgi?id=15359#c9,
  included was same patch mentioned there as it's the same signature
  from bug report.
- Apply updated upstream patch (v2) for freedesktop.org bug #27449
  Reference: http://lists.mandriva.com/kernel-discuss/2010-04/msg00007.php
- Apply "ALSA: hda - Add position_fix quirk for Biostar mobo", fix
  for issue reported on Cooker ML.

  + Pascal Terjan <pterjan@mandriva.org>
    - Add a patch by arnaud to avoid a crash on VirtualBox x86_64 without IO-APIC

* Thu Apr 15 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.2-2mnb2
+ Revision: 535113
- Prepare to release.
- ALSA: hda - via - fix master mute and automute with VT1812/VT2002P
- Apply fix from freedesktop.org bug #27449 (drm/i915: fix tiling
  limits for i915 class hw). Reference:
  http://lists.mandriva.com/kernel-discuss/2010-04/msg00004.php
- Drop from patches-broken gpu-drm-i915-add-gem-enable-parameter.patch,
  it should be uneeded currently.
- Oops, add missing -p1 arg for patch after previous change.
- Bring back old ipset version to allow backport.
- Updated ipset to version 4.2
- Apply change "ALSA: pcm_lib - fix xrun functionality" from
  upstream kernel, bug fix to previously added patch
  sound-alsa-pcm_lib-add-possibility-to-log-last-10-DMA-ring.patch
- Don't create debug packages by default when building backport
  packages for 2010.0
- Drop hid-usbhid-quirk-multilaser.patch (reset leds quirk): this is
  obsolete, since commit 08ef08e in upstream kernel.
- wacom: update to linuxwacom.sf.net version 0.8.5-12 (updated
  hardware support). Reference:
  http://lists.mandriva.com/kernel-discuss/2010-04/msg00000.php

  + Thomas Backlund <tmb@mandriva.org>
    - apply nouveau git update only for 2010.1
    - restore and apply nouveau ctxprogs generator for nv50/nv8x/nv9x
      only for 2010.0 backports

* Mon Apr 05 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.2-1mnb2
+ Revision: 531903
- Prepare to release 2.6.33.2-1mnb
- saa7134: Fix tuner_config setting for Avermedia M733A (from
  Avermedia). Also add new pci id support.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.33.2
      * drop merged patch:
        net-wireless-ath9k-ar2427.patch
      * rediff patch:
        gpu-drm-nouveau-git-20100316.patch

* Mon Mar 29 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.1-2mnb2
+ Revision: 528806
- Prepare to release 2.6.33.1-2mnb
- Include more hid drivers from 2.6.34-rc2: hid-3m-pct, hid-mosart,
  hid-quanta, hid-stantum.
  Reference: http://lists.mandriva.com/kernel-discuss/2010-03/msg00007.php
- saa7134: add support for Avermedia M733A. The original version for
  linux 2.6.31 was sent to me from Avermedia, original author is
  unknown, I ported it to 2.6.33.
- New advansys patch with fixed error handling.
- Apply n-trig patches from 2.6.34-rc2 to fix/add hardware support
  on some newer dell notebook models.
  Reference: http://lists.mandriva.com/kernel-discuss/2010-03/msg00005.php
- Fix advansys regression when firmware files are not found or
  loading fails (MDV #53220).
- Revert commit which breaks saa7134 tv output ("V4L/DVB (11906):
  saa7134: Use v4l bounding/alignment function").
- saa7134: add one more remote control type for for Avermedia M135A.
- Fix mach64 to handle drm_ioctl unlocked_ioctl switch in 2.6.33

* Tue Mar 16 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.33.1-1mnb2
+ Revision: 521930
- Prepare to release.
- Updated to 2.6.33.1
  * drop following merged patches:
    ahci-disable-FPDMA-auto-activate-optimization-on-NVIDIA-AHCI.patch
    security-fix-error-return-path-in-ima_inode_alloc.patch
  * rediff net-wireless-ath9k-ar2427.patch

  + Anssi Hannula <anssi@mandriva.org>
    - update nouveau to git snapshot (allowing and requiring the upgrade
      of nouveau userspace)
    - Fix quilt command for patch removal in managing-patches.txt

  + Pascal Terjan <pterjan@mandriva.org>
    - Update unionfs fix, to fix the issue instead of trying to workaround it

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - fixed glob in created_quilt_tree

  + Thomas Backlund <tmb@mandriva.org>
    - update unionfs to v. 2.5.4
    - fix series file
    - btrfs: fix memory corruption on mount
    - add HPET Erratum fix for triggering WARN_ON due to mismatch on
      HPET_Tn_CMP readback (replaces HPET: Drop WARN_ON for mismatch
      on HPET_Tn_CMP readback)
    - ahci: disable FPDMA auto-activate optimization on NVIDIA AHCI
    - security: fix error return path in ima_inode_alloc

* Wed Feb 24 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-1mnb2
+ Revision: 510799
- Prepare to release
- alsa: hda_intel: preallocate 4MB dma buffer (Request by Colin)
- update to 2.6.33 final
  * drop merged patches:
    net-wireless-iwlwifi-fix-AMSDU-Rx-afte-paged-Rx-patch.patch
    net-mac80211-fix-handling-of-null-rate-control-in-rate_control_get_rate.patch
  * rediff patch:
    acpi-processor-M720SR-limit-to-C2.patch
- drop patch:
  kernel-pid-export-find_task_by_vpid-symbol-for-fglrx.patch
  (not needed anymore, confirmed by Anssi)
- b43: convert B43_PIO(_FORCE) to a module option (pio=1)
- HPET: Drop WARN_ON for mismatch on HPET_Tn_CMP readback

* Sat Feb 13 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-0.rc8.1mnb2
+ Revision: 505186
- Tag Release
- iwlwifi: fix broken AMSDU Rx functionality
- mac80211: fix handling of null-rate control in rate_control_get_rate
- add support for Atheros AR8151 and AR8152
- drop merged pathces:
  fs-freeze_bdev-dont-deactivate-successfully-frozen-MS_RDONLY-sb.patch
  sound-alsa-hda-intel-avoid-divide-by-zero-crash.patch
- update to 2.6.33-rc8
- update ndiswrapper to 1.56
  * rediff 3rd-ndiswrapper-Makefile-build-fix.patch
  * drop 3rd-ndiswrapper-keep-local-cmpxchg8b-for-2.6.31.patch

  + Pascal Terjan <pterjan@mandriva.org>
    - add patches to fix Saitek X52 (#56765)

  + Anssi Hannula <anssi@mandriva.org>
    - drm: nouveau: add ctxprogs generator for nv50/nv8x/nv9x (fixes
      fd.o bug #23198)

* Sun Feb 07 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-0.rc7.1mnb2
+ Revision: 501610
- Tag Release
- alsa: hda-intel: avoid divide-by-zero crash (potential local DoS)
- drop merged patch: drm-intel-git-fixes.patch
- update to 2.6.33-rc7

* Sat Feb 06 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-0.rc6.6.3mnb2
+ Revision: 501476
- add fixes from drm-intel git queue for 2.6.33

* Sat Feb 06 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-0.rc6.6.2mnb2
+ Revision: 501303
- set CONFIG_SND_HDA_INPUT_BEEP_MODE=2
- update to 2.6.33-rc6-git6
- drop merged patch: x86-agp-fix-agp_amd64_init-regression.patch

* Fri Jan 29 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-0.rc6.1mnb2
+ Revision: 498357
- update to 2.6.33-rc6 and prepare for release
- update fix for #56768 with the one finally submitted upstream
- fix non-bootable dmraid due to oops in block_dev (#56768)
- Apply following changes from alsa-kernel tree:
  * ALSA: pcm_native: fix runtime boundary calculation
  (additional fix for #57010, requested by Colin)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Apply following changes from alsa-kernel tree:
      * ALSA: pcm_core: Fix wake_up() optimization
      * ALSA: pcm_lib - return back hw_ptr_interrupt
      Last one should fix MDV #57010

* Tue Jan 26 2010 Thomas Backlund <tmb@mandriva.org> 2.6.33-0.rc5.2.1mnb2
+ Revision: 496876
- x86/agp: fix agp_amd64_init regression
- update to 2.6.33-rc5-git2
- remove file diff committed by mistake
- update to 2.6.33-rc5
- update filelists
- update defconfigs
- rediff source2 and source3 to apply cleanly
- rediff 3rd-3rdparty-merge.patch
- drop patch: staging-et131x-va_phy_alignment.patch (fixed differently upstream)
- drop merged: media-video-bttv-add-another-i2c-addr-to-probe-for-ir.patch
- drop merged: media-video-uvc-handle-garbage-at-the-end-of-streaming-interface-descriptors.patch
- rediff sound-alsa-pcm_lib-add-possibility-to-log-last-10-DMA-ring.patch
- drop merged sound-alsa-hda-via-* updates
- rediff serial-docomo-pinfree1p.patch
- rediff platform-x86-add-samsung-backlight-driver.patch
- drop platform-x86-dell-laptop-Fix-rfkill-state-setting.patch (fixed differently upstream)
- rediff patch: net-wireless-ath9k-ar2427.patch
- drop merged patch: net-wireless-rtl8187-add-radio-led-and-fix-warnings-on-suspend.patch
- drop merged patch: net-ppp-enlarge-upload-buffer-to-cope-with-HSUPA-connections.patch
- rediff kbuild-really-dont-remove-bounds-asm-offsets-headers.patch
- rediff input-atkbd-positivo-i30-release-keys.patch
- fix gpu-drm-mach64.patch to apply cleanly
- fix sqashfs-lzma mismerge
- update squashfs-lzma support for 2.6.33 series kernels
- update unionfs for 2.6.33 series kernels
- drop nouveau patches, as it's now merged in mainline
- drop drbd from 3rdparty as it's now merged in mainline
- start rebase to 2.6.33-rc4-git7

* Fri Jan 15 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32.4-0.rc1.1mnb2
+ Revision: 491867
- Include missing .sign file.
- Prepare to release.
- Updated to 2.6.32.4-rc1
  * Dropped merged patches:
    fs-quota-fix-reserved-space-management-for-ordinary-fs.patch
    gpu-drm-remove-dma-mask-setting-in-drm_pci_alloc.patch
- Apply following change from alsa-kernel tree:
  ALSA: pcm_lib - fix wrong delta print for jiffies check
- Set CONFIG_EXT3_DEFAULTS_TO_ORDERED=y, default option was chosen
  on a previous config rebase (follow same recent change on
  kernel-linus and kernel-tmb packages).

* Fri Jan 08 2010 Thomas Backlund <tmb@mandriva.org> 2.6.32.3-2mnb2
+ Revision: 487796
- fix quota regression introduced in 2.6.32.3

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - "Tag" new release.
    - Apply following change from alsa-kernel tree:
      ALSA: pcm_lib: fix "something must be really wrong" condition

* Fri Jan 08 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32.3-1mnb2
+ Revision: 487412
- Updated to 2.6.32.3
- Apply following changes from alsa-kernel tree:
  ALSA: pcm_lib.c - convert second xrun_debug() parameter to use defines
  ALSA: pcm_lib - add possibility to log last 10 DMA ring buffer positions
  ALSA: pcm_lib - cleanup & merge hw_ptr update functions
  ALSA: pcm_lib - optimize wake_up() calls for PCM I/O

* Wed Jan 06 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32.3-0.rc2.1mnb2
+ Revision: 486686
- Fix mach64 drm build with changed drm_pci_alloc of previous commit.
- Apply "remove dma mask setting in drm_pci_alloc" fix from
  http://bugzilla.kernel.org/show_bug.cgi?id=14627#c30
- Updated to 2.6.32.3-rc2
  * revert potential quota deadlock on ext4 patch and fix rt61pci
    powersaving disable fix, based on LKML comments.
- Enable namespaces support for all kernel flavours, not only for kernel
  server, as more applications are starting to use it not only in server
  configurations (for example google chrome using PID namespaces for
  sandboxing).

* Wed Dec 23 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32.2-2mnb2
+ Revision: 481854
- ath9k: add support for new Atheros device (0x002c).

  + Pascal Terjan <pterjan@mandriva.org>
    - Fix a oops when removing openoffice.org-voikko from a flash
    - Add lzma support for squashfs

* Mon Dec 21 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32.2-1mnb2
+ Revision: 480742
- rtl8187: add radio led and fix warnings on suspend.
- Updated to 2.6.32.2

  + Thomas Backlund <tmb@mandriva.org>
    - disable MULTICORE_RAID456, it's not production ready (reported by Anssi)

  + Pascal Terjan <pterjan@mandriva.org>
    - Switch to unionfs 2.x, it seems to work fine now

* Wed Dec 16 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32.1-1mnb2
+ Revision: 479501
- Updated to 2.6.32.1

* Sat Dec 12 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.32-1mnb2
+ Revision: 477589
- Fixed kversion definition.
- Package build fixes.
- Redid/rediff 3rd-ndiswrapper-keep-local-cmpxchg8b-for-2.6.31.patch
- Updated drbd to version 8.3.6
- Rediff/redid patches:
  disable-mrproper-in-devel-rpms.patch
 disable-prepare-scripts-configs-in-devel-rpms.patch
- Dropped hid-hid-ntrig-ingnore-HID_DG_INRANGE.patch because of different
  fix upstream in 2.6.32.
- Fixed heci build.
- Misc build fixes.
- * updated nouveau to latest git snapshot.
- Regenerate configs for 2.6.32
- (work in progress)
- Update to 2.6.32:
  * dropped merged patches:
    net-wireless-rtl8187-fix-circular-locking-rtl8187_stop-rtl8187_work.patch
    net-wireless-rtl8187-Implement-rfkill-support.patch
    net-wireless-rtl8187-fix-kernel-oops-when-device-is-removed.patch
    net-jme-fix-unmatched-tasklet_-enable-disable-pair.patch
    net-wireless-hostap-Revert-a-toxic-part-of-the-conversion-to-net_device_ops.patch
    platform-x86-add-topstar-laptop-driver.patch
    rtc-add-boot_timesource-sysfs-attribute.patch
    sound-alsa-hda-dont-select-unavailable-dmic.patch
    sound-alsa-pcm-Tell-user-that-stream-to-be-rewound-is-susp.patch
    fs-chrdev-implement-__re-unregister_chrdev.patch
    sound-request-char-major-module-aliases-for-missing-OSS-devices.patch
    sound-make-OSS-device-number-claiming-optional-and-schedule-its-removal.patch
    sound-alsa-hda-Add-quirks-for-some-HP-laptops.patch
    sound-alsa-hda-Add-support-for-HP-dv6.patch
    sound-alsa-hda-set-default-GPIO-for-STAC-IDT-codecs.patch
    sound-alsa-hda-set-default-GPIO-for-IDT92HD71bxx.patch
    media-dvb-12197-Remove-unnecessary-semicolons.patch
    media-dvb-12396-patch-Added-Support-for-STK7700D-DVB.patch
    media-dvb-12584-Support-for-Kaiser-Baas-ExpressCard-Du.patch
    media-dvb-12886-Added-new-Pinnacle-USB-devices.patch
    media-dvb-12888-STK7770P-Add-support-for-STK7770P.patch
    media-dvb-12889-DIB0700-added-USB-IDs-for-a-Terratec-D.patch
    media-dvb-12892-DVB-API-add-support-for-ISDB-T-and-ISD.patch
    media-dvb-12896-ISDB-T-add-mapping-of-LAYER_ENABLED-to.patch
    media-dvb-12898-DiB0070-Update-to-latest-internal-rele.patch
    media-dvb-12899-DiB0070-Indenting-driver-with-indent-l.patch
    media-dvb-12900-DiB8000-added-support-for-DiBcom-ISDB-.patch
    media-dvb-12901-DiB0700-add-support-for-STK807XP-and-S.patch
    media-dvb-12903-DiB8000-fix-channel-search-parameter-i.patch
    media-dvb-12906-dib0700-Add-support-for-Prolink-SBTVD.patch
    staging-rtl8187se-rtl8192su-allow-module-unload.patch
  * rediffed patches:
    include-kbuild-export-pci_ids.patch
    sound-alsa-hda-ad1884a-hp-dc-model.patch
    hid-usbhid-quirk-multilaser.patch
    media-video-uvc-handle-garbage-at-the-end-of-streaming-interface-descriptors.patch
    3rd-3rdparty-merge.patch
  * moved to patches-broken, to be decided if still needed to keep:
    sound-alsa-hda-add-msi-quirk-list.patch (different fix in alsa now)
  * drop net-wireless-rt2800-use-ralink-staging-driver.patch and
    net-wireless-rt2800usb-move-ids.patch, reenable use of rt2800usb.
- (work in progress)
- Update to 2.6.32:
  * rediffed patches:
    input-atkbd-philco-i4xsi-release-keys.patch
    input-atkbd-positivo-i30-release-keys.patch
    net-netfilter-IFWLOG-mdv.patch
    net-netfilter-psd-mdv.patch
    net-wireless-zd1211rw-add-id.patch
    net-usb-rndis-lite-samsung.patch
  * dropped merged patches:
    input-sentelic-remove-direct-access-to-PS-2-port.patch
    hwmon-asus_atk0110-Refactor-the-code.patch
    net-wireless-ath9k-race-condition-in-SCANNING-state-check-during-ANI-calibration.patch
    input-sentelic-drop-unused-variables-from-fsp_hw_sta.patch
    net-wireless-ath9k-Trivial-fix-in-Kconfig.patch
    net-wireless-ath9k-Update-beacon-RSSI.patch
    hwmon-asus_atk0110-Enable-the-EC.patch
    input-sentelic-use-strict_strtoul.patch
    net-wireless-ath9k-downgrade-assert-in-rc.c-for-invalid-rate.patch
    input-sentelic-remove-batch-register-access.patch
    net-wireless-ath9k-Do-a-full-reset-for-AR9280.patch
    input-sentelic-remove-acceleration-handling.patch
    input-various-fixups-to-Sentelic-driver.patch
    net-wireless-ath9k-fix-misplaced-semicolon-on-rate-control.patch
    net-wireless-ath9k-remove-unnecessary-STATION-mode-check.patch
    net-wireless-ath9k-Fix-bug-in-PCI-resume.patch
    net-wireless-ath9k-downgrade-ASSERT-in-ath_clone_txbuf.patch
    net-wireless-ath9k-Fix-bug-in-ANI-channel-handling.patch
    net-wireless-ath9k-Fix-read-buffer-overflow.patch
    input-add-new-driver-for-Sentelic-Finger-Sensing-Pad.patch
    net-wireless-ath9k-claim-irq-for-ath9k-not-ath-for-pci.patch
    net-wireless-ath9k-do-not-stop-the-queues-in-driver-stop.patch
    net-wireless-ath9k-Fix-bug-in-retrieving-average-beacon-rssi.patch
    net-wireless-ath9k-stop-ani-when-the-STA-gets-disconnected.patch
    net-wireless-ath9k-Set-HW-state-properly.patch
    net-wireless-ath9k-Manipulate-and-report-the-correct-RSSI.patch
    net-wireless-ath9k-Remove-bogus-assert-in-ath_clone_txbuf.patch
    net-wireless-ath9k-Fix-TX-poll-cancelling.patch
    net-wireless-ath9k-Make-sure-we-configure-a-non-zero-beacon-interval.patch
    net-wireless-ath9k-Fix-TX-hang-issue-with-Atheros-chipsets.patch
    net-wireless-ath9k-Disable-autosleep-feature-by-default.patch
    input-sentelic-fix-setreg-input-handling.patch
    net-wireless-ath9k-differentiate-quality-reporting-between-legacy-and-HT-configurations.patch
    input-sentelic-add-protocol-documentation.patch
    net-wireless-ath9k-Handle-tx-desc-shortage-more-appropriately.patch
    net-wireless-ath9k-Handle-different-TX-and-RX-streams-properly.patch
    net-wireless-ath9k-Fix-RFKILL-bugs.patch
    net-wireless-ath9k-RX-stucks-during-heavy-traffic-in-HT40-mode.patch
- (work in progress)
- Updated to 2.6.32
  * dropped x86-revert-unify-stackprotector-features.patch,
    CONFIG_CC_STACKPROTECTOR_ALL was removed.
  * dropped merged patches:
    kernel-sched-Introduce-SCHED_RESET_ON_FORK-scheduling-policy.patch
    kernel-sched-Clean-up-SCHED_RESET_ON_FORK.patch
    kernel-sched-Add-SCHED_RESET_ON_FORK-functionality-for-nice.patch
    ahci-Add-AMD-SB900-SATA_IDE-controller-device-IDs.patch
    ahci-Add-the-AHCI-controller-Linux-Device-ID-for-NVIDIA-chipsets.patch
    md-raid1-raid10-add-cond_resched.patch
    fs-xfs-bug-in-log-recover-with-quota.patch
    fs-devtmpfs-kernel-maintained-tmpfs-based-dev.patch
    char-mem_class-use-minor-as-index-instead-of-searching-the-array.patch
    char-mem_class-fix-bug.patch
    driver-core-extend-devnode-callbacks-to-provide-permissions.patch
    drivers-media-video-dabusb-extend-devnode-callbacks-to-provide-permissions.patch
    gpu-drm-radeon-kms-add-32-64-ioctl-support.patch
    hwmon-coretemp-Add-Intel-Atom-support.patch
    hwmon-coretemp-Fix-Atom-CPU-support.patch
    hwmon-coretemp-Add-support-for-Penryn-mobile-CPUs.patch
    hwmon-coretemp-Add-Lynnfield-CPU.patch
  * rediffed patches:
    acpi-dsdt-initrd-v0.9c-fixes.patch
  * moved to patches-broken, to be decided if still needed to keep:
    fs-sreadahead-1.0-trace-open.patch
    gpu-drm-i915-add-gem-enable-parameter.patch
- Copy 2.6.32 sources for kernel update.
- Sync fixes from 2010.0 kernel.
- Add comment about usblp for backported kernels.
- Disabled CONFIG_USB_PRINTER (usblp), as cups is now using libusb.
- Prepare to release.

  + Thomas Backlund <tmb@mandriva.org>
    - bttv: add missing i2c addr to probe for ir (A. Williamson / J.Wilson)
    - hostap: Revert a toxic part of the conversion to net_device_ops
      (fixes MDV #55805, KBZ #14000)
    - ppp: enlarge upload buffer to support HSUPA upload speeds
    - xfs: fix bug in recovering logs when using quota
    - wireless: ath9k: fix misplaced semicolon on rate control
    - another missing CVE noted by bogdano
    - add missing CVE, noted by bogdano
    - update to 2.6.31.6 (CVE-2009-3612, CVE-2009-3621)

  + Pascal Terjan <pterjan@mandriva.org>
    - Add samsung backlight driver

* Mon Nov 09 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31.6-0.rc1.1mnb2
+ Revision: 463578
- Update to 2.6.31.6-rc1
  * dropped pci-increase-alignment-to-make-more-space-for-hidden-code.patch
    (merged)
- Fix changelog typo.
- Choose gzip vmlinux compression for all kernels with xen enabled.
- Choose gzip instead of lzma for kernel-server's vmlinux
  compression, to allow xen to load it (#54775).
- Apply "jme: Fix unmatched tasklet_{enable|disable} pair" jme bug fix
  from later kernels.

  + Anssi Hannula <anssi@mandriva.org>
    - include btcx-risc.h and bt848.h in kernel-devel, they are now
      required by bttvp.h which is already included and required by
      dkms-lirc-gpio (fixes #54907)

* Fri Oct 23 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31.5-1mnb2
+ Revision: 458997
- Updated to 2.6.31.5
- New release.
- Drop net-wireless-rt2800usb-comment-duplicated-ids.patch, it's broken.
- Don't apply compress-kernel-modules-on-installation.patch only at
  kernel-source build, to avoid its extra options being asked when
  building kernel-source using default configs.
- Fix minor typos.
- Backport "uvcvideo: Handle garbage at the end of streaming
  interface descriptors", fixes bug with newer Bison webcams
  (id 5986:0241).
- Include patch from Claudio Matsuoka with new hda model for HP DC
  series machines with Analog ad1884a codec.

  + Thomas Backlund <tmb@mandriva.org>
    - revert 'x86: unify stackprotector features', and disable
      CC_STACKPROTECTOR_ALL, as it gives unvanted overhead and
      makes atleast xfs blow up some times
      http://marc.info/?l=linux-kernel&m=125614028227106&w=4
    - ahci: Add the generic device ID for NVIDIA AHCI controller

* Sat Oct 17 2009 Thomas Backlund <tmb@mandriva.org> 2.6.31.5-0.rc1.1mnb2
+ Revision: 457987
- rediff disable-mrproper and disable-prepare patches to apply cleanly
- update to 2.6.31.5-rc1
- drop merged patches:
  net-e1000e-jumbo-frames-no-longer-work-Unsupported-MTU-setting.patch
  pci-intel-iommu-Cope-with-broken-BIOS-and-VT-d.patch
  usb-serial-ftdi_sio-remove-tty-low_latency.patch
- fix spacing
- Patch-series from Via to add support for:
  VT1702B-CE, VT1716S, VT1718S,VT1812, VT1828S, VT2002P, VT2020.
  Also merged in upstream alsa tree as of 2009-10-15
- hwmon: add Asus P7P55D support to asus_atk0110
- update to 2.6.31.4 final
- drop  merged patches:
  revert-kvm-svm-fix-tsc-offset-adjustment-when-running-nested.patch
  kvm-svm-fix-tsc-offset-adjustment-when-running-nested.patch
- pci: increase alignment to make more space for hidden code (#54137)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Added atkbd quirk to report release events for mute, volume up and
      volume down keys on Positivo I30.
    - Prepare to release.
    - Drop alsa-pulse dir from patches-broken, not relevant anymore for
      cooker/2010.0
    - Enable 6pack hamradio driver on i386 configs (#32808).

* Mon Oct 12 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31.4-0.rc2.1mnb2
+ Revision: 456700
- Prepare to release, updated/fixed
  kvm-svm-fix-tsc-offset-adjustment-when-running-nested.patch
- Small adjustment to allow the package to be released as backports
  for older distro versions.

  + Thomas Backlund <tmb@mandriva.org>
    - revert "KVM: SVM: Fix tsc offset adjustment when running nested"
      from stable 2.6.31.4-rc2 as it breaks the build as noticed on LKML.
    - update to 2.6.31.4-rc2 (CVE-2009-2903)
    - minor cleanups
    - really disable -debug rpms for backports
    - kernel-source: compress modules at 'make modules_install' time,
      as it saves space for those building their own kernels (#54028)
    - dont create -debug rpms by default when backporting
    - e1000e: fix jumbo frame support (kernel bz #14261)
    - wireless ath9k: redo patches and add additional ones based on
      fixes merged in 2.6.32-rc1 (closes #52739)
    - update to 2.6.31.2 final

  + Pascal Terjan <pterjan@mandriva.org>
    - update to 2.6.31.3
    - add hctosys sysfs attribute

* Sat Oct 03 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31.2-0.rc1.1mnb2
+ Revision: 453187
- Fix bug introduced by the change for 2.6.31.2-rc1 "[CPUFREQ] Fix
  NULL ptr regression in powernow-k8"
  Reference: http://lkml.org/lkml/2009/10/3/121
- One more last change:
  Apply ftdi_sio usb serial driver tty->low_latency fix from
  http://patchwork.kernel.org/patch/49918/
- Prepare to release.
- Backport Prolink SBTVD DVB adapter support from mainline.
  SBTVD == http://en.wikipedia.org/wiki/SBTVD
- Apply two fixes from acpi upstream tree scheduled to 2.6.31.x
  stable series:
  ACPI: fix Compaq Evo N800c (Pentium 4m) boot hang regression
  ACPI: Clarify resource conflict message
- Added support to spec to build "stable-review" kernels.
- Updated to 2.6.31.2-rc1
  * dropped driver-core-add-new-device-to-bus-s-list-before-prob.patch
    (merged)
- Add acerhk back, there are still Acer laptops not supported by
  acer-wmi. Reference:
  http://lists.mandriva.com/kernel-discuss/2009-09/msg00036.php
- Staging: rtl8187se/rtl8192su: allow module unload.
- Enable CONFIG_RTC_HCTOSYS and CONFIG_RTC_DRV_CMOS=y, as Mandriva
  userspace will now support this configuration.

  + Thomas Backlund <tmb@mandriva.org>
    - fix typo in changelog
    - replace Intel Lynnfield coretemp patch with patch merged upstream
    - add Intel Mobile Penryn support in coretemp
    - replace Intel Atom coretemp patch with patches merged upstream
    - clean ndiswrapper tarball (remove headers generated at buildtime)

* Fri Sep 25 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31.1-1mnb2
+ Revision: 449177
- Apply "Driver core: add new device to bus's list before probing"
  upstream change from mainline (commit 2023c61), fixes race with
  udev/user programs in some cases.
- Prepare to release.
- Regenerated configs.
- Disable otus staging driver: ar9170 in wireless tree should
  already handle it. Also Kconfig otus description states that it
  needs a special wpa_supplicant.
- Apply SCHED_RESET_ON_FORK scheduling policy flag addition from
  mainline. Reference:
  http://lists.mandriva.com/kernel-discuss/2009-09/msg00006.php
- Apply upstream commit 70ba2a3 "drm/radeon/kms: add 32/64 ioctl
  support". Only affects radeon with kms enabled. Reference:
  http://lists.mandriva.com/kernel-discuss/2009-09/msg00002.php
- Disable build of aedsp16 oss driver: the snd-sc6000 alsa driver
  should now handle all support for same cards it supports, as
  stated in kernel changelog.
- pwc: fix driver name shown in /proc/bus/devices and /sys, remove
  display of list of device names supported in kernel log, from
  Thierry Vignaud.
- rtc_cmos: avoid oops when ioctl RTC_AIE*/RTC_UIE* is done on /dev/rtc*
  right after it's created.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.31.1
    - driver core: extend devnode callbacks to provide permissions
    - add Intel Lynnfield (i5/i7) support in coretemp
    - add back atom coretemp hwmon support that got removed by mistake
      in the 2.6.31 rebase
    - fix build warnings when building without source/debug/devel/doc rpms

  + Pascal Terjan <pterjan@mandriva.org>
    - Add upstream quirks for HP dv5/dv6 laptops (#53858)

* Mon Sep 14 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-2mnb2
+ Revision: 440325
- More topstar-laptop updates (linux-acpi review).
- Prepare to release.

  + Thomas Backlund <tmb@mandriva.org>
    - Add AMD SB900 SATA/IDE controller device IDs
    - disable radeon kernel modesetting again as it breaks too many systems

* Thu Sep 10 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-1mnb2
+ Revision: 437168
- Prepare to release.
- Updated platform-x86-add-topstar-laptop-driver.patch with latest
  version.

  + Thomas Backlund <tmb@mandriva.org>
    - enable kernel modesetting by default when using radeon driver
    - update to 2.6.31 final

* Mon Sep 07 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc9.1mnb2
+ Revision: 432982
- Prepare to release.
- Add new topstar-laptop driver with support for hotkeys on Topstar N01.

  + Anssi Hannula <anssi@mandriva.org>
    - enable kernel modesetting by default when using nouveau driver

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.31-rc9
    - drop merged patches:
      fs-inotify-do-not-send-a-block-of-zeros-when-no-pathname-is-available.patch
      fs-inotify-fix-length-reporting-and-size-checking.patch
      fs-inotify-update-the-group-mask-on-mark-addition.patch

  + Pascal Terjan <pterjan@mandriva.org>
    - fix video-mdk-logo.patch broken in 2.6.31 rebase

* Fri Aug 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc8.1mnb2
+ Revision: 422029
- Integrate latest changes in latest release.
- Prepare to release.

  + Thomas Backlund <tmb@mandriva.org>
    - inotify: update the group mask on mark addition
    - inotify: fix length reporting and size checking
    - fix inotify regresion in -rc8 causing boot hang/failure
    - enable IWLWIFI_DEBUG
    - drop merged patch:
      platform-x86-wmi-stack-corruption.patch
    - update to 2.6.31-rc8

* Wed Aug 26 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc7.4.1mnb2
+ Revision: 421522
- rtl8187: fix circular locking (rtl8187_stop/rtl8187_work).
- rtl8187: Implement rfkill support.
- Updated to 2.6.31-rc7-git4
  * dropped net-wireless-rtl8187-always-set-MSR_LINK_ENEDCA-flag-with-RTL8187.patch
    (merged).
- Made all agp drivers built in (=y).
- rtl8187: always set MSR_LINK_ENEDCA flag with RTL8187B.

  + Thomas Backlund <tmb@mandriva.org>
    - initial fixes for ath9k (#52739)
      downgrade ASSERT in ath_clone_txbuf
      manipulate and report the correct RSSI
      RX stucks during heavy traffic in HT40 mode
      handle tx desc shortage more appropriately
      trivial fix in Kconfig
      update beacon RSSI
      fix bug in PCI resume
      set HW state properly
      fix bug in retrieving average beacon rssi
    - update to 2.6.31-rc7-git1
    - update series file
    - add workaround for broken bioses on vt-d enabled hardware
    - enable CONFIG_ATH5K_DEBUG,CONFIG_ATH9K_DEBUG
    - disable MAC80211_DEFAULT_PS (powersaving) as it's known to cause
      instabilities and performance regressions on wireless drivers
      including iwlwifi and p54.
    - update to 2.6.31-rc7
    - drop merged patches:
      dvb-usb-af9015-fix-crash.patch
      sound-hda-codec-add-Toshiba-Pro-A210-to-quirk-table.patch

* Fri Aug 14 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc6.1mnb2
+ Revision: 416331
- Prepare to release.
- Clarify changelog.
- Include patch with new devtmps from greg's tree.
- Apply patch series to make OSS device number claiming optional,
  Reference: http://lists.mandriva.com/kernel-discuss/2009-08/msg00002.php
- Added "ALSA: pcm - Tell user that stream to be rewound is suspended"
  change from sound tree.
  Reference: http://lists.mandriva.com/kernel-discuss/2009-08/msg00004.php
- Enabled (=y): CONFIG_FTRACE, CONFIG_FUNCTION_TRACER, CONFIG_BOOT_TRACER,
  CONFIG_SYSPROF_TRACER, CONFIG_SCHED_TRACER, CONFIG_FTRACE_SYSCALLS,
  CONFIG_POWER_TRACER, CONFIG_STACK_TRACER, CONFIG_BLK_DEV_IO_TRACE,
  CONFIG_DYNAMIC_FTRACE, CONFIG_FUNCTION_PROFILER.
- Enabled (=m): CONFIG_RING_BUFFER_BENCHMARK.
- Enabled (=y) CONFIG_MMIOTRACE, reference:
  http://lists.mandriva.com/kernel-discuss/2009-08/msg00005.php
- Enable i915 KMS by default.
- Fix digital mic recording noise with ALC268 in auto config model, when
  only one digital mic input is available.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.31-rc6
    - drop acerhk from 3rdparty. everything it does is now supported by
      acer-wmi and the userspace rfkill utility
    - update nouveau to 2009-08-12 snapshot
    - update to 2.6.31-rc5-git9
    - update to 2.6.31-rc5-git5
      - rediff patch:
        gpu-drm-i915-add-gem-enable-parameter.patch
      - drop merged patches:
        net-core-dev-lockdep-fix.patch
        gpu-drm-git-fixes.patch

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - Enabled perf-counters

* Fri Aug 07 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc5.3.1mnb2
+ Revision: 411301
- Prepare to release.
- Add Sentelic touchpad support, from Dmitry Torokhov's input tree.

  + Thomas Backlund <tmb@mandriva.org>
    - sync defconfigs
    - net: core dev lockdep fix
    - drm: add radeon rs880 pci ids, radeon kms TTM patch, radeon kms suspend/resume fix
    - update nouveau to 2009-08-07 snapshot
    - update to 2.6.31-rc5-git3

* Sun Aug 02 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc5.2mnb2
+ Revision: 407512
- New release.

  + Thomas Backlund <tmb@mandriva.org>
    - rediff patch to apply cleanly
    - fix crash in dvb-usb-af9015
    - update nouveau to 20090801 git snapshot
    - drop nouveau buildfix

* Sat Aug 01 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc5.1mnb2
+ Revision: 405330
- Prepare to release.
- unionfs: use atomic_long_read when reading struct file f_count
  field (f_count is atomic_long_t).

  + Thomas Backlund <tmb@mandriva.org>
    - fix series
    - update to 2.6.31-rc5
      - drop merged patches:
        usb-serial-option-add-ZTE-device-ids-and-remove-ONDA-ids.patch
        net-rfkill-fix-rfkill_set_states-to-set-the-hw-state.patch
        platform-x86-acer-wmi-rfkill-reversion.patch
      - add patches:
        fix nouveau build with 2.6.31-rc5
      - update defconfigs

* Tue Jul 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.31-0.rc4.1mnb2
+ Revision: 402385
- Prepare to release.
- rt2800usb: disable temporarily usb ids that clash with rt2870sta
  module in staging.
- Enabled (=y): CONFIG_PCIE_ECRC.
- Enabled (=m): CONFIG_USB_SERIAL_QUATECH2, CONFIG_RDC_17F3101X,
  CONFIG_FB_UDL.
- Disabled on 2.6.31 default configs: CONFIG_CAN_SJA1000_PLATFORM,
  CONFIG_KEYBOARD_MATRIX, CONFIG_KEYBOARD_LM8323,
  CONFIG_BATTERY_MAX17040, CONFIG_LEDS_LP3944
  They shouldn't be needed by default pc/x86 hardware.

  + Thomas Backlund <tmb@mandriva.org>
    - fix dell-laptop rfkill state change logic
    - I forgot the changelog...
    - Character device in Userpace support (CUSE)
    - fix changelog
    - export find_task_by_vpid symbol again, needed for Ati fglrx
    - rename patch as it only adds A210 support now
    - update defconfigs
    - dont obsolete dkms-nouveau
    - add nouveau support (and obsolete dkms-nouveau)
    - fix reversed rfkill on acer-wmi
    - fix rfkill_set_states to set the hw state
    - make hid-ntrig not detect HID_DG_INRANGE as TOUCH (O. Thauvin)
    - fix mach64 build with 2.6.31
    - fix ndiswrapper build with 2.6.31
    -rediff patches:
        acpi-dsdt-initrd-v0.9c-fixes.patch
        fs-dynamic-nls-default.patch
        fs-sreadahead-1.0-trace-open.patch
        gpu-drm-i915-add-gem-enable-parameter.patch
        gpu-drm-mach64.patch
        input-atkbd-philco-i4xsi-release-keys.patch
        net-sis190-fix-list-usage.patch
        scsi-ppscsi-2.6.2.patch
        serial-docomo-F2402.patch
        sound-hda-codec-add-Toshiba-Pro-A200-A210-to-quirk-table.patch
        usb-serial-option-add-ZTE-device-ids-and-remove-ONDA-ids.patch
        video-mdk-logo.patch
    - drop merged patches:
        gpu-drm-i915-hook-connector-to-encoder-during-load-detect.patch
        hwmon-coretemp-atom.patch
        input-appletouch.patch
        input-wacom-intuos4.patch
        media-video-uvc-workaround-invalid-formats.patch
        mmc-add-VIA-MSP-card-reader-driver-support.patch
        serial-8250_pci-add-OXCB950-id.patch
        sound-alsa-hda-add-acer-alc889-model.patch
        sound-alsa-hda-add-quirk-for-STAC92xx-SigmaTel-STAC9205.patch
        usb-dlink-dwm652.patch
        usb-option.c-add-a-link-3gu-device-id.patch
    - update to 2.6.31-rc4

* Mon Jul 20 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.30.2-1mnb2
+ Revision: 398203
- Prepare to release 2.6.30.2-1mnb
- USB: option: add ZTE device ids and remove ONDA ids.
- usb: Added A-Link 3GU device id 1e0e:9200 into option driver, from
  Anssi Hannula.
  Reference: http://lists.mandriva.com/kernel-discuss/2009-07/msg00003.php
- Fix patch changelog.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.30.2 (CVE-2009-1895, CVE-2009-1897)

* Sun Jul 05 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.30.1-1mnb2
+ Revision: 392406
- Prepare to release.
- Enable drbd only in server kernels.
- Remove comment from drbd Kconfig.
- Restore 3rd-ndiswrapper-dma_addr_t-print-warn-fix.patch, not merged,
  and fix its changelog.
- Added atkbd quirk to report release events for mute, volume up and
  volume down keys on Philco I4xSI.
- ALSA, hda: Apply upstream patch with STAC9205 new id 0x83847698
  (#41385). Fixed quirk section mismatch.

  + Thomas Backlund <tmb@mandriva.org>
    - update ndiswrapper to 1.55
      - rediff patch:
        3rd-ndiswrapper-Makefile-build-fix.patch
      - drop merged patches:
        3rd-ndiswrapper-dma_addr_t-print-warn-fix.patch
        3rd-ndiswrapper-irqreturn-warn-fix.patch
        3rd-ndiswrapper-missing-ndo-fix.patch
    - update drbd to 8.3.2
      - redo patches:
        3rd-drbd-makefile-fix.patch
        3rd-drbd-build-fixes.patch
      - add patch:
        3rd-drbd-usermode_helper.patch
    - update to 2.6.30.1
      - drop merged patches:
        sound-intel8x0-fix-sound-skipping-introduced-in-2.6.30-rc8.patch

* Thu Jun 18 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.30-2mnb2
+ Revision: 387222
- Prepare to release.
- Include WMI stack corruption fix from Arch Linux
  Reference: http://bbs.archlinux.org/viewtopic.php?id=73877
- Include tv/vga load-detect fix for drm/i915 from mainline
  Reference: http://lists.mandriva.com/cooker/2009-06/msg00323.php
- Disabled CONFIG_COMEDI_PCI_DRIVERS. At least one module built with
  it enabled (s626) claims the pci id 1131:7146 for all subvendors
  and subdevice ids. The problem is that this will clash with many
  media/dvb cards that have the same main pci vendor and device ids,
  but properly specify/check subvendor and subdevice ids. For now
  just disable comedi pci drivers, in this specific case s626
  probably would need a specific subvendor/subdevice restriction in
  its pci id table or additional checks to avoid freezing when it is
  loaded on media/dvb cards with same vendor:device pci id. (#51314)

  + Thomas Backlund <tmb@mandriva.org>
    - fix intel8x0 sound skipping introduced in 2.6.30-rc8
      (http://marc.info/?l=linux-kernel&m=124465853625485&w=2)

* Fri Jun 12 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.30-1mnb2
+ Revision: 385377
- Update media-video-uvc-workaround-invalid-formats.patch with
  upstream final solution from Laurent Pinchart, "uvcvideo: Ignore
  non-UVC trailing interface descriptors".
- Unset CONFIG_UEVENT_HELPER_PATH, installer was adapted to not need
  this set in kernel config.
- Move gpu-drm-i915-disable-gem-on-i8xx.patch to patches-broken:
  reevaluate the situation after the last drm/i915 fixes that went
  in 2.6.30
- apply_patches: cosmetic line break.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.30 final

* Thu Jun 04 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.30-0.rc8.1mnb2
+ Revision: 382601
- Updated to 2.6.30-rc8
  * dropped security-tomoyo-call-cap_bprm_set_creds.patch (merged)
- comment patch in series file.
- uvcvideo: workaround invalid formats exposed by buggy uvc webcams.
- Switch to CONFIG_SND_DEBUG=y and CONFIG_SND_PCM_XRUN_DEBUG=y in kernel
  configs.

* Tue May 26 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.30-0.rc7.1mnb2
+ Revision: 379728
- Add missing patch to series file.
- Prepare to release.
- Renamed (added back since this is not merged)
  security-tomoyo-change-boot-message-to-be-more-user-friendly.patch
  to security-tomoyo-friendly-ccs_loader-msg.patch; rebased to 2.6.30,
  changed boot message and use printk_once instead of printk
- Add missing call to cap_bprm_set_creds in tomoyo.
- Updated ndiswrapper to version 1.54
  * Added following warning/build fixes on top:
    3rd-ndiswrapper-dma_addr_t-print-warn-fix.patch
    3rd-ndiswrapper-missing-ndo-fix.patch
    3rd-ndiswrapper-irqreturn-warn-fix.patch
  * Dropped merged 3rd-ndiswrapper-wext_compat_2.6.27.patch
- Rediff/fix:
  disable-mrproper-in-devel-rpms.patch
  disable-prepare-scripts-configs-in-devel-rpms.patch
- Don't allow -devel mrproper patches to be applied if fuzz factor
  is greater than zero in some hunk.
- Updated to 2.6.30-rc6
  * Redid/rediff following patches:
    hid-usbhid-quirk-multilaser.patch
    net-netfilter-psd.patch
    fs-sreadahead-1.0-trace-open.patch
    input-wacom-intuos4.patch
    acpi-dsdt-initrd-v0.9c-2.6.28.patch
    sound-alsa-hda-add-acer-alc889-model.patch
    acpi-dsdt-initrd-v0.9c-fixes.patch
    x86-p4_clockmod-reasonable-default-for-scaling_min_freq.patch
    usb-dlink-dwm652.patch
    fs-unionfs-1.4.patch
    fs-dynamic-nls-default.patch
    gpu-drm-i915-add-gem-enable-parameter.patch
    net-netfilter-IFWLOG.patch
    acpi-add-proc-event-regs.patch
    serial-docomo-F2402.patch
    3rd-drbd-build-fixes.patch
  * Removed merged fixes/additions (same patch or another solution):
    mmc-Increase-power_up-delay-to-fix-TI-readers.patch
    fs-ext4-add-EXT4_IOC_ALLOC_DA_BLKS-ioctl.patch
    fs-ext4-Automatically-allocate-delay-allocated-blocks-on-close.patch
    fs-ext4-Automatically-allocate-delay-allocated-blocks-on-rename.patch
    gpu-drm-radeon-r6xx-r7xx.patch
    gpu-drm-i915-no-gem-if-no-tiling.patch
    input-elantech-provide-workaround-for-jumpy-cursor.patch
    media-dvb-add-Yuan-PD378S.patch
    rtc-cmos.c-fixed-alias.patch
    net-mac80211-deauth-before-flushing-STA-information.patch
    net-wireless-fix-rt2x00-double-free.patch
    sound-alsa-hda-consider-additional-capsrc-alc889.patch
    sound-alsa-hda-alc882_auto_init_input_src-selector.patch
    sound-alsa-add-subdevice_mask-field-to-quirk-entries.patch
    sound-alsa-hda-92hd71xxx-disable-unmute-support-for-code.patch
    sound-alsa-hda-Additional-pin-nids-for-STAC92HD71Bx-and.patch
    sound-alsa-hda-Dynamic-detection-of-dmics-dmuxes-smuxes.patch
    sound-alsa-hda-Don-t-call-stac92xx_parse_auto_config-wi.patch
    sound-alsa-hda-Don-t-touch-non-existent-port-f-on-4-por.patch
    sound-alsa-hda-fix-speaker-output-on-hp-dv4-1155-se.patch
    sound-alsa-hda-cleanup-idt92hd7x-hp-quirks.patch
    sound-alsa-hda-cleanup-ecs202-quirks.patch
    sound-alsa-hda-Add-4-channel-mode-for-3stack-hp-model.patch
    sound-alsa-hda-Add-headphone-automute-support-for-3stac.patch
    sound-alsa-hda-Map-3stack-hp-model-ALC888-for-HP-Educ.patch
    sound-alsa-hda-Cleanup-printk-from-alc888_6st_dell_unso.patch
    video-n411-add-missing-Makefile-entry.patch
    staging-agnx-mac80211-hw-config-change-flags.patch
    staging-rtl8187se-iw_handler-fixes.patch
    security-tomoyo-1.6.7-20090401.patch
    security-tomoyo-build.patch
    security-tomoyo-change-boot-message-to-be-more-user-friendly.patch
  * Moved sound-hda-codec-add-Sony-Vaio-VGN-FZ18M-to-quirk-table.patch
    to patches-broken, the used Vaio quirk was removed.
  * Moved uss725 patches to patches-broken: even fixing some issues
    previously, uss725 isn't working properly from reports received,
    not sure if worked well some point back in time. Stop carrying
    the patches and deprecate them.
  * Moved x86-UBUNTU-SAUCE-fix-kernel-oops-in-VirtualBox-during.patch
    to patches-broken, doesn't apply, possibly not wanted anymore.
  * Added patches with build fixes:
    fs-unionfs-use-current_umask-helper.patch
    3rd-acerhk-proc_dir_entry-owner.patch
- Include drivers/ieee1394 headers for dkms-v4l-dvb-testing
  (http://lists.mandriva.com/cooker/2009-05/msg00534.php)

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.30-rc7
      * rediffed the following:
        acpi-add-proc-event-regs.patch
        sound-hda-codec-add-Toshiba-Pro-A200-A210-to-quirk-table.patch
      * drop the following merged patches:
         sound-oss-mixer-name.patch
    - update defconfigs
    - update to 2.6.29.4

* Wed May 13 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.3-1mnb2
+ Revision: 375509
- Update to 2.6.29.3
  * rediff usb-storage-unusual_devs-add-id.patch

* Wed May 06 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.2-1mnb2
+ Revision: 372639
- Update to 2.6.29.2
  * removed merged patches:
    x86-platform-acer-wmi-Blacklist-Acer-Aspire-One.patch
    mm-define-a-UNIQUE-value-for-AS_UNEVICTABLE-flag.patch

* Mon Apr 20 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.1-4mnb2
+ Revision: 368469
- Prepare to release take 2
- Back out addition of alsa patches intended for pulseaudio
  enhancements since it's causing regressions (#50120).
- Fixed rpm group of debug packages.

  + Pascal Terjan <pterjan@mandriva.org>
    - Release 2.6.29.1-4mnb
    - Drop sound-alsa-pcm-midlevel-Add-more-strict-buffer-position-checks-based-on-jiffies.patch, it breaks sound in VirtualBox

* Thu Apr 16 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.1-3mnb2
+ Revision: 367711
- Fix changelog date.
- Added patch scheduled for stable 2.6.29.x: "mm: define a UNIQUE
  value for AS_UNEVICTABLE flag".
- Blacklist acer-wmi on Acer Aspire One, upstream patch scheduled
  for -stable.
- More upstream ALSA patches which should help in pulseaudio issues.
- Minor WARN redefine fix in heci 3rdparty driver.
- Changelog fix.
- Added back gem_enable parameter to i915 module in case someone still
  needs it to workaround issues with gem.
- i915: disable gem automatically also for i8xx hardware, patch from
  Fedora.
  Reference: http://lists.mandriva.com/cooker/2009-04/msg00577.php

  + Pascal Terjan <pterjan@mandriva.org>
    - Add another upstream ALSA patch
    - Add some upstream ALSA fixes to fix some of the pulseaudio issues

* Sat Apr 11 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29.1-2mnb2
+ Revision: 365943
- Prepare to release.
- rt2x00: prevent double kfree when failing to register hardware
  (#46710).
- Enable and select minstrel as default mac80211 rate control (should
  behave better than previous pid, 2.6.29 default).
- Drop unset of CONFIG_UEVENT_HELPER_PATH, needed by installer.
- Disable gem automatically if it's not possible to do tiled
  rendering, fixes 3d performance regression on some intel i945
  based machines. Fix/patch made by Ander Conselvan de Oliveira.
  With this remove previous gem_enable parameter added to i915,
  obsolete by this solution.
- Unset CONFIG_UEVENT_HELPER_PATH, this shouldn't be needed anymore.

  + Pascal Terjan <pterjan@mandriva.org>
    - Add forgotten part of previous patch
    - Hide unused interface in option for D-Link DWM-652 and ensure it is ignored by usb-storage when in modem mode
    - Disable CONFIG_AES2501 (#40523)

* Tue Apr 07 2009 Pascal Terjan <pterjan@mandriva.org> 2.6.29.1-1mnb2
+ Revision: 364926
- Add support for D-Link DWM 652 3G modem
- Add support for Wacom Intuos 4 tablets

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Prepare to release.
    - Refresh gpu-drm-radeon-r6xx-r7xx.patch with change "drm/radeon: load
      the right microcode on rs780".
    - Updated ipset to 2.4.9 (matches current userspace on cooker, and fixes
      oops when running ipset tests).
    - Some fixes to acpi-dsdt-initrd-v0.9c-2.6.28.patch
    - Removed already applied patches:
      net-sis190-sis966.patch (similar fix merged)
      net-bluetooth-fix-oops-in-l2cap_conn_del.patch
      net-bluetooth-fix-esco-sync.patch (similar fix merged)
    - scripts/apply_patches: use --fuzz=0 for patch (same default as for
      general distro packages).
    - Rediffed all fuzzy patches. Some styling/trailing spacing removal
      fixes were done too.
    - Drop x86-cpufreq-e_powersaver-print-voltage-mult-only-in-debug.patch,
      stick with upstream default after change "[CPUFREQ] Remove
      debugging message from e_powersaver".
    - Renamed acpi-CELVO-M360S-disable_acpi_irq.patch to
      acpi-CLEVO-M360S-disable_acpi_irq.patch, and rediffed.
    - Removed unecessary patches:
      net-bonding-alias.patch (possible easter egg? :-) )
      usb-use-old_scheme_first.patch
    - Updated acpi-dsdt-initrd patch with enhanced (with fixes) version.
      (version v0.9c-2.6.28)
    - Removed already applied input-add-dell-xps-m1530-nomux-quirk.patch
    - Add via card reader support (sd/mmc only) v5 patch from Joseph Chan.
    - Removed pat cleanup (new vm flag to track full pfnmap at mmap), keep
      with 2.6.29 stable series default.
    - elantech: apply upstream patch with workaround for jumpy cursor on
      firmware 2.34
    - Regenerate configs.
    - Refresh gpu-drm-radeon-r6xx-r7xx.patch with additional commit that
      adds RS780 new pci ids.
    - Added parameter gem_enable to i915, based on patch/idea posted by
      Vasily Khoruzhick, for more information see following bug report:
      http://bugs.freedesktop.org/show_bug.cgi?id=16835
    - Tomoyo update to 1.6.7-20090401
    - Disabled CONFIG_USB_GADGET on configs where it was enabled.
    - Disabled CONFIG_WIRELESS_OLD_REGULATORY on all configs.
    - Enabled CONFIG_X86_GENERICARCH for all i386 configs, as we set
      NR_CPUS=32 (reported by Pascal Terjan).
    - Included x86 pat fixes, should fix problems reported at kernel.org
      bug #12800, and fixes virtualbox regression without the workaround
      setting VBOX_USE_INSERT_PAGE=1
      Reference: http://www.virtualbox.org/ticket/3403
    - Added bug fix for network stuck issue in 2.6.29 final
      Reference: http://marc.info/?l=linux-kernel&m=123789980524715&w=2
    - Regenerate configs.
    - Updated to 2.6.29
      * dropped following merged patches:
        fs-ext4-fix-header-check-in-ext4_ext_search_right-fo.patch
        fs-ext4-Print-the-find_group_flex-warning-only-once.patch
    - Backported r6xx/r7xx support from drm-next tree.

  + Thomas Backlund <tmb@mandriva.org>
    - doh! add drbd tarball too
    - alsa is 1.0.19
    - update drbd to 8.3.1
    - update to 2.6.29.1

* Wed Mar 18 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29-0.rc8.3.1mnb2
+ Revision: 357368
- Updated to 2.6.29-rc8-git3
- typo fix.
- Select default CONFIG_SCTP_HMAC_MD5 on all configs (instead of
  CONFIG_SCTP_HMAC_NONE currently selected).
- Disabled CONFIG_SYS_DEPRECATED* on all configs, report/reference:
  http://lists.mandriva.com/kernel-discuss/2009-03/msg00036.php
- Disabled CONFIG_USB_DEVICE_CLASS on all configs, report/reference:
  http://lists.mandriva.com/kernel-discuss/2009-03/msg00037.php)
- Rediff main uss725 patch, fixes In-System Design USS725 USB/IDE probe
  error reported by Sergio Monteiro Basto.

* Fri Mar 13 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29-0.rc8.1mnb2
+ Revision: 354635
- Included following ext4 fixes from Theodore Ts'o git tree:
  * Fixes for 2.6.29-rcX:
  ext4: fix header check in ext4_ext_search_right() for deep extent trees
  ext4: Print the find_group_flex() warning only once
  * ext4+delayed allocation issues solution (reference:
  http://thunk.org/tytso/blog/2009/03/12/delayed-allocation-and-the-zero-length-file-problem/)
  ext4: add EXT4_IOC_ALLOC_DA_BLKS ioctl
  ext4: Automatically allocate delay allocated blocks on close
  ext4: Automatically allocate delay allocated blocks on rename
- Updated to 2.6.29-rc8
- Enabled (=y) on all kernel configs: CONFIG_IPV6_ROUTER_PREF,
  CONFIG_IPV6_ROUTE_INFO, CONFIG_IPV6_OPTIMISTIC_DAD,
  CONFIG_IPV6_MROUTE, CONFIG_IPV6_PIMSM_V2.
- Enabled CONFIG_TCP_MD5SIG on server kernels.
- Enabled (=y) on all kernel configs: CONFIG_CPU_FREQ_STAT_DETAILS.
- Enabled cpufreq options on powerpc config.
- mac80211: deauth before flushing STA information.
  (handles mac80211 userspace notification issue when interface goes
  down pointed at ticket #43441).

* Wed Mar 11 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29-0.rc7.4.1mnb2
+ Revision: 353590
- Updated to 2.6.29-rc7-git4
- Enabled (=y) on i386/x86_64 configs: CONFIG_PM_DEBUG,
  CONFIG_PM_TRACE_RTC.
- Enabled (=y) on x86_64 config: CONFIG_DIRECT_GBPAGES.
- Enable Xen guest support by default when available.
- create_configs: cleanup unused/gone config options, cosmetics,
  enable xen when available (not only when customizing options for
  server kernel).
- Updated to 2.6.29-rc7-git1
- Turn on DEVPTS_MULTIPLE_INSTANCES for server kernels.
- Updated to 2.6.29-rc7
  * dropped w1-slaves-ds2431-kbuild.patch (merged)
- Fixes/enhancements for HP Educ.ar machine/alc888 3stack-hp model:
  * Added additional 4 channel mode
  * Added headphone automute support
  * Map 3stack-hp model (ALC888) for HP Educ.ar
- ALSA: hda - Cleanup printk from alc888_6st_dell_unsol_event
- Only enable namespaces support for server config.
- Only enable (=m) virtual ethernet pair device and MAC-VLAN for
  server config.
- Enabled (=m) on sparc config: CONFIG_SND_MTPAV, CONFIG_SND_PORTMAN2X4,
  CONFIG_SND_SERIAL_U16550.
- Enable group cpu scheduler, switch to cgroup scheduler on server
  config.
- Disabled on all configs: CONFIG_FB_METRONOME.
- Disabled on i386/x86_64 configs: CONFIG_FB_VIRTUAL.
- Disabled on i386/sparc/x86_64 configs: CONFIG_FB_S1D13XXX.
- Enabled (=y) on i386 config: CONFIG_FB_HGA_ACCEL.
- Disabled on x86_64 config: CONFIG_FB_HGA.
- Disabled on i386/x86_64 configs: CONFIG_FB_N411, CONFIG_FB_HECUBA.
- n411: add missing Makefile entry.
- Enabled (=m) on i386 config: CONFIG_EFI_VARS.
- Enabled (=y) on i386 config: CONFIG_EFI, CONFIG_FB_EFI.
- Disabled on all configs: CONFIG_LCD_PLATFORM.
- Disabled on sparc/powerpc configs: CONFIG_LCD_CLASS_DEVICE.
- Enabled (=m) on i386 config: CONFIG_FB_ARC.
- Disabled on i386/powerpc/x86_64 configs: CONFIG_USB_GPIO_VBUS,
  CONFIG_USB_OTG_UTILS.
- Disabled on all configs: CONFIG_UIO_PDRV, CONFIG_UIO_PDRV_GENIRQ,
  CONFIG_UIO_SMX.
- Enabled (=y) on all configs: CONFIG_SERIAL_8250_RSA.
- Enabled (=y) on sparc config: CONFIG_SERIAL_8250_EXTENDED,
  CONFIG_SERIAL_8250_SHARE_IRQ.
- Disabled on all configs: CONFIG_RTC_DRV_TEST, CONFIG_RTC_DRV_X1205.
- Disabled on i386/x86_64 configs: CONFIG_RTC_DRV_V3020.
- Disabled CONFIG_RTC_DRV_STK17TA8
- Disabled CONFIG_RTC_DRV_S35390A
- Disabled on i386/sparc/x86_64 configs: CONFIG_RTC_DRV_RS5C372,
  CONFIG_RTC_DRV_RX8581.
- Disabled on sparc/powerpc configs: CONFIG_RTC_INTF_PROC.
- Disabled CONFIG_RTC_DRV_PCF8583
- Disabled on i386/sparc/x86_64 configs: CONFIG_RTC_DRV_PCF8563.
- Disabled CONFIG_RTC_DRV_M48T86, CONFIG_RTC_DRV_MAX6900.
- Disabled on i386/powerpc/x86_64 configs: CONFIG_RTC_DRV_M48T59.
- Disabled CONFIG_RTC_DRV_M48T35
- Disabled on i386/sparc/x86_64 configs: CONFIG_RTC_DRV_M41T80.
- Enabled (=m) on sparc config: CONFIG_VIDEO_WM8775.
- Enabled (=m) on sparc/powerpc configs: CONFIG_VIDEO_CX88*,
  CONFIG_RTC_DRV_ISL1208.
- Disabled CONFIG_RTC_DRV_FM3130
- Disabled on i386/x86_64 configs: CONFIG_RTC_DRV_DS1742.
- Enabled (=m) on powerpc config: CONFIG_RTC_DRV_DS1742.
- Disabled on all kernel configs: CONFIG_RTC_DRV_DS1511,
  CONFIG_RTC_DRV_DS1672.
- Disabled on i386/x86_64 configs: CONFIG_RTC_DRV_DS1553.
- Disabled on i386/x86_64 configs: CONFIG_RTC_DRV_DS1307.
- Enabled (=m) on powerpc config: CONFIG_RTC_DRV_DS1307.
- Disabled on i386/sparc/x86_64 configs: CONFIG_RTC_DRV_DS1374.
- Disabled CONFIG_RTC_DRV_DS1286
- Enabled (=y) on sparc/powerpc configs: CONFIG_RTC_INTF_DEV_UIE_EMUL.
- Disabled on i386/powerpc/x86_64 configs: CONFIG_RTC_DRV_BQ4802.
- Change from =m to =y CONFIG_RTC_CLASS/CONFIG_RTC_LIB on powerpc
  config.
- Enabled (=y) on i386/x86_64 configs: CONFIG_SONYPI_COMPAT.
- Disabled on all kernel configs: CONFIG_PARPORT_AX88796.
- Enabled (=m) on sparc config: CONFIG_PARPORT_SUNBPP.
- Enabled (=y) on x86_64 config: PARPORT_PC_SUPERIO.
- Disabled on all kernel configs: CONFIG_MTD_PHYSMAP,
  CONFIG_MTD_PLATRAM, CONFIG_MTD_NAND_PLATFORM.

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - Keep Module.symvers as /boot/symvers-$version.gz in order to allow partial
      kernel builds
    --EstaKernelVer linha, e as abaixo, ser?\195?\163o ignoradas--
      M    SPECS/kernel.spec

* Tue Feb 24 2009 Pascal Terjan <pterjan@mandriva.org> 2.6.29-0.rc6.1.1mnb2
+ Revision: 344570
- Release

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.29-rc6-git1
    - update to 2.6.29-rc6
    - add drivers/acpi/acpica header files to -devel rpms, needed by fglrx

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Disabled on all kernel configs: CONFIG_LEDS_GPIO, CONFIG_LEDS_PCA9532,
      CONFIG_LEDS_PCA955X.
    - Enabled on powerpc config: CONFIG_LEDS_TRIGGER_TIMER,
      CONFIG_LEDS_TRIGGER_HEARTBEAT.
    - Disabled on x86_64 config: CONFIG_LEDS_ALIX2.
    - Enabled on sparc config: CONFIG_NEW_LEDS, CONFIG_LEDS_CLASS,
      CONFIG_LEDS_SUNFIRE, CONFIG_LEDS_TRIGGERS*.
    - Disabled CONFIG_KEYBOARD_GPIO, CONFIG_MOUSE_GPIO
    - Disabled CONFIG_BLK_DEV_PLATFORM
    - Disabled on all kernel configs: CONFIG_I2C_GPIO, CONFIG_I2C_OCORES,
      CONFIG_I2C_SIMTEC, CONFIG_I2C_PCA_PLATFORM, CONFIG_I2C_STUB.
    - Disabled on powerpc config: CONFIG_I2C_ISCH.
    - Disabled on sparc config: CONFIG_I2C_ALI1535, CONFIG_I2C_ALI1563,
      CONFIG_I2C_ALI15X3, CONFIG_I2C_AMD756, CONFIG_I2C_AMD8111,
      CONFIG_I2C_I801, CONFIG_I2C_ISCH, CONFIG_I2C_NFORCE2,
      CONFIG_I2C_PIIX4, CONFIG_I2C_SIS5595, CONFIG_I2C_SIS630,
      CONFIG_I2C_SIS96X, CONFIG_I2C_VIA, CONFIG_I2C_VIAPRO.
    - Enabled on powerpc config: CONFIG_COMPUTONE, CONFIG_I2C_VOODOO3.
    - Disabled CONFIG_PATA_PLATFORM
    - Disabled CONFIG_USB_R8A66597_HCD on all configs.
    - Tomoyo build patch update for 2.6.29-rc5

* Fri Feb 20 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29-0.rc5.4.1mnb2
+ Revision: 343308
- Fixed drbd build with BIO_RW_SYNC change after 2.6.29-rc5-git4 update.
- Disabled CONFIG_USB_ISP116X_HCD
- Updated to 2.6.29-rc5-git4
- Disabled CONFIG_USB_C67X00_HCD
- Disabled CONFIG_SOC_CAMERA
- Disabled CONFIG_MFD_WM8400
- Disabled CONFIG_TPS65010
- Disabled CONFIG_MFD_SM501.
- Disabled CONFIG_HTC_PASIC3.
- Disabled on all configs: CONFIG_SENSORS_ADS7828.
- Disabled on powerpc/sparc: CONFIG_HWMON_VID, CONFIG_SENSORS_AD*,
  CONFIG_SENSORS_F718*, CONFIG_SENSORS_F75375S,
  CONFIG_SENSORS_LTC4245, CONFIG_SENSORS_MAX*,
  CONFIG_SENSORS_W83792D, CONFIG_SENSORS_W83L786NG,
  CONFIG_SENSORS_DS1621, CONFIG_SENSORS_I5K_AMB,
  CONFIG_SENSORS_GL5*, CONFIG_SENSORS_IT87, CONFIG_SENSORS_LM*,
  CONFIG_SENSORS_PC87360, CONFIG_SENSORS_SIS5595,
  CONFIG_SENSORS_DME1737, CONFIG_SENSORS_SMS*,
  CONFIG_SENSORS_THMC50, CONFIG_SENSORS_VIA686A,
  CONFIG_SENSORS_W83781D, CONFIG_SENSORS_W83L785TS,
  CONFIG_SENSORS_W83627HF.
- w1: add missing Kconfig/Makefile entries for DS2431 slave driver.
- Disabled CONFIG_W1_MASTER_GPIO, CONFIG_W1_SLAVE_BQ27000,
  CONFIG_W1_SLAVE_DS2760, CONFIG_BATTERY_BQ27x00, CONFIG_BATTERY_DS2760,
  CONFIG_PDA_POWER.
- Disabled CONFIG_MFD_WM8350_I2C
- Disabled CONFIG_SPI
- Disabled on all kernel configs: CONFIG_UCB1400_CORE,
  CONFIG_TOUCHSCREEN_ADS7846, CONFIG_TOUCHSCREEN_WM97XX,
  CONFIG_TOUCHSCREEN_TSC2007.
- Disabled on x86_64 config: CONFIG_TOUCHSCREEN_MK712.
- Disabled on powerpc config: CONFIG_TOUCHSCREEN_TOUCHIT213.
- Enabled (=m) on powerpc config: CONFIG_TOUCHSCREEN_ELO,
  CONFIG_TOUCHSCREEN_MTOUCH, CONFIG_TOUCHSCREEN_PENMOUNT,
  CONFIG_TOUCHSCREEN_TOUCHRIGHT, CONFIG_TOUCHSCREEN_TOUCHWIN.
- Disabled CONFIG_UCB1400_CORE
- Disabled on kernel configs: CONFIG_MDIO_BITBANG, CONFIG_MDIO_GPIO.
- ALSA/hda changes:
  * Include new SND_PCI_QUIRK_MASK and SND_PCI_QUIRK_VENDOR macros,
    cleanup IDT92HD7x HP quirks and backport SND_PCI_QUIRK_MASK
    cleanup for stac922x ecs202 model from alsa tiwai's sound tree.
  * Fix speaker output on HP DV4 1155-SE

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - Enabled CONFIG_MODVERSIONS and CONFIG_MODULE_SRCVERSION_ALL, as a first
      step towards ABI control

* Mon Feb 16 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.29-0.rc5.1mnb2
+ Revision: 341088
- Prepare to release.
- Updated to 2.6.29-rc5
  * dropped sound-alsa-hda-change-hp-dv7-quirk.patch (merged)
- Fixed build with drbd 8.3.0
- Update ipt_set for netfilter/xtables changes in 2.6.29
- Fixed build warnings in agnx and rtl8187se staging drivers.
- ALSA/hda/idt: change HP dv7 (103c:30f4) quirk from hp-m4 to hp-dv5
  model, to fix not working internal microphone. References:
  https://qa.mandriva.com/show_bug.cgi?id=44855#c193
  https://qa.mandriva.com/show_bug.cgi?id=44855#c196
- Updated to 2.6.29-rc4
  * Removed following merged patches:
    x86-cpufreq-add-more-pcore-fsbs.patch
    x86-cpufreq-add-celeron-core-to-p4-clockmod.patch
    char-agp-intel-agp-add-support-for-G41-chipset.patch
    fs-squashfs3.4.patch
    fs-squashfs3.4-2.6.28.patch
    media-video-uvc-add-support-for-samsung-q310-webcam.patch
    media-video-uvc-add-support-for-thinkpad-sl500-webcam.patch
    media-video-uvc-sort-the-frame-descriptors-during-parsing.patch
    media-video-uvc-handle-failed-GET_MIN_MAX_DEF-more-gracefully.patch
    media-video-uvc-commit-stream-param-when-enabling-stream.patch
    misc-eeepc-laptop-check-return-values-from-rfkill_register.patch
    misc-eeepc-laptop-implement-rfkill-hotplugging-in-eeepc-laptop.patch
    misc-eeepc-laptop-add-support-for-extended-hotkeys.patch
    net-fix-userland-breakage-wrt-if_tunnel.h.patch
    serial-RS485-ioctl-structure-uses-__u32-include.patch
    sound-alsa-hda-Add-quirk-for-another-HP-dv5-model.patch
    btusb-add-broadcom-dongle.patch
  * Rediffed/Redid following patches:
    acpi-add-proc-event-regs.patch
    fs-dynamic-nls-default.patch
    media-dvb-add-Yuan-PD378S.patch
    serial-docomo-F2402.patch
    sound-alsa-hda-add-acer-alc889-model.patch
    sound-alsa-hda-92hd71xxx-disable-unmute-support-for-code.patch
    sound-alsa-hda-Additional-pin-nids-for-STAC92HD71Bx-and.patch
    sound-alsa-hda-Dynamic-detection-of-dmics-dmuxes-smuxes.patch
    sound-alsa-hda-Don-t-call-stac92xx_parse_auto_config-wi.patch
    sound-alsa-hda-one-more-hp-dv7-quirk.patch
    sound-alsa-hda-Don-t-touch-non-existent-port-f-on-4-por.patch
    sound-alsa-hda-sigmatel-ecs202-new-quirk.patch
    usb-storage-uss725-build-fixes.patch
    bluetooth-hci_usb-disable-isoc-transfers.patch
    hid-usbhid-quirk-multilaser.patch
    3rd-3rdparty-merge.patch
  * Pending/moved to patches-broken:
    - acpi-asus-input.patch: same functionality merged upstream, but
      needs extra checking on some extra/different key codes to be
      dropped.
    - hid-hotplug-racefix.patch: possibly fixed by commit "HID:
      hiddev cleanup -- handle all error conditions properly"
      upstream.
   * Dropped from patches-broken:
    - media-video-uvc-max-iso-pkts.patch: no machine/environment
      available anymore to reproduce the problem.
   * Added alc889 fixes submitted upstream for which
     sound-alsa-hda-add-acer-alc889-model.patch depends:
     sound-alsa-hda-consider-additional-capsrc-alc889.patch
     sound-alsa-hda-alc882_auto_init_input_src-selector.patch
   * Updated tomoyo to 1.6.6-20090202, 2.6.29-rc3 build and kernel
     log warning patches adapted.
   * Adjusted drbd and unionfs for 2.6.29 changes.
   * Removed rt2860 from additional 3rdparty drivers, it is now
     included in staging.

  + Thomas Backlund <tmb@mandriva.org>
    - update drbd to 8.3.0

  + Anssi Hannula <anssi@mandriva.org>
    - Disable CONFIG_HID_COMPAT (hid-dummy module) as our udev supports
      driver autoloading on all buses.

* Mon Feb 09 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.28.4-1mnb2
+ Revision: 338755
- Removed input-samsung-nc10.patch (merged in 2.6.28.4).
- Prepare to release.
- Remove previous applied enhancements/fixes to STAC92HD71Bx and
  STAC92HD75Bx hda codec support, and reapply splitted changes
  submitted upstream. Apply also additional fixes and HP dv quirks
  in sound tree. Added additional quirk for HP dv7 to be submitted
  after I get positive report about it.
- ALSA/hda: Map new ecs motherboard id 1019:2950 to STAC9221 ecs202
  model.
- Updated to 2.6.28.4

  + Anssi Hannula <anssi@mandriva.org>
    - Build HID core as modules instead of built-in. Having it built-in
      makes no sense as both USB HID and Bluetooth HIDP are built as
      modules anyway.

* Wed Feb 04 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.28.3-1mnb2
+ Revision: 337511
- serial.h exported userspace header fix (#47313, and reported also by
  Gustavo De Nardin).
- Prepare to release.
- Added upstream fix for the exposed linux/ip.h header in
  if_tunnel.h exported to userspace bug
  (http://lists.mandriva.com/kernel-discuss/2009-02/msg00000.php).
- Updated to 2.6.28.3
  * removed x86-pat-1MB-nonram.patch (merged)
- Small corrections/cosmetics in sreadahead 1.0 patch.

* Wed Jan 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.28.2-1mnb2
+ Revision: 334911
- Make sure tracer for sys_open() builds on 2.6.28.
- Updates for sreadahead 1.0 support.
- Updated to 2.6.28.2
  * removed following patches (already applied or obsolete with
    "usb-storage: set CAPACITY_HEURISTICS flag for bad vendors"
    change):
    usb-storage-unusual_devs-nokia-5200.patch
    usb-storage-unusual-devs-nokia-5610.patch
  * rediff sound-alsa-hda-enhance_fix_stac92hd71bx_stac92hd75bx.patch
  * cosmetic changes at sound-alsa-hda-add-acer-alc889-model.patch

  + Pascal Terjan <pterjan@mandriva.org>
    - Try to better describe -devel

* Fri Jan 23 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.28.1-2mnb2
+ Revision: 333095
- Makefile:
  * remove unused SOURCES_DIR
  * fix errors with latest rpm (wrong topdir)
- Fix snd-hda-intel oops with some alc883 models after addition of
  model for Acer Aspire 8930

* Thu Jan 22 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.28.1-1mnb2
+ Revision: 332607
- Prepare to release.
- Updated to 2.6.28.1
- Add MSI quirk list for hda devices, to force enable_msi setting
  parameter when needed (#44855).
- Enhance/fix some aspects related to STAC92HD71Bx and STAC92HD75Bx
  support (#44855).
- Add hda-intel ALC889 model for Acer Aspire 8930 (#45838).
- Add Suggests for crda in kernel packages.

  + Pascal Terjan <pterjan@mandriva.org>
    - Add id for Yuan PD378S DVB receiver
    - Add back patch on asus-laptop to convert acpi events to input
    - Drop asus_acpi patch
    - Disable asus_acpi, we have asus-laptop and eeepc-laptop
    - Better titles
    - List added modules
    - Fix bug number in changelog
    - Add patch from upstream #19422 to allow X starting on some systems (#46384)

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Fix rtc-cmos loading (patch suggested by Oden Eriksson)
    - Update package's changelog
    - Make CONFIG_IDE modular in all configs (asked by Thierry Vignaud)
    - Update configs to 2.6.28: CONFIG_X86_PTRACE_BTS is being disabled because
      it's marked as broken and as CONFIG_X86_DS depends on it it's also being
      disabled

  + Thierry Vignaud <tv@mandriva.org>
    - add probable author
    - add probable author

* Tue Dec 30 2008 Pascal Terjan <pterjan@mandriva.org> 2.6.28-2mnb2
+ Revision: 321303
- Support fn+* in Samsung NC10

* Mon Dec 29 2008 Pascal Terjan <pterjan@mandriva.org> 2.6.28-1mnb2
+ Revision: 320994
- Updated to 2.6.28 final

* Fri Dec 12 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.28-0.rc8.1mnb2
+ Revision: 313689
- Minor spec code fix.
- More build fixes, and fix previous "build fixes"...
- * Redid/Rediffed following patches (updates for netfilter/xtables
  changes in 2.6.28):
  net-netfilter-IFWLOG-mdv.patch
  net-netfilter-psd-mdv.patch
  * Update ipt_set for netfilter/xtables changes in 2.6.28
- Updated to 2.6.28-rc8
- Removed 3rdparty et131x which is now in staging.
- Misc build fixes.
- Updated to 2.6.28-rc7
  * Dropped (merged):
    x86-add-northbridge-pci-ids-for-fam-0x11-processors.patch
    x86-add-detection-of-AMD-family-0x11-northbridges.patch
    fastboot-1.patch
    acpi-add-preemption-to-avoid-latency-issue.patch
    acpi-ACPICA-Add-function-to-dereference-returned-referen.patch
    ata-ata_piix-hercules-ec900-short-cable.patch
    ide-pci-piix-hercules-ec900-short-cable.patch
    scsi-megaraid-proc-oops.patch
    gpu-drm-SiS-DRM-fix-a-pointer-cast-warning.patch
    gpu-drm-fix-sysfs-error-path.patch
    gpu-drm-radeon-fix-writeback-across-suspend-resume.patch
    gpu-drm-i915-remove-settable-use_mi_batchbuffer_start.patch
    gpu-drm-i915-Ignore-X-server-provided-mmio-address.patch
    gpu-drm-i915-Use-more-consistent-names-for-regs-and-store.patch
    gpu-drm-i915-Add-support-for-MSI-and-interrupt-mitigation.patch
    gpu-drm-i915-Track-progress-inside-of-batchbuffers-for-dete.patch
    gpu-drm-Add-Intel-ACPI-IGD-OpRegion-support.patch
    gpu-drm-i915-save-restore-MCHBAR_RENDER_STANDBY.patch
    media-video-uvc-implement-usb-reset-resume.patch
    media-video-uvc-supress-spurious-EOF-in-empty-payload-trace-msg.patch
    media-video-uvc-fix-incomplete-frame-drop-switch-variable-size.patch
    media-video-uvc-dont-use-part-of-buffer-for-USB-transfer.patch
    media-video-uvc-declare-missing-unit-controls.patch
    media-video-uvc-control-cache-access-fix.patch
    media-video-uvc-add-bison-quirk-fujitsu-amilo-si2636.patch
    media-video-uvc-add-bison-quirk-advent-4211.patch
    media-video-uvc-support-two-new-bison-webcams.patch
    media-video-gspca-add-m5602-driver.patch
    misc-add-panasonic-laptop-extras.patch
    net-sis190-add-atheros-phy-ar8012.patch
    net-r8169-Tx-performance-tweak-helper.patch
    net-r8169-use-pci_find_capability-for-the-PCI-E-feature.patch
    net-r8169-add-8168-8101-registers-description.patch
    net-r8169-add-hw-start-helpers-for-the-8168-and-the-810.patch
    net-r8169-additional-8101-and-8102-support.patch
    net-r8169-WoL-fixes-part-1.patch
    net-r8169-WoL-fixes-part-2.patch
    net-wireless-b43-Fix-QoS-defaults.patch
    net-wireless-b43legacy-Fix-to-enhance-TX-speed.patch
    net-wireless-b43-Fix-Bluetooth-SPROM-coding-error-Motorola-7010-BCM4306.patch
    net-atl2-add-atl2-driver.patch
    net-atl2-add-tx-bytes-statistic.patch
    net-enic-add-Cisco-10G-Ethernet-NIC-driver.patch
    net-enic-Don-t-indicate-IPv6-pkts-using-soft-LRO.patch
    net-enic-fixes-for-review-items-from-Ben-Hutchings.patch
    net-enic-Bug-fix-Free-MSI-intr-with-correct-data-handl.patch
    net-enic-bug-fix-don-t-set-netdev-name-too-early.patch
    net-jme-JMicron-Gigabit-Ethernet-Driver.patch
    net-qlge-New-Qlogic-10Gb-Ethernet-Driver.patch
    net-qlge-Fix-warnings-in-debugging-code.patch
    net-qlge-Protect-qlge_resume-with-CONFIG_PM.patch
    net-bluetooth-apple-wireless-keyboard-fnkey.patch
    net-wireless-iwlagn-downgrade-BUG_ON-in-interrupt.patch
    sound-alsa-revert-for-20081011-merge.patch
    sound-alsa-20081011-merge.patch
    sound-alsa-20081013-merge.patch
    sound-alsa-20081016-merge.patch
    sound-alsa-20081017-merge.patch
    sound-alsa-20081020_1-merge.patch
    sound-alsa-20081020_2-merge.patch
    sound-alsa-20081020_3-merge.patch
    sound-alsa-20081023-merge.patch
    sound-alsa-20081027-merge.patch
    sound-alsa-pci_ioremap_bar-only-in-2.6.28.patch
    sound-alsa-revert-for-20081030-merge.patch
    sound-alsa-20081030-merge.patch
    sound-alsa-20081103-merge.patch
    sound-alsa-20081110-merge.patch
    sound-alsa-20081112-merge.patch
    sound-alsa-20081118-merge.patch
    sound-alsa-20081130-merge.patch
    usb-storage-nokia-6300.patch
    usb-storage-unusual-devs-nokia-7610.patch
  * Moved to patches-broken:
    irq-debug-shared.patch
    pci-default-nomsi.patch (continue to disable msi by default?)
    scsi-sg-allow-dio-as-default.patch
    hwmon-applesmc-retry-when-accessing-keys.patch (still needed?)
    hwmon-applesmc_int.patch (useful?)
    media-video-uvc-max-iso-pkts.patch
    apparmor patches
    aufs patches
  * Redid/Rediffed following patches:
    ide-pci-sis5513-965.patch
    fs-dynamic-nls-default.patch
    media-video-uvc-handle-failed-GET_MIN_MAX_DEF-more-gracefully.patch
    net-netfilter-psd-mdv.patch
    hid-usbhid-IBM-BladeCenterHS20-quirk.patch
    hid-usbhid-quirk-multilaser.patch
    3rd-3rdparty-merge.patch
    gpu-drm-mach64.patch
    gpu-drm-mach64-fixes.patch
  * Removed kernel-add-mute-events-log-level.patch (not worth/sent
    upstream).
  * Removed fastboot-2.patch (asynchronous stuff not accepted
    into 2.6.28).
  * Removed acpi-asus-laptop-input.patch and acpi-eeepc-input.patch,
    as different input support was merged for eeepc-laptop.
  * Removed net-enic-build-fix.patch, not needed on 2.6.28
  * Removed acpi-dsdt-initrd-fastboot.patch, not needed anymore.
  * Removed net-wireless-at76_usb.patch, at76_usb is now in staging
    tree.
  * Updated drbd code for 2.6.28 (3rd-drbd-2.6.28.patch).
  * Added patch from squashfs CVS to allow successful build on 2.6.28
  * Removed 3rdparty prism25 which is now in staging.

  + Pascal Terjan <pterjan@mandriva.org>
    - Improve the chance that build works on ppc

* Fri Dec 05 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.7-3mnb2
+ Revision: 310826
- Prepare to release.
- Upstream alsa bug fixes/updates (1.0.18, 20081130 merge).
- * acpi-eeepc-input.patch: add more hotkeys for newer eeepc models,
  keycode references from http://lkml.org/lkml/2008/11/17/161
- Backport wireless hotplug support for eeepc from
  http://lkml.org/lkml/2008/11/17/170 (#43332).

  + Pascal Terjan <pterjan@mandriva.org>
    - Enable CONFIG_CIFS_DFS_UPCALL

* Wed Nov 26 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.7-2mnb2
+ Revision: 307181
- Commit right version of
  media-video-uvc-commit-stream-param-when-enabling-stream.patch
- o Luiz Capitulino <lcapitulino@mandriva.com.br>
  - Support for broadcom bluetooth dongle 0a5c:2009 in btusb (#44886)
  o Herton Ronaldo Krzesinski <herton@mandriva.com.br>
  - Sync alsa/uvc updates with kernel-2.6.27-0.uc1mnb2 available in
    main/testing for 2009.0

* Tue Nov 25 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.7-1mnb2
+ Revision: 306719
- Prepare to release.
- Add fix for ppscsi module oops (#45393).
- Backport gspca m5602 driver from 2.6.28 (#44898).
- Apply upstream workaround for #44891 (iwlagn: downgrade BUG_ON in
  interrupt).
- Update to 2.6.27.7 (CVE-2008-5033)
  * dropped input-ALPS-add-signature-for-DualPoint-model-found-in-Dell-Latitude-E6500.patch
    (merged)

  + Pascal Terjan <pterjan@mandriva.org>
    - Disable CONFIG_BLK_DEV_UB

* Sat Nov 15 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.6-1mnb2
+ Revision: 303502
- Prepare to release.
- More unusual_devs additions for Nokia 5610/7610 (sources: linux-usb ML
  and Ubuntu bug #287701).
- unusual_ids usb-storage addition for Nokia XpressMusic 5200
  (#44988).
- Regenerate configs.
- More alsa 1.0.18 updates, snd-hda-intel sigmatel codec fixes
  among others.
- Update to 2.6.27.6
  * dropped md-fix-bug-in-raid10-recovery.patch (merged)
  * dropped net-r8169-get-ethtool-settings-through-the-generic-mii.patch
    (merged)
  * dropped net-wireless-iwlwifi-generic-init-calibrations-framework.patch
  * dropped security-keys-request_key-oops.patch (merged)
- i915/drm: backported bug fix for suspend/resume with i915 on some
  configurations (Save/restore MCHBAR_RENDER_STANDBY commit on
  2.6.28).
- Include r8169 WoL fixes from 2.6.28, related ticket: #41782

  + Pascal Terjan <pterjan@mandriva.org>
    - Enable the Nokia 6300 quirk for new revisions

  + Thomas Backlund <tmb@mandriva.org>
    - add fixed BZ #

* Sun Nov 09 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.5-1mnb2
+ Revision: 301258
- o Thomas Backlund <tmb@mandriva.org>
  - fix md raid10 recovery bug
- Prepare to release.
- Add patch to fix oops in prism2_usb (#44612).
- Fix pcspkr disabled in kernel configs (#45319).
- Apply upstream change in acpi "ACPICA: Add function to dereference
  returned reference objects" (#44870).
- Alsa updates from 2.6.27-git* (2.6.28).
- Update to 2.6.27.5
  * dropped acpi-ec-fast-transaction.patch (merged)
  * rediffed char-agp-intel-agp-add-support-for-G41-chipset.patch
  * dropped net-restore-ordering-of-tcp-options.patch (merged)
  * dropped sound-alsa-snd-hda-intel-fix-halt-hang.patch (merged)
- Don't use subshell with tar while building patches tarball
  (from Gustavo de Nardin -- spuk).
- Backport uvcvideo fixes from 2.6.28 and linux-uvc svn.

  + Thomas Backlund <tmb@mandriva.org>
    - fix drbd CN_IDX 0x4 conflict with v86d

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Fix eeepc shutdown hang caused by snd-hda-intel (#44752)

* Tue Oct 28 2008 Pascal Terjan <pterjan@mandriva.org> 2.6.27.4-2mnb2
+ Revision: 297927
- Fix a oops in request_key when keyring is not already there
- Add missing patch
- Really add the fastboot patches and add some explanations
- Add Fastboot patches
- Fix a oops when reading /proc/megaraid/hba0/diskdrives-ch* (upstream #11792)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Alsa fixes from 2.6.27-git* (2.6.28).

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Restore ordering of TCP options (#43372)
    - Update to 2.6.27.4
      * Drop usb-atm-speedtch-2.6.27-fix.patch (merged)
    - Copy patch-2.6.27.4.bz2.sign from kernel-tmb
    - Copy patch-2.6.27.4.bz2 from kernel-tmb

* Thu Oct 23 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.3-1mnb2
+ Revision: 296759
- More alsa updates from 2.6.27-git* (2.6.28).
- Update to 2.6.27.3

* Wed Oct 22 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.2-3mnb2
+ Revision: 296373
- Don't install vmlinux as executable for debug packages to avoid
  strip_and_check_elf_files from spec-helper stripping it.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Fix USB ATM Speed Touch OOPS (#44803)
    - Update .configs

* Tue Oct 21 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.2-2mnb2
+ Revision: 295899
- Release bump.
- o Herton Ronaldo Krzesinski <herton@mandriva.com.br>
  - Update alsa 1.0.18rc3 to "final" version included in kernel 2.6.28
    and dropped following patches:
    * sound-alsa-revert-fixes.patch (not needed anymore)
    * sound-hda-codec-add-Foxconn-45CMX_45GMX_45CMX-K-quirk.patch
      (merged)
    * sound-hda-codec-fix-ALC662-auto-config-mixer-mutes.patch
    * sound-hda-codec-slave_dig_outs-oops.patch (merged)
    * sound-hda-codec-add-Gigabyte-945GCM-S2L-quirk.patch (merged)
  o Pascal Terjan <pterjan@mandriva.com>
  - Drop Acer One alsa quirk, it works now better with "auto" model

* Sun Oct 19 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27.2-1mnb2
+ Revision: 295191
- Update to 2.6.27.2
  * dropped net-wireless-b43legacy-Fix-failure-in-rate-adjustment-mechanism.patch
    (merged)
  * dropped net-wireless-libertas-clear-current-command-on-card-removal.patch
- Update to 2.6.27.1 (just cosmetic, luckily we didn't have
  FTRACE+DYNAMIC_FTRACE enabled on supported archs).
- Copying patch-2.6.27.1.bz2.sign from kernel-linus package.
- Copying patch-2.6.27.1.bz2 from kernel-linus package.
- Create kernel debug packages with vmlinux and debugging symbols
  from modules.
- Disable CONFIG_KALLSYMS_EXTRA_PASS were it was enabled, as Kconfig
  description states this should only be enabled temporarily as a
  workaround while something is broken in kallsyms.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Enable CONFIG_KPROBES: needed for systemtap

* Fri Oct 10 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-1mnb2
+ Revision: 291575
- Prepare for release.
- Added superreadahead ext3 patch for tests to be done with it.
- Add Panasonic Let's Note laptop extras driver from acpi-test. Now
  dkms-pcc-acpi packages can be dropped.
- Drop from svn patches already applied on 2.6.27
- Add p4-clockmod support for Celeron Core processors (#43885).
- Merge atl2 fixes from net-next tree.
- Merge enic and qlge fixes from net-next tree.
- Grr, patch added in previous commit had typos, fix them.
- Add i8042_nomux quirk for Dell XPS M1530 (#43532).
- Use official patch version from Linus git tree for patch added in
  previous commit.
- Add fix for e1000e corruption bug and re-enable it
  (http://lkml.org/lkml/2008/10/1/368). Closes #44147

  + Pascal Terjan <pterjan@mandriva.org>
    - Update to 2.6.27 final
    - Prepare for a release of 2.6.27-0.rc8.1mnb

* Wed Oct 01 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc8.1mnb2
+ Revision: 290279
- p4-clockmod: set reasonable default for scaling_min_freq, to
  prevent too low performance with governors that use the lowest
  frequency. Closes: #43155
- Fix typo in early boot parameter that enables mtrr cleanup, patch from
  J.A. Magallon.
- Minor changelog fix.
- Add patch from LKML titled "Input: ALPS - add signature for DualPoint
  model found in Dell Latitude" from Elvis Pranskevichus,
  reported/requested by Frederik Himpe.
- 3rdparty/rt2860: Fix x86_64 issues found while inspecting x86_64
  build logs.
- drbd fixes for Linux 2.6.27
- Enable CONFIG_KARMA_PARTITION, otherwise Rio Karma mp3 player is
  unusable.
- Remove 3rdparty acx driver due to its dubious legal status
  (unanswered questions about reverse engineering process done while
  developing the driver).
- Add fix for sata_nv regression in latest 2.6.27 rcs (kernel.org
  bug #11615). Closes: #44287
- Fix sis190 ethernet device support on Asus P5SD2-VM motherboard
  (kernel.org bug #11073).

  + Pascal Terjan <pterjan@mandriva.org>
    - Update to 2.6.27-rc8

  + Thomas Backlund <tmb@mandriva.org>
    - fix patch prefix

* Sat Sep 27 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc7.5.1mnb2
+ Revision: 288876
- Prepare for build+release.
- ALSA/hda-intel: map proper ALC662 model for Gigabyte 945GCM-S2L and
  Foxconn 45CMX/45GMX/45CMX-K motherboards.
- Drop Wacom ACPI patches: seems they were forgotten here, same
  functionality should already be provided by drivers/serial/8250_pnp.c
- Add again Intel ACPI IGD OpRegion support patch and its needed
  patches, but now without the patch that introduced the regression
  found with one 855GM based laptop (the patch that introduced the
  regression was "i915: Initialize hardware status page at device
  load when possible.", turned out also that this patch wasn't
  really needed in the series so it's safely dropped). Closes: #43061
- Include patch from linux-acpi to avoid stalls while inside acpi code
  in slow machines, like when reading acpi battery info
  (http://marc.info/?l=linux-acpi&m=122235488029621&w=2). A workaround
  could be used too for the problem, using cache_time parameter of
  battery module setting a larger value, but the patch to preempt acpi
  code is a better/definitive solution.
- patches-broken: rediff and fix hid-usbhid-IBM-BaldeCenterHS20-HID.patch
  for 2.6.27 (rename also to hid-usbhid-IBM-BladeCenterHS20-quirk.patch).
- Drop acpi-tc1100-wmi* patches, kernel already has all relevant
  support.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Update to 2.6.27-rc7-git5
      * drop net-wireless-ath9k-connectivity-is-lost-after-Group-rekeying-is-done.patch
        (merged)
      * drop USB-revert-recovery-from-transient-errors.patch (merged)
      * Update security-apparmor-2.6.27.patch due to change in mm/tiny-shmem.c
      * Add usb-storage-uss725-build-fixes.patch

  + Pascal Terjan <pterjan@mandriva.org>
    - Fix disable camera on EeePc breaking USB
    - Fix Wlan and Webcam keyboard switching on EeePc
    - Fix function keys on EeePc, some NEC and some other laptops

* Tue Sep 23 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc7.1.1mnb2
+ Revision: 287506
- Update to 2.6.27-rc7-git1
- Disable e1000e module until a fix for its corruption issue is
  available (#44147).
- Remove already applied fs-xfs-fix-remount-failure.patch
- Fix checkpatch.pl complaint on net-enic-build-fix.patch

  + Pascal Terjan <pterjan@mandriva.org>
    - Support fn key on Apple Wireless keyboards (#44119)

* Fri Sep 19 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc6.5.1mnb2
+ Revision: 286037
- Add "mute" kernel start-up parameter to disable all log messages, from
  Tiago Salem Herrmann.
- Include following bug fixes from linux-wireless ML:
  * ath9k: connectivity is lost after Group rekeying is done
  * b43: Fix Bluetooth coexistence SPROM coding error for Motorola
    7010 variant of BCM4306
- Add qlge: Qlogic 10Gb Ethernet Driver, from Jeff Garzik netdev-2.6
  tree.
- New/updated ethernet drivers from Jeff Garzik netdev-2.6 tree:
  * updated jme driver;
  * Cisco 10G Ethernet NIC driver.
- Updated atl2 driver from Jeff Garzik netdev-2.6 tree.
- ALSA: Fix ALC662 DAC mixer mutes also for auto config model.
- Cosmetics.
- Add Hercules EC900 short cable entry for piix too.
- Add Hercules EC-900 mini-notebook to ich_laptop short cable list.
- Remove alternative patch for kernel.org bug 7694, a proper patch is
  already on mainline.
- Fix changelog date.
- Revert Intel ACPI IGD OpRegion support patch addition along with
  its needed patch series, we discovered a regression on a laptop
  with 855GM when using kde4 with gfx effects enabled (X hangs in
  session startup). Probably is related to the change "i915: Add
  support for MSI and interrupt mitigation." patch at first look
  after some initial debugging made by Luiz Capitulino (we are not
  sure, needs more investigation and upstream bug report that will
  be done later, but reverting all patches for now works).
- Lets build a new kernel release.
- Wireless bugfixes from linux-wireless ML applicable to 2.6.27:
  iwlwifi: generic init calibrations framework
  b43: Fix QoS defaults
  b43legacy: Fix failure in rate-adjustment mechanism
  b43legacy: Fix to enhance TX speed
  libertas: clear current command on card removal
- Added fix for 2.6.27 boot issue with xfs, fs can't be mounted rw
  (http://lkml.org/lkml/2008/9/14/135), reported by Frederik Himpe.
- Re-include a workaround for a virtualbox bug (#42776) removed in
  previous release, even with Mandriva cooker/2009.0 having a newer
  VirtualBox version that has the bug fixed. Before we had this as a
  revert of both commits e587cadd8f47e202a30712e2906a65a0606d5865
  and 2f1dafe50cc4e58a239fd81bd47f87f32042a1ee, but reverting the
  later reintroduces another bug:
  http://linux.derkeiler.com/Mailing-Lists/Kernel/2008-04/msg07574.html
  Reverting the second one is needed when reverting the first one
  that is which caught the bug in VirtualBox versions prior to 2.0.2.
  The problem is that people using other distributions or older
  Mandriva releases that contains old VirtualBox versions will not
  be able to run and test Mandriva 2009.0, so we still need to apply
  a workaround. Ubuntu has a less intrusive one (not using reverts),
  so use it instead of just fully reverting the kernel commits.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Update to 2.6.27-rc6-git5
    - Update .configs

  + Pascal Terjan <pterjan@mandriva.org>
    - Add the ruby script I use to find modules renaming between kernels
    - Enable CONFIG_CIFS_EXPERIMENTAL to support Kerberos auth (#43933)
    - Really disable braille console support when it is not used (#41999)
    - Undo part of last commit which should not have got in
    - Fix changelog as an upload had occurred
    - Don't tar .svn to remove it afterwards and don't include *~ either
    - Re-enable PROFILING and OPROFILE

* Mon Sep 15 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc6.3.1mnb2
+ Revision: 284833
- Minor build fix for x86-add-detection-of-AMD-family-0x11-northbridges.patch
- Update to 2.6.27-rc6-git3
- Remove already applied fs-partitions-revert-exceeds-partition-error.patch
- Add compatibility quirk for ALI M5229 patch posted on LKML, needed by
  pata_ali libata driver to work with M5229 in some setups.
- Add patches for detection of northbridge in family 0x11 AMD processors
  from tip/x86/iommu tree.
- Include Intel G41 agpgart support patch posted on LKML.
- Add Intel ACPI IGD OpRegion support patch from drm-next, needed to
  enable ACPI backlight control on some newer laptops with Intel
  integrated graphics. Some other patches were needed to be applied also
  because of conflicts, they do some a bit extra changes, not something
  really wanted, but possibly also fixes some stability issues when
  using intel dri. While at it also grabbed some minor additional bug
  fixes only patches from drm-next.
- Remove revert patch to workaround VirtualBox bug (#42776), VirtualBox
  2.0.2 now on cooker has the bug fixed.
- Add updated fs-partitions-revert-exceeds-partition-error.patch with
  extra comments.
- Fix kernel regression in partition check code
  (http://bugzilla.kernel.org/show_bug.cgi?id=11554).
- Added fix for snd-hda-intel oopses in alsa 1.0.18rc3.
- ALSA: update to v1.0.18rc3
- usb-storage: fixed and added back In-System Design USS725 USB/IDE
  bridge support patches.
- Regenerated configs.
- Fixed and added back mach64 drm support.
- Added fix to build warnings in rt2860 3rdparty driver.
- Really build unionfs 1.4.
- Backport unionfs-1.4-security_hooks.patch from dkms-unionfs.
- Backport unionfs-1.4-attr_mode_notify_change.patch from dkms-unionfs
- Downgrade unionfs to version 1.4, the main unionfs patch also
  comes from Ubuntu with minor adaptations, for the same reason as
  with aufs: it has already integrated apparmor changes. We are
  downgrading because of newer problems with unionfs 2.3 + linux
  2.6.25+, we will keep it until the problems are sorted out.
- Fix build with aufs as a module.
- Add aufs into Mandriva kernel, can be used as an unionfs alternative.
  The main patch and code comes from Ubuntu (see main patch file for
  details), as they already made necessary ports to account for
  apparmor patch that we also share.
- Fix build with rt2860 3rdparty driver.
- Minor changelog nitpick.
- Move dkms-et131x into kernel package.
- Move dkms-rt2860 into kernel package.
- Include JMicron JMC2x0 series PCIe Ethernet Linux Device Driver from
  Guo-Fu Tseng, posted on netdev.

  + Pascal Terjan <pterjan@mandriva.org>
    - Use the value in $to_add even if the option was already in the config
    - Set CONFIG_LEGACY_PTY_COUNT to 0
    - Include r8169 patches for 8102 (patches 0001 to 0006 from
       http://userweb.kernel.org/~romieu/r8169/2.6.27-rc3/20080818/).
       Fixes networking on Acer Aspire One and MSI Wind.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Update to 2.6.27-rc6
      * Drop clockevents patch series from Thomas Gleixner (already merged)
    - Update to 2.6.27-rc5-git7
    - Add missing patch from the Thomas Gleixer's series to
      fix #43475
    - Fix package release: it should be 1mnb, rather than 2mnb
    - Fix boottime hang on nvidia C51 mobos (#43475)
    - Update to 2.6.27-rc5-git6

  + Thomas Backlund <tmb@mandriva.org>
    - update TomoyoLinux to 1.6.4 final

* Sun Aug 31 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc5.2.1mnb2
+ Revision: 277730
- Use git snapshot number in package release like is done currently on
  kernel-linus package.
- Updated to 2.6.27-rc5-git2
- Updated Tomoyo Linux patches to latest version from tomoyo svn
  (r1499). It contains fixed code for locking problems with apparmor
  patches applied (http://lkml.org/lkml/2008/8/30/75).
- apply_patches: fix integrity check of 3rdparty.series/series files
  regarding unlisted patch files.

* Sun Aug 31 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.27-0.rc5.1mnb2
+ Revision: 277688
- svn+ssh://svn.mandriva.com/svn/packages/cooker/kernel/branches/rebase-to-2.6.27
  is now current kernel.
- Updated to 2.6.27-rc5
- I missed one conversion fix for unionfs when updating to 2.6.27,
  handle this like already done upstream.
- Updated to 2.6.27-rc4-git7
- Fix changelog entry.
- Added apparmor patch from John Johansen fixing ptrace lsm hooks,
  forwarded by Ben Collins (Ubuntu).
- Add missing sources.
- Updated to 2.6.27-rc4-git6
- Updated to latest alsa from git.alsa-project.org/alsa-kernel.git
- Updated to 2.6.27-rc4
- Rediffed/updated patches for 2.6.27:
  disable-mrproper-in-devel-rpms.patch
  hwmon-coretemp-atom.patch
- Drop wireless and gspca backport patches for 2.6.26 already
  applied on 2.6.27
- Drop already applied/obsoleted patches:
  net-usb-rndis_host-support-WM6-devices-as-modems.patch
  acpi-compal-laptop-0.2.5.patch
  kernel-sched-disable-hrtick.patch
  3rd-3rdparty-merge.patch
  net-atl1e-driver.patch
  net-atl1e-fix-no-pm-build.patch
  pci-fix-boot-time-hang-on-g31-g33-pc.patch
- Remove 3rdparty at76_usb driver, include the version present in
  wireless-testing tree on git.kernel.org
- Fix tomoyo to build under 2.6.27 (vfs changes).
- Fix ndiswrapper 1.53 to build with 2.6.27
- Added more fixes to 3rdparty/modules for build with 2.6.27
  (prism25, unionfs, acx, ipset)
- Removed separated apparmor patches, and include port for 2.6.27
  from Ben Collins (Ubuntu). Also fixed some still present warnings.
- Include updated atl2 driver version.
- Remove unused ppc arch support, unified with powerpc on 2.6.27
- Re-import alsa 1.0.18rc1 patch, now against 2.6.27 and is a
  snapshot of alsa git repository (with changes after 1.0.18rc1).
- Copy revision 275691 from packages/cooker/kernel/current
- Newer b43 version after 2.6.27 backport can trigger an oops in current
  2.6.26 led subsystem, apply bug fix from 2.6.27
- Backport most of the wireless changes from 2.6.27 (until ath9k
  addition).
- Remove unused net-wireless-bcm43xx-dont-flood-syslog-with-ifplugd.patch
  (broken), bcm43xx was removed in 2.6.26
- Fix missing newline escape at mkflavour macro.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Fix DEBUG_RODATA support revert patch: smp_alt must be a spinlock, not
      a mutex
    - Update squashfs to v3.4
    - Fix VirtualBox boot time crash (#42776)
    - Revert unionfs v2.4 update: it is buggy and One LiveCD is getting
      OOPses
    - Update changelog (preparing to release)
    - Disable PCI MSI by default, because it is known to cause boot hangs
      (patch from Fedora)
    - Drop x86-debug-boot.patch. It is confusing a lot of people, the patch was
      supposed to help rather than causing any harm (#41946)
    - Add Atheros L1E Gigabit Ethernet driver from 2.6.27-rc2 (#41551)
    - Update unionfs-apparmor patch name to fs-unionfs-2.4-apparmor.patch
    - Update unionfs to v2.4

  + Pascal Terjan <pterjan@mandriva.org>
    - Move EeePc patch to eeepc-laptop
    - Map Acer Aspire One to acer model to get internal/external speaker, and external mic to work
    - Add Atom support in coretemp
    - Obsolete dkms-iwlwifi (#42766)

  + Thomas Backlund <tmb@mandriva.org>
    - really disable CONFIG_SCHED_HRTICK
    - update defconfigs
    - revert rtl8187-fix-lockups-due-to-concurrent-access-to-config-routine
      as it's already included in the wireless backport
    - update to 2.6.26.3
    - disable CONFIG_SCHED_HRTICK as it's known to cause boot problems with
      at least Intel GMA cards, as noted on LKML and kernel BugZilla #10892
    - Update Alsa to 1.0.18rc1
    - revert alsa-emu10k1-fix-inverted-analog-digital-mixer-switch-on-audigy2, already in 1.0.17+
    - revert alsa-hda-add-missing-thinkpad-z60m-support, already in 1.0.17+
    - revert alsa-hda-fix-dma-position-inaccuracy, already in 1.0.17+
    - revert alsa-hda-fix-wrong-volumes-in-ad1988-auto-probe-mode, already in 1.0.17+
    - update to 2.6.26.2
    - Update TomoyoLinux gcc-4.3.1 buildfix with ACK from Tetsuo Handa,
      and some more info regarding the bug we are working around.
    - update tomoyolinux-build.patch due to unionfs update
    - fix TomoyoLinux tomoyo_network build with gcc-4.3.1
    - make TomoyoLinux boot-time message more userfriendly
    - update TomoyoLinux to 1.6.3 and enable it

* Sat Aug 02 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.26.1-1mnb2
+ Revision: 260532
- Regenerated configs.
- Handle 2.6.26.1 patch conflict in alsa: we already apply a change
  that is now on latest kernel stable update, revert the change to
  be able to continue to apply it in official alsa patch set.
- Remove x86-Fix-typos-from-signal_32-64.h-merge.patch (already applied
  in 2.6.26.1).
- Updated to 2.6.26.1
- Fix net-usb-rndis-lite-samsung.patch so that build works.
- Add synce 'dirty patch' from John Carr, fixes support for quite a
  lot of Windows Mobile devices in rndis_host, requested by
  Adam Williamson.
- Integrate gspcav2 from kernel 2.6.27
- Added alsa 1.0.17 fixes/updates from 2008-07-27 LKML submission.
  Removed patches replaced by it.
- Drop asoc patches, we don't use them.
- Disabled also ASOC on i386 kernel, no use for it currently.
- Added following alsa fixes/updates from upstream git:
  ALSA: HDA - Add automatic model setting for the Acer Aspire 5920G laptop
  ALSA: soc - wm9712 mono mixer
  ALSA: opti9xx: no isapnp param for !CONFIG_PNP
  ALSA: opti93x - Fix NULL dereference
  ALSA: hda - Added support for Asus V1Sn
  ALSA: ALSA: ens1370: communicate PCI device to AC97
  ALSA: ens1370: SRC stands for Sample Rate Converter
  ALSA: hda - Align BDL position adjustment parameter
  ALSA: Au1xpsc: psc not disabled when TX is idle
  ALSA: add TriTech 28023 AC97 codec ID and Wolfson 9701 name.
- sis190: fix link status on some devices.

  + Thomas Backlund <tmb@mandriva.org>
    - really add the patch that was supposed to be added in commit 241129

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Drop video-bootsplash-3.1.6-2.6.25.patch, we use splashy now.

  + Pascal Terjan <pterjan@mandriva.org>
    - Add upstream patch to support EeePc P900A and P901
    - Fix sound on NEC Versa S9100

* Wed Jul 23 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.26-2mnb2
+ Revision: 242536
- Prepare to release 2.6.26-2mnb
- Disable CONFIG_FIRMWARE_EDID on i386 and x86_64 also on cooker's
  kernel, like on latest 2008.1 kernel update candidate (enhances boot
  time in some cases by a considerable amount).
- Fix typos from signal_32/64.h merge.
- Disable also *config, prepare and scripts targets on kernel*-devel
  packages (previously we only disabled mrproper).
- Backport RTL8187B support for rtl8187 from wireless-testing.
- Fix build of kernel-source after previous commit.
- kernel-source package shouldn't have a prepared environment, user
  is responsible to prepare and configure it for build/external use
  (don't prepare it anymore and clean uneeded files with make
  mrproper). Also, kernel*-devel packages needs a prepared
  environment, this was already assured before by the build, but
  anyway prepare the tree again to check for possible errors.
- Really don't remove bounds.h and asm-offsets.h with make clean.
- Fix the patch included in the previous commit.
- Added fs-squashfs3.3-f_pos-wrong-decrement.patch, small bug fix for
  squashfs.
- create_configs: enable CONFIG_HIGHMEM4GB for desktop586 kernel
  flavour.
- Fix regression of fakerel not using anymore mkrel macro (and use
  manbo_mkrel for manbo packages).
- I forgot to update changelog date on previous release, done now.

  + Thomas Backlund <tmb@mandriva.org>
    - update drbd to 8.2.6
    - update the use WM6 device as modem patch to the one submitted upstream
    - add support for WM6 tethering (used as modems)
    - drop spec fix for #29744, #29074 (not needed anymore)
    - update alsa to 1.0.17 final
    - update to 2.6.26 final
    - update summary and description for desktop586 kernel to
      reflect that they now support 4GB
    - update to 2.6.26-rc9
    - drop Dell laptops resume fix, merged upstream in -rc9
    - fix broken resume on Dell laptops (reset & reboot during resume)
    - update Alsa to 1.0.17rc3
    - update to 2.6.26-rc8-git5

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Disable CONFIG_USB_MOUSE and CONFIG_USB_KBD: their usage is only useful
      in embedded systems and are known to cause problems in desktops
    - Remove old apparmor from patches-broken
    - Update apparmor to r1292 (untested)
    - Update to 2.6.26-rc9-git8
    - Update changelog date (preparing to release)

* Thu Jul 03 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.26-0.rc8.1mnb2
+ Revision: 231347
- Add missing updated sign file after update of previous commit.
- Updated to 2.6.26-rc8-git3, and removed 3rdparty uvcvideo as it's now
  in upstream kernel.
- Disable smack due to more issues with unionfs.
- Fix build with gcc 4.3 when xen guest support is enabled.
- o Anssi Hannula <anssi@mandriva.org>
  - Obsolete kernel-laptop-devel-latest
- Updated wacom from linuxwacom.sf.net (0.8.0).
- Added Phillip Lougher's patch for squashfs 3.3 on 2.6.25, reenable
  squashfs.
- Updated mach64 drm support for 2.6.25
- Update ppscsi for 2.6.25
- Update configs after compal-laptop update.
- Added updated compal-laptop patch for 2.6.25
- Fix/update broken patch for 2.6.25:
  x86-default_poweroff_up_machines.patch
- Included following r8169 fixes from Linus tree:
  "r8169: fix past rtl_chip_info array size for unknown chipsets"
  "r8169: fix oops in r8169_get_mac_version"
  They were tested by Adam Pigg and fixed an oops with his machine.
- Rediffed and updated bootsplash patch for 2.6.25
- Removed sound-sigmatel_audio_fix_macbook_v2.patch (it's broken, does
  nothing, where is pin cfg assigment for model it adds?).
- Add max_iso_pkts parameter to uvcvideo, to limit its memory usage on
  memory constrained systems.
- Fix changelog typo.
- Add patch from Linus tree: "pcsp - Don't build pcspkr when snd-pcsp is
  enabled". It seems we don't have the full set of 2.6.26 alsa
  submission... needed to avoid building pckspkr and snd_pcsp as they
  conflict.
- Updated alsa to latest LKML submission (git-2008-04-24), and removed
  patches already applied upstream.
- Updated uvcvideo to r205, and removed already applied
  3rd-uvc-x300.patch
- Updated unionfs to version 2.3.3
- Removed 3rd-uvc-limit-max-iso-packets.patch, I found one type of
  webcam that doesn't like it, so just revert.
- ACPI: limit Clevo M720SR to C2 processor idle state (machine freezes
  with C3).
- Added optimized ALC267 model for Quanta IL1 (alsa).
- Fix spec License tag as per current license policy (GPL -> GPLv2),
  reported by Gustavo De Nardin (spuk).
- Alsa (snd-hda-intel) bug fixes/additions/cleanups:
  * Added support model for Clevo M720R from upstream alsa
    (by Jiang zhe).
  * Cleanups after DAC assignment order in ALC883.
  * Support mic automute in Clevo M720R, and map Clevo M720SR to use
    the same model (they are identical). Also choose a more generic
    model name ("clevo-m720").
- Alsa (snd-hda-intel) bug fixes:
  * Fix DAC assignment order in ALC883.
  * Choose correct ALC883 codec model for MSI 945GCM5 V2 (MSI-7267).
- Include bttv.h and bttvp.h headers in kernel-devel, required by
  dkms-lirc-gpio (#39004, patch by Anssi Hannula <anssi@mandriva.org>).
- Alsa (snd-hda-intel) bug fixes:
  * Fixed mute switches of ALC662 mixers (generic models).
  * Choose correct ALC662 codec model for Asus P5GC-MX.
- Backport/add intel igd, sis 662/671, ati rv380 drm/agp support and
  sis-agp suspend support from 2.6.25-rcX.
- Added some x86 cpufreq updates from Linux 2.6.25-rcX:
  * CPUFREQ: Powernow-k8: Update to support the latest Turion
    processors;
  * CPUFREQ: Support Model D parts and newer in e_powersaver;
  * CPUFREQ: Add missing printk levels to e_powersaver.
- Added patch to e_powersaver to limit processor voltage/multiplier
  status printed to syslog (avoid flood of messages when we have
  ondemand governor and many P-state changes for example).
- Added patch from Andrey Borzenkov that add aliases to toshiba_acpi.
  With this module autoloading is possible for devices which aliases
  are added (suggested by Olivier Blin).
- Disable control group support and fair group cpu scheduler for default
  configs.
- scripts/create_configs:
  * enable cgroup/fair group scheduler options for server kernel
    flavour;
  * remove SWAP_PREFETCH and ADAPTIVE_READAHEAD config option uses (we
    don't have them anymore).
- Updated to 2.6.24.3
- Added patch from Alan Stern to fix reported USB-Persist+suspend issues
  (one of the problems found while testing on Intel Classmate).
- hda-intel - Fix Oops with ATI HDMI devices, fix from alsa hg
  change 5873
- Added fix from alsa hg tree (5846):
  "hda-codec - Don't create vmaster if no slaves found"
  This should address problems with mixers without any slave control
  defined for models in codecs with vmaster control being used, and
  will fix mandriva bug #37984
- Drop char-intel-agp-revert-revert-fix-stolen-mem-range-on-G33.patch
  x11-driver-video-intel reverted the change that required this, as
  reported by Colin Guthrie.

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Update to 2.6.26-rc8-git2
    - Explicitly enable PARAVIRT_GUEST to fix 2.6.26-rc8 compilation
    - net-netfilter-psd-mdv.patch: export ipt_psd.h to user-space, iptables
      and any psd user will need it
    - net-netfilter-IFWLOG-mdv.patch: export ipt_IFWLOG.h to user-space, iptables
      and any IFWLOG user will need it.
    - Remove -rc6 patches.
      Should have done that in the last commit.
    - Update to 2.6.26-rc7-git2
     * Drop acpi-video-ignore-unsupported-devices.patch (merged upstream)
    - Update to 2.6.26-rc6-git6
    - Update to 2.6.26-rc5-git6
    - Revert change r216992, alsa-1.0.17rc1 is not working on some machines
    - Fix typo in my email address used in the package's changelog
      (caught by Anssi Hannula)
    - Update to 2.6.26-rc5-git5
    - Boot debug patch for x86 and x86_64: with it it is possible to have
      a good idea of where the boot process has stopped
    - Temporary fix for Smack and unionfs deadlock
    - Update to 2.6.26-rc5
     * Drop smack-fuse-mount-hang-fix.patch (merged upstream)
    - Update to 2.6.26-rc4-git5
      * rediff usb-ehci-hcd-isoc-sync-transfer-fix.patch
    - Commit r214357 missed the patch, adding it now.
    - Fix fuse hang caused by SMACK (#40620)
    - Drop fs-ntfs-rw-support-as-module-option.patch, we use ntfs-3g (fuse)
      for ntfs write support
    - Remove already dropped module from 3rdparty.series
    - Update drbd to v8.0.12
    - Update atl2 network driver to v2.0.4
    - Update rfswitch to v1.3
    - Update to 2.6.26-rc4
    - Update disable-mrproper-in-devel-rpms.patch for 2.6.26-rc3-git8
    - Update create_quilt_tree: add support for -rc, -git and -stable patches
    - Update to 2.6.26-rc3-git8
    - Fix kernel-devel: we should include the kernel/bounds.c file, otherwise
      it is not possible to run 'make prepare' on kernel-devel and dkms
      will fail because of the missing bounds.h (which is generated by
      bounds.c)
    - Update irq-debug-shared.patch for 2.6.26-rc3
    - Update to 2.6.26-rc3
    - Copy 2.6.26-rc3 patch from kernel-linus
    - Merge branch rebase-to-2.6.26-rc2
    - Enable CONFIG_HID_DEBUG for all archs (#40501)
    - Enable CONFIG_USB_SUSPEND for i386 and x86_64 (#40482)
    - Update to 2.6.25.3
    - Fix scsi-megaraid-new-sysfs-name.patch for 2.6.25
    - move apparmor patch into apparmor directory
    - Update netfilter PSD module for 2.6.25 kernel
    - Drop kernel-sysctl_check-remove-s390-include.patch from patches broken
      It has been fixed upstream.
    - Fix Intel's HECI driver for 2.6.25
    - Drop acer_acpi from patches-broken. Kernel 2.6.25 provides acer_wmi,
      which should be used instead
    - Update to 2.6.25.2
    - Reset changelog (preparing to release)
    - Update the package's URL
      The page title has been changed because the kernel is not
      Mandriva-only, it's actually part of Manbo-Core. The title
      should reflect that.
    - Update package's URL info
    - Update to 2.6.25.1
    - Remove media-usbvideo-device-link.patch from series file.
      We have to remove merged patches from the series file as
      well.
    - Enable CONFIG_SMACK for i386 and x86_64
    - Reset version to 1.0 (preparing to release)
    - Merge branch 'rebase-2.6.25'
    - Setting date (preparing to release)
    - Update unionfs to 2.3.1
      * dropped fs-unionfs-2.2-apparmor-2.1.patch and addded a rediffed
        version named fs-unionfs-2.3-apparmor-2.1.patch
    - Update to 2.6.24.4
      * rediff capabilities-remove-cap-task-kill.patch
    - Disable MSI on i386. MSI seems to be still problematic and some
      machines are not booting because of it, so it's better to stay safe
      for now and just disable it again
    - Reset changelog (preparing to release)
    - Fix apparmor OOPS because of FUSE accessing ia_file
      unconditionally (#38688)
    - Update changelog (preparing to release)
    - Update fs-fat-allow-utime.patch with a new default initialization,
      which allows all users to use utime() on files if the directory
      is writable
    - Add back cpufreq tables for Centrino Dothan in speedstep-centrino
      (#38760)
    - Kill patches-purgatory/ directory, tomoyo patches and
      usb-storage-unusual_devs.patch have been merged; block-cciss-ioctlret.patch
      will be dropped
    - Disable BadRAM on x86_64, it doesn't compile if CONFIG_DISCONTIGMEM
      is enabled
    - Reset changelog (prepering to release)
    - fat: allow utime() (#26819)
    - bluetooth: fix eSCO connection (#9041)
    - bluetooth: fix OOPS in l2cap_conn_del()
    - Add badram
    - Revert r178498
      The build_sources script must be updated before killing the
      Makefile, otherwise the kernel won't build.
    - Drop package's Makefile: the Makefile is useless now, if you don't know
      how to build the kernel without using it please read
      PATCHES/Documentation/kernel-build-svn-checkout.txt
    - Introduce svn-tag-kernel script
    - Drop tomoyo linux patches from patches-purgatory/, they have been
      merged already
    - Enable CONFIG_PCI_MSI on i386: MSI had to be disable in 2.6.22 because
      of a bug which caused PCI to stop working on some machines. It seems
      it's safe to enable again now
    - Remove cap_task_kill() to fix kill() semantic bug (#37328)
    - Drop input-export-module_device_tables.patch and
      char-export-module_device_tables.patch from patches-purgatory.
      According to Shinji Makino these patches are not needed anymore.
    - Drop block-scsi_ioctl-GPCMD_SEND_KEY.patch from patches-purgatory/.
      According to Shinji Makino this Turbo Linux patch is not needed anymore
    - Introduce HECI v3.2.0.24 driver (to support Intel's AMT)
    - Update unionfs to 2.2.4
    - Minor changelog fix
    - Drop pci-pciaddress-64bit-fix.patch from patches-purgatory/. According to
      Shinji Makino this Turbo Linux patch is not needed anymore
    - Special release due to compilation problems in the previous one
    - Drop input-alps-pad-fix.patch according to Shinji Makino this TL
      patch is not needed anymore
    - Update drbd to v8.0.11
    - cripts/create_quilt_tree: report errors when creating the tree
    - Actually move patches into patches-purgatory directory. The following
      patches: block-cciss-ioctlret.patch, block-scsi_ioctl-GPCMD_SEND_KEY.patch,
      pci-pciaddress-64bit-fix.patch, usb-storage-unusual_devs.patch,
      char-export-module_device_tables.patch, input-export-module_device_tables.patch
      were deleted instead of being moved into the purgatory dir. Add them back in
      the expected location.
    - Fix apparmor boottime flag handling
    - scripts/create_quilt_tree: add a hack to support mainline patches

  + Thomas Backlund <tmb@mandriva.org>
    - update ndiswrapper Makefile fix to a more correct one
    - add missing viahss MODULE_LICENSE
    - update ndiswrapper to 1.53
    - update to 2.6.26-rc8
    - add dvb-core header files to -devel rpms so it's possible to build
      external dvb drivers without needing full source (#41418)
    - update Alsa to 1.0.17rc2
    - drop x86-xen-time-prevent-gcc-4.3-optimizations.patch (fixed differently
      upstream, commit: f595ec964daf7f99668039d7303ddedd09a75142)
    - update to 2.6.26-rc6-git3
    - disable CONFIG_USB_RIO500, as it will switch to libusb (#41504)
    - update Alsa to 1.0.17-rc1
    - fix HD-audio controllers inaccurate IRQ timing of PCM period updates.
      Needed for next version of PulseAudio (requested by Colin Guthrie)
    - add patch to adapt prism25 to new netdev structure
    - update prism25 to 0.2.9-r8159 and enable it
    - update defconfigs for unionfs
    - drop usb-fix-USB-Persist-suspend, it's fixed upstream in 2.6.26-rc1
      (commit 5e6effaed6da94e727cd45f945ad2489af8570b3)
    - remove the patch too
    - fix changelog
    - drop patch input-tablet-wacom-0.8.0 as it already is in 2.6.24-rc4
    - fix unionfs umount_begin for 2.6.26 series kernels
    - add unionfs 2.3.3 support back
    - drop net-usb-rndis_host-wm5-6.patch, fixed differently upstream
    - add support for WM5/6 devices (#30128)
    - Fix kernel-source symlinks if the kernel is installed after the
      source and no matching -devel- rpm is installed (#38862)
    - add fixes and addons from Alsa HG tree:
      * hda-codec fix ALC880 F1734 model
      * hda-codec fix automute of AD1981HD hp model
      * hda-codec fix wrong capture source selection for ALC883 codec
      * hda-codec fix ALC882 capture source selection
      * hda-codec clean up capture source selection of Realtek codecs
      * hda-codec implement auto mic jack-sensing for Samsung laptops with AD1986A
      * hda-codec more auto configuration fixups
      * hda-codec fix auto configuration of realtek codecs
      * hda-codec add IEC958 default PCM switch
      * hda-codec add more names to vendor list
      * hda-codec fix breakage of resume in auto-config of realtek codecs
      * hda-intel add ATI RV7xx HDMI audio support
      * hda-codec fix amp-in values for pin widgets
      * hda-codec fix missing capsrc_nids for ALC262
      * hda-codec add support for AD1883, AD1884A, AD198A, q984B
      * hda-codec add model=mobile for AD1884A
      * intel8x0 add support for 8 channel sound
      * hda-codec fix master volume on HP dv8000
      * bt87X fix freeing of shared interrupt
      * hda-codec fix ALC662 recording
      * hda-codec fix ALC268 capture source
      * hda-codec fix STAC927x power management
      * hda-codec fix STAC927x invalid association value
      * hda add PCI_QUIRKS for laptops with 92HDxxxx codecs
      * hda STAC927x support analog mic
      * seq_oss_synth remove invalid bug()
      * hda-codec add missing descriptions for STAC codec models
      * hda-codec adapt eeepc p701 mixer for virtual master control
      * usb-audio add workaround for broken E-Mu frequency feedback
      * usb-audio sort quirks list
      * sb8 fix sb 1,0 capture DMA programming
      * hda-codec fix AD1988 capture elements
      * hda-codec add Fujitsu Lifebook E8410 to quirk table
      * hda-codec fix initial DAC numbers of 92HD71bxx codecs
      * oxygen add owner field
      * hda-codec add docking station mic input for Thinkpad X61
      * hda-codec fix names of realtek codecs to adapt master controls
      * intel8x0 add quirk for Compaq Deskpro EN
      * hda-sigmatel disable power management on fixed ports
      * hda-sigmatel add verbs for 92hd73xxx laptops
      * hda-codec fix array over-range access with stac92hd71bxx codec
    - add usb hid quirk for Multilaser USB-PS/2 keyboard adapter (#36870)
    - update wacom tablet to 0.7.9-8 (#37073)
      * bugfixes, adds support for Wacom Cintiq 20WSX
    - update acer_acpi to 0.11.1
    - add Prism2 support back (#38155)
    - update ndiswrapper to 1.52
    - enable PANTHERLORD_FF and ZEROPLUS_FF (#38213)
    - add creator info to specfile as requested by Luiz
    - spec changelog fix
    - o Pascal "Pixel" Rigaux <pixel@mandriva.com>
      - use %%manbo_mkrel for Manbo Core 1
      - rename %%mdvrel into %%mnbrel
      - get rid of %%mkrel usage (using plain release with no distsuffix)
      - replace (old) versioned buildrequires with plain buildrequires
      - %%ktag is now mnb
    - update Wacom tablet support (#37073)
      * adds support for: Bamboo1, BambooFun and Cintiq 12WX
    - disable CONFIG_USB_OHCI_HCD_SSB so ssb wont get loaded even if it
      is blacklisted (reported by AdamW on kernel-discuss)
    - add compal-laptop driver (#37860)

  + Anssi Hannula <anssi@mandriva.org>
    - do not remove modules.* before calling depmod in %%install (fixes
      missing modules.order file)

  + Pascal Terjan <pterjan@mandriva.org>
    - Obsolete kernel-laptop-latest in kernel-desktop-latest
    - Rediffed acpi-asus-eee.patch
    - Rediffed acpi-asus-eee.patch
    - revert last commit
    - Too late for this release
    - Add a changelog entry for previous commit
    - drop media-usbvideo-device-link.patch, merged upstream
    - fix a crash in uvcvideo on X300 (upstream r199)
    - drop ipt_time patch, xt_time was now included
    - Set correct model for TOSHIBA Satellite Pro A200 and A210
    - asus_acpi: Fix brightness handling on EeePc
    - iwlwifi: Initialize rf_kill status
    - Don't break ACPI support when the child of a video bus device is not a video device (kernel bug #9761)
    - Fix the previous patch
    - Rewrite patch for Asus ACPI keys (#23741)
    - Alsa (snd-hda-intel) : Set correct model for Sony Vaio VGN FZ18M
    - Generate input events for ACPI hotkeys in asus-laptop and autoload it instead of asus_acpi (#23741)
    - Fix asus_acpi patch, latest commit broke keys handling
    - Don't pollute logs when using brightness or wiki keys on EeePc
    - Remove the bug number, I got confused with other webcam bug
    - Add a device link in video4linux/video*/ else hal don't see them
    - Add a new id for rt2500usb (#38512), and fix the changelog
    - Update the asus_acpi patch for EeePc :
    - Have the mute and volume keys generate input events
    - Use the [AP] (fn+f6) key to enable/disable the webcam
    - Don't handle wireless switching, we didn't do anything anyway
    - It's actually a Provides which is needed, not a Suggests
    - Add missing entry in changelog
    - Fix sound on NEC S970
    - Suggest restarting the system after installing a new kernel
    - Use rpmbuild instead of rpm in our Makefile
    - added NF_MATCH_TIME support

  + Olivier Blin <blino@mandriva.org>
    - update changelog
    - fix typo
    - make kernel-<flavour>-devel-latest provide kernel-devel-latest (#36524)

  + Shinji Makino <shinji@turbolinux.co.jp>
    - bugfix to unicon startup problem. bug#37928
    - usb-storage-unusual_devs-add-id.patch add(TL)
    - add to tomoyolinux patches(TL patches)
    - change smp power off patch(TL patches)
    - fix diff flie video-char-enable-unicon.patch(TL patch)

* Mon Feb 11 2008 Thomas Backlund <tmb@mandriva.org> 2.6.24.2-1mdv2008.1
+ Revision: 165122
- update to 2.6.24.2 (CVE-2008-0600)
- add selected fixes from alsa HG tree:
  * sound-soc-fix-duplicate-rj-master-test.patch
  * sound-hda-intel-Fix-PCM-device-number-assignment.patch
  * sound-hda-codec-Add-ID-for-HDMI-codec-on-Jetway-J9F2.patch
  * sound-ice1712-Fix-hoontech-MIDI-input.patch
  * sound-hda-STAC927x-power-down-inactive-DACs.patch
  * sound-hda-intel-use-SG-buffers.patch
  * sound-hda-intel-support-64bit-buffer-allocation.patch
  * sound-ice1712-add-support-for-Delta1010E.patch
  * sound-ice1712-all-support-for-Delta-66E.patch
  * sound-hda-intel-Fix-compile-error-with-CONFIG_SND_DEBUG_DETECT.patch
  * sound-hda-codec-correct-HDMI-transmitter-names.patch
  * sound-hda-codec-remove-duplicate-controls-in-alc268-test-mixer.patch
- update alsa to 1.0.16 final
- drop mm-zerolen-iov-fix.patch (merged upstream)
- update to 2.6.24.1
- disable inclusion of s390 file in sysctl_check as we dont ship arch/s390
  files in our kernel-source (#37388)
- update alsa to 1.0.16rc2 + alsa-git-2008-01-31
- add sched cpu_share tunable crash fix (Mingo, LKML)
- update alsa to 1.0.16rc1
- drop sound-Fix-5.1-sound-in-Dell-6stack-ALC888-HDA.patch (merged upstream)
- update to 2.6.24-rc8-git5
- make 32bit kernels conflict arch(x86_64) so they cant be installed
  by mistake (#32631)
- disable XEN Guuest support on all but server kernels as it breaks AGP support (#36458)
- add support for Dell i8k on x86_64 (#32447)

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Added updated AppArmor patches for 2.6.24 (thanks to John Johansen at
      Suse for them).
    - Fix some changelog release entries.
    - Updated uvcvideo to svn r173 (and removed already applied
      3rd-uvc-stream-no-fid.patch).
    - Updated nozomi driver patch with version added recently to Linus
      tree (pre 2.6.25, commit 20fd1e3bea554620d489f3542496639c1babe0b3,
      char-nozomi-driver.patch).
    - Updated uvcvideo to r166.
    - Replaced previously added sync quirk for Syntek webcam with a better
      version, that avoids losing sync of frames by using reported EOF
      marker. For more details see:
      https://lists.berlios.de/pipermail/linux-uvc-devel/2008-January/002779.html
      (final patch by Laurent Pinchart)
    - Added fix for isochronous transfer bug in ehci-hcd, adding patch from
      http://bugzilla.kernel.org/show_bug.cgi?id=7694
      I experienced the same issue but when using uvcvideo with a Syntek
      webcam (174f:5212), after some time the streaming fails with
      -EL2NSYNC. The patch there fixed the problem.
    - Modified kernel configs:
      * i386.config: enabled USB_EHCI_ROOT_HUB_TT (y) and
                     USB_ISP116X_HCD (m).
      * x86_64.config: likewise, and also enabled
                       CONFIG_USB_SL811_HCD (m) and
                       CONFIG_USB_SL811_CS (m).
    - Minor typo fix in changelog.
    - Added patch from Claudio S. Matsuoka that fix 5.1 sound in Dell 6stack
      ALC888 HDA, currently used in Dell Inspiron 530
      (sound-Fix-5.1-sound-in-Dell-6stack-ALC888-HDA.patch)
    - Renamed alsa-mm-git-2008-01-04.patch to
      sound-alsa-mm-git-2008-01-04.patch
    - 3rdparty addition: AuthenTec AES2501 Fingerprint Sensor Driver for
      Linux. Added in tree build support and oops on module removal fix when
      device isn't available:
      3rd-aes2501-kbuild.patch
      3rd-aes2501-rmmod-oops-fix.patch

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Move the following patches into the 'patches-purgatory' dir:
      block-cciss-ioctlret.patch, block-scsi_ioctl-GPCMD_SEND_KEY.patch,
      pci-pciaddress-64bit-fix.patch, usb-storage-unusual_devs.patch,
      char-export-module_device_tables.patch,
      input-export-module_device_tables.patch
    - Move Tomoyo patches into patches-purgatory
    - Drop kernel-export-machine_restart.patch
      It's not legal to change code's license w/o the author's agreement.
    - SLIENT: Remove 3rd-gspcav from series files
    - Introduces README document
    - Introduces patch-format.txt
    - Introduces managing-patches.txt document
    - Introduces create_quilt_tree script
    - Introduces PATCHES/Documentation directory
    - Introduces kernel-build-svn-checkout.txt document
    - Fix unionfs OOPS when umounting root partition when there's a nfs volume
      in the branch
    - Enable PREEMPT_BKL for -desktop kernels (i386 and x86_64)
    - Enable TIPC network protocol for i386
    - Enable all CONFIG_TASKSTATS options for i386 and x86_64
    - Move all (but net-sis190-sis968.patch) back to patches,
      net-sis190-sis968.patch is already in 2.6.24
    - Remove badram patch from patches-broken (there's no up to date version
      for 2.6.24, we can add it later if needed)
    - Update unionfs to 2.2.2
    - Update to 2.6.24
    - Fix apparmor disable flag (apparmor doesn't work yet though #36004)
    - Fix ipt_IFWLOG user-space header (#37082)
    - Update to 2.6.24-rc8-git1
    - Update to 2.6.24-rc8
    - Use kgit support in the spec
    - Update to 2.6.24-rc7-git5

  + Shinji Makino <shinji@turbolinux.co.jp>
    - delte of 3rd-gspca.tar and 3rd-gspcav-kbuild.patc.
    - commit of Turbolinux patches

  + Pascal Terjan <pterjan@mandriva.org>
    - Add patch by Nick Piggin fixing pan going unkillable (#37050)
    - Added Intel(R) 82575 Gigabit Ethernet driver (igb)
    - Fix Makefile when KPATCH is defined

* Mon Jan 07 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.24-0.rc7.1mdv2008.1
+ Revision: 146220
- Enabled SND_HDA_POWER_SAVE (Aggressive power-saving feature of
  snd-hda-intel), and keep the default Kconfig choice of automatic
  power-save mode (disabled = 0).
- Updated alsa to latest hg/git tree, mostly because of bug fixes and
  hda-intel updates, so we can test it early. Reverted some commits
  though so we can still use userspace lib/utils from alsa 1.0.15, if
  some revert is missing it's a bug.

  + Thomas Backlund <tmb@mandriva.org>
    - update to 2.6.24-rc7
    - update to 2.6.24-rc6-git12
    - more spec cleanups
    - use make clean on -devel & source tree to not ship unneeded files
    - move defcofigs to the correct location for i386 and x86_64, prefix
      them the same way as upstream, and drop defconfig-maximum
    - fix build,source symlinks to -source tree to be created only if no
      matching -devel tree is installed, and to be removed only if they
      point at the -source tree
    - change url to Mandriva wiki

* Fri Jan 04 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.24-0.rc6.3mdv2008.1
+ Revision: 144877
- Change changelog entry for release.
- Updated to 2.6.24-rc6-git10
- Updated to 2.6.24-rc6-git9, rediffed irq-debug-shared.patch
- Update unionfs again, now to version 2.2.1
- Added back apparmor for 2.6.24 from Suse (with minor patch changes in
  hunks that touch reiserfs code, as it didn't apply by default because
  our reiserfs differs. Also needed to fix build when cgroups is
  enabled).
- Brought back and redid patch to fix build of unionfs with apparmor.
- Renamed kernel-2.6.spec to kernel.spec
- Renamed kernel-2.6 entry to kernel, to be consistent with package
  name (see '[RFC] SRPMS not in SVN' thread on maintainers ML).
- Build genrtc as module now that Mandriva's udev is now creating
  automatically the /dev/rtc symlink pointing to /dev/rtc0, making
  possible using /dev/rtc from one of the modules from new modular rtc
  framework (Reported/pointed by Dick Gevers and Andrey Borzenkov on
  cooker ML).
- Updated uvcvideo to svn r158
- Add new sync quirk to uvcvideo and use it (needed by Syntek 174f:5212
  webcam), from Claudio S. Matsuoka <cmatsuoka@gmail.com>
- Prevent uvcvideo to alloc too much memory in usb_buffer_alloc,
  lowering UVC_MAX_ISO_PACKETS. In machines with not much memory webcam
  that uses isoc transfers, several calls to it can cause memory
  fragmentation or requesting too much memory resulting in an Page
  Allocation Failure (OOM). UVC_MAX_ISO_PACKETS is arbitrary, see
  http://article.gmane.org/gmane.linux.drivers.uvc.devel/1956
- Updated to 2.6.24-rc6-git5

  + Thomas Backlund <tmb@mandriva.org>
    - fix Makefile to match renamed module/spec
    - update alsa krpovides
    - update source2 to apply cleanly
    - update unionfs to 2.2
    - dont ship prebuilt module in tarball
    - correct git path

  + Pascal Terjan <pterjan@mandriva.org>
    - Add support for EeePc in asus_acpi
    - Add mactel patches (#35420)

* Tue Dec 25 2007 Thomas Backlund <tmb@mandriva.org> 2.6.24-0.rc6.1mdv2008.1
+ Revision: 137791
- prefix 3rdparty tarballs with 3rd- to match the new patch naming scheme
- update acer_acpi to 0.10
- update drbd to 8.0.8
- update ndiswrapper to 1.51
- update defconfigs
- remove video patch applied upstream
- update to 2.6.24-rc6-git2
- add support for upstream -git tarballs
- update to 2.6.24-rc6
- fix weburl to update instructions
- fix -devel rpm breakage due to i386/x86_64 merge into x86
- add /drivers/lguest/lg.h to -devel rpms

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Pascal Terjan <pterjan@mandriva.org>
    - Add forgotten file
    - Switch atl2 to 2.0.3, which is the branch aiming at upstream merge
    - Fix TI PCIxx12 card readers (#35887)
    - Use hid blacklist in usbmouse/usbkbd (fixes Wacom tablets)
    - Fix a typo in PrepareKernel

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - scripts/apply_patches: usage message fixes.
    - Removed already applied upstream alsa quirk for Dell XPS M1330.
    - Updated uvcvideo to r149, and removed already applied
      3rd-uvcvideo-add-quirk-ali-5606.patch
    - Fix return type of write file_operations callback functions in
      tc1100-wmi.
    - One more api fix for ipset on 2.6.24.
    - Fix build with ndiswrapper.
    - Changelog typo fix.
    - More netfilter api fixes for ipt_set and ipt_psd for 2.6.23 and later.
    - Updated ndiswrapper to version 1.50rc3.
    - Enabled XEN guest, suggested by Olivier Blin
      (http://archives.mandrivalinux.com/kernel-discuss/2007-11/msg00033.php).
    - Regenerate configs against lastest sources.
    - Added quirk for uvcvideo, needed by the webcam found on Clevo M540SR
      (ALi 5606).
    - Updated to 2.6.24-rc2-git3.
    - Updated unionfs to 2.1.9.
    - Updated to 2.6.24-rc2-git2.
    - Rediffed patches:
      130-netfilter-ipset.patch
      netfilter_IFWLOG.patch
      netfilter_psd.patch
    - Updated to 2.6.24-rc2.
    - scripts/create_configs: updates for i386/x86_64 arch unification;
      kernel-2.6.spec: likewise.
    - package Makefile: deal with kpatch field inside spec, to create the
      patches tarball with the correct name when it's used.
    - Updated acer_acpi to 0.10_rc4, and added needed build fixes/updates
      for 2.6.24-rc2:
      acer-acpi-extra-cflags.patch
      acer-acpi-match-dmi_system_id-callback.patch
    - Removed ipw3945, now use the iwl3945 in upstream kernel, if required
      in the case iwl doesn't work well for some devices we can readd it.
    - Updated squashfs to version 3.3, dropped already applied/obsolete
      squashfs-add-missing-include, squashfs-inode-fix,
      squashfs-2.6.23-buildfix patches.
    - Updated 3rdparty_merge patch for 2.6.24-rc2.
    - Updated unionfs to version 2.1.8, builds with new kernel andalso has a
      fix for a self deadlock issue reported here:
      http://www.fsl.cs.sunysb.edu/pipermail/unionfs/2007-October/005536.html
    - Drop BadRAM patch until we fix it or a new version for 2.6.24 is
      available.
    - Made needed fixes for misc build/code issues required now on
      2.6.24-rc2 for extra patches/3rdparty additions:
      * ndiswrapper: ndiswrapper-proc_net-namespace.patch
                     ndiswrapper-new-napi-polling.patch
                     ndiswrapper-remove-set_module_owner.patch
                     ndiswrapper-extra-cflags.patch
      * acx: acx-remove-set_module_owner.patch
      * acerhk: acerhk-extra-cflags.patch
      * drbd: drbd-8.0.6-linux-2.6.24-fixes.patch
      * ppscsi: ppscsi-sg-helper-update.patch
      * netfilter_IFWLOG: netfilter_IFWLOG_2.6.24.patch
      * uss725: uss725-sg-helper-update.patch
                uss725-avoid-ide-fix-driveid.patch
        the uss725-sg-helper-update.patch makes
        uss725_revert_sg-address_removal.patch unecessary,
        so it was removed
      * atl2: atl2-linux-2.6.24.patch
    - Updated mach64 drm support for 2.6.24-rc2.
    - Updated uvc to r141 svn snapshot.
    - Updated apparmor patches to build again with 2.6.24-rc2, but I'm not
      sure if it still works, need more testing and probably more changes. I
      had to revert too some upstream changes that make LSM a static
      interface, it would be good to check the changes more in detail and
      migrate more apparmor bits, seems it can't be a module anymore.
    - Dropped ralink legacy drivers, keep now only the mac80211 ones
      integrated in linus kernel, if in the future we see we still need them
      we can readd.
    - Drop already applied patches:
      zd1211rw-more-ids
      ALSA-hda-codec-Fix-input_mux-numbers-for-vaio-st
      alsa-hg5424
      ipg
      i386-add-support-for-picopower-irq-router
      alsa-hg5408
      alsa-git-20070912
      alsa-hg5432
      alsa-hg5436
      alsa-fix-sound-oops-dell-xps-m1210
      ALSA-hda-codec-Fix-for-Fujitsu-Lifebook-C1410
      ueagle-atm-patches-eagle-iv-support
      alsa-hg5416
    - Rediffed patches:
      Toshiba_Equium_A60-needs-pci-assign-busses
      boot-video-80x25-if-break.patch
    - Enabled CONFIG_DEBUG_BUGVERBOSE option on configs where it was
      disabled, it's useful despite some more ram usage, see
      http://archives.mandrivalinux.com/kernel-discuss/2007-11/msg00006.php
      (Suggested by Olivier Blin).
    - Added fix from Erez Zadok for unionfs self deadlock issue:
      http://www.fsl.cs.sunysb.edu/pipermail/unionfs/2007-October/005536.html

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Minor changelog fix
    - Upgrade to 2.6.24-rc5-git2
    - Minor changelog typo fix
    - Upgrade unionfs to 2.1.11
    - Update to 2.6.24-rc5
    - Update to 2.6.24-rc4-git2 (#35822)
    - Reorganize series file
    - Better names for netfilter patches
    - New patch naming scheme: now patches have the following format:
      subsystem-description.patch. A detailed documentation will be provided
      shortly.
    - Kill patches-to-drop directory: that directory exists for a long time
      and its patches seems to not be useful
    - Update to 2.6.24-rc4
    - Add missing changelog entries
    - Update etfilter-IFWLOG-mdv.patch to v1.1
    - Better multicast group usage
    - Coding style fixes
    - Do not return -EINVAL by default in ipt_ifwlog_init()
    - Minor refinements
    - Merge ipt_IFWLOG patches into netfilter-IFWLOG-mdv.patch
      Currently, we're adding a new patch to fix every single API change
      in the netfilter subsystem.
      This doesn't scale and add a bit of overhead (think of updating four
      or five patches on a kernel update).
      Instead of doing this, we're adding a new patch
      (netfilter-psd-mdv.patch) which holds the Mandriva changes.
      As we're just doing API updates, you can think of this patch as being
      a new version of the ipt_IFWLOG module.
    - Merge ipt_psd patches into netfilter-psd-mdv.patch
      Currently, we're adding a new patch to fix every single API change
      in the netfilter subsystem.
      This doesn't scale and add a bit of overhead (think of updating four
      or five patches on a kernel update).
      Instead of doing this, we're adding a new patch
      (netfilter-psd-mdv.patch) which holds the Mandriva changes.
      As we're just doing API updates, you can think of this patch as being
      a new version of the ipt_psd module.
    - Update to 2.6.24-rc3-git6
    - Reset version (preparing to release)
      This also removes the 'git' name from the package name
      because I couldn't find a nice way to have it w/o breaking
      RPM's comparision. But this is a -git snapshot kernel.
    - Update to 2.6.24-rc3-git1
    - Move AppArmor patches to patches-broken directory, the -rc updates
      broke it
    - Upgrade to 2.6.24-rc3
      NOTE: It's not building yet, commiting now so that other people
      can help.
    - Kill PATCHES/doc directory
      The documentation in that directory is quite old and not usefull.
      New documentation will be put in kernel's Documentation/mandriva
    - fix ipt_psd netfilter API usage
    - Kill naming_patches
      That document describes a very old naming scheme which is
      not longer used.
    - Introduces patches-broken directory
      Patches broken not supposed to be dropped should be moved into
      patches-broken dir.

* Wed Oct 31 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.6.23.1-1mdv2008.1
+ Revision: 104219
- Fix ndiswrapper tarball for x86_64 build (add missing win2lin_stubs.h
  file).
- Updated to 2.6.23.1, and prepare to release.
- apply_patches: remove reference for Juan Quintela's now invalid email
  address (reported by Thierry Vignaud).
- Drop prefixes for all remaining patches that still used them, now that
  we don't need this anymore. Also fix placement of some patches inside
  series file.
- Switch from SLAB to SLUB on all kernel configs, SLUB is the default
  since 2.6.23.
- Updated kernel changelog in spec for changes in the latest two
  commits.
- Fix unpackaged files.
- Updated to version 2.6.23.
- Added updated BadRam patch for 2.6.23.
- Updated ndiswrapper to version 1.49.
- Updated unionfs to 2.1.7; redid fix-unionfs-build-with-AppArmor
  patch because of it, and removed already applied
  unionfs-2.1.3-do-not-update-mtime-if-no-upper-branch patch.
- Added updated version of nozomi patch from gregkh git repository.
- Updated tc1100-wmi module patch for 2.6.23, and made fix for acpi
  subsystem updates (tc1100-wmi-2.6.23-fixes patch). Also removed
  uneeded tc1100-wmi-depends-ACPI_INTERPRETER patch.
- Updated mach64 drm module for 2.6.23.
- Added updated apparmor patches that apply on 2.6.23 from kernel-tmb.
- Redid patches:
  pnpbios-off-as-default
  acpi_fix_double_video_proc_entries
  sis190-sis968
  boot-video-80x25-if-break
- Added squashfs fix for 2.6.23 from kernel-tmb.
- Added Revert-Revert-intel_agp-fix-stolen-mem-range-on-G patch, we
  don't need the upstream revert commit because our
  x11-driver-video-intel already has a patch for that change on kernel.
- Added ipset 2.6.23 fixes from kernel-tmb (ipset-2.6.23-buildfix,
  ipset_2.6.23-buildfix2 patches).
- Fix atl2 module building on 2.6.23 (atl2-linux-2.6.23 patch).
- Drop already applied changes from ueagle-atm-patches-eagle-iv-support
  patch (and the diff is now from upstream linus git tree).
- create_configs: update for NOHIGHMEM case, probably there is a bug in
  Kconfig selection now that asks for X86_PAE.
- Remove already applied patches:
  USB-option-Add-a-new-device-ID-for-the-HUAWEI-E220
  PCI-Run-k8t_sound_hostbridge-quirk-only-when-needed
  sata_mv-PCI-IDs-for-Hightpoint-RocketRaid-1740-1742
  pata_marvell-Add-more-identifiers
  add-eeprom_93cx6-support
  b44-updates
  r8169_link_down_fix
  pci-fix-unterminated-pci_device_id-lists
  alsa-git-2007-07-20
  PCI-unhide-SMBus-on-Compaq-Deskpro-EP-401963-001-mo
  ipw2100-updates
  ext34_orphan_list_corruption_fix
  ipaq_htc_smartphones_support
  ACPI-dock-use-dynamically-allocated-platform-devic
  i386-do-not-restore-reserved-memory-after-hibernati
  drm-via-Fix-dmablit-when-blit-queue-is-full
  jmicron-PIO-fixes
  smbus_sb800_support
  fix_ENE_CB712-4_card_readers
  libata-clean-up-horkage-handling
  ACPI-dock-cleanup-the-uid-patch
  ata_piix-fix-pio-mwdma-programming
  myri10ge-Add-support-for-PCI-device-id-9
  usb-misc-sisusbvga-add-product-ID-of-TARGUS-MCT-dev
  hid_fix_autocentering_of_pid_devices
  unusual-devs-updates
  intel-agp-Fix-i830-mask-variable-that-changed-with
  acpi-battery-updates
  acpi-ec-updates
  USB-option-Add-Dell-HSDPA-5520-to-driver
  intel-agp-945_965_GME-G33-fixes
  mac80211-updates
  zd1211rw-updates
  ipw2200-updates
  ext34_orphan_list_check
  agp-Add-device-id-for-P4M900-to-via-agp-module
  rtl8187
  smbus_sb700_support
  libata-ahci-add-ATI-SB800-PCI-IDs
  USB-cdc-acm-add-new-device-id-to-option-driver
  pata_it821x-fix-lost-interrupt-with-atapi-devices
  pata_cs5520-Fix-probe-bug-regression-introduced-in
  add-wacom-bamboo-tablet-support
  libertas-updates
  PCI-pci_ids-add-atheros-and-3com_2-vendors
  debugfs_rename
  ata_piix-IDE-mode-SATA-patch-for-Intel-Tolapai
  USB-visor-add-ACER-S10-palm-device-id
  USB-ftdi_sio-add-of-a-new-product-manufacturer-TM
  USB-fix-support-for-Dell-Wireless-Broadband-aka-WW
  Fix-broken-pata_via-cable-detection
  libata_broken_hpa_horkage
  eeprom-93cx6-misc-fixes
  PCMCIA-NETDEV-add-new-ID-of-lan-modem-multifunctio
  pata_sis-fix-MWDMA-for-UDMA66-chipsets-and-UDMA
  forcedeth-mac-address-correct
  cdc-subset-to-support-new-vendor-product-ID
  libata-IDE-add-new-VIA-bridge-to-VIA-PATA-drivers
  airo-updates
  forcedeth-mcp73-support
  Add-the-Osprey-440-to-the-Bt878-ALSA-whitelist
  pata-hpt-clock-fixes
  Fix-sata_via-write-errors-on-PATA-drive-connected-to
  genetlink-dynamic-multicast-groups
- Removed hrtimer patches, already applied or not relevant anymore.
- Removed custom kvm, use the one from 2.6.23.
- Remove swap prefetch patches, as they don't apply and aren't
  maintained anymore, also dropped on mm (see thread on lkml).
- Moved marvell-ide to patches-to-drop. Because of many ide subsystem
  changes it doesn't apply anymore, and we have already pata_marvell so
  for now it's not critical. We can fix it later if desired.
- Removed some mac80211 wireless drivers that were pushed from old
  wireless-dev tree. We will update later to 2.6.24 that have them, and
  if some driver is still missing we just readd them later.
- Removed CFS v22 patch, 2.6.23 already have CFS, not with all changes
  but we will update later to 2.6.24 that has all features from v22
  patch.
- Removed e1000_7.6.5 patch, we need to check later after update to
  2.6.24 if stock e1000/e1000e is sufficient or if we need to add back
  the driver from intel.
- apply_patches:
  * introduce a different scheme to process patches: really use
    series file now, taking the patches in their order. With this we
    can drop the confusing prefixes that anyone knows for sure their
    meaning in all cases. Also use 3rdparty.series file to add third
    party additions, in the same way as series, this way we can
    document/comment third party additions inside it. It's separated
    from series file so we can use quilt for the patches;
  * fix usage output;
  * make sure no patches are forgotten in patches directory, if a
    patch or 3rdparty addition isn't listed in
    3rdparty.series/series exit with error.
- apply_patches: remove trailings spaces, fix tabs vs. spaces.
- Parallelize xargs invocations for smp machines on rpm build.
- Fix kernel-laptop description for now because of latest commit,
  reported by Thomas Backlund.
- Change laptop flavour to use CONFIG_HZ = 300. Turns out that HZ = 100
  is too low for interactivity, and on laptops it seems it's not worth
  the extra economy of energy (for example, with HZ = 100 there are too
  many audio skips in some applications/games). Reported by Andreas
  Hasenack, and Acked by Luiz Capitulino. We could choose HZ = 250, but
  300 is a bit better in interactivity/less latency and not much a
  difference anyway. And note that accordingly to Len Brown et al paper here:
  http://ftp.kernel.org/pub/linux/kernel/people/lenb/acpi/doc/OLS2006-bltk-paper.pdf
  CONFIG_HZ has a small impact on power consumption on idle workloads,
  so we could even start to think of selecting a HZ = 1000 value for
  laptops where interactivity/less latency is also important (when
  CONFIG_NO_HZ is also available on x86_64 we can switch).
- Removed already applied/removed patch from series file.
- Added upstream alsa patch to fix sound issues on Fujitsu-Siemens C1410
  (#34555).
- Removed unwanted piece of changelog from cooker's kernel (changed by
  mistake on r98299).
- Updated uvcvideo module to svn-r133 (#34772).
- Remove ati hdmi id patch for rv610/630, accordingly to feedback on
  #34545 it isn't sufficient to work, just revert the modification for
  now.
- Attansic/Atheros(R) L2 isn't a gigabit chip, fix kbuild/changelog.
- Added upstream alsa bugfix: hda-codec - Fix input_mux numbers for vaio
  stac92xx.
- Added proper fix for oops on Dell XPS M1210 (not a workaround
  anymore), after feedback and discussion upstream (patch from Takashi
  Iwai).
- Add ids for alsa atihdmi support of ATI HD2400/HD2600 integrated sound
  devices (#34545).
- Add ipg module from netdev tree (IC Plus IP1000 Gigabit Ethernet
  Adapter).
- Added patch from Emmanuel Andry that adds support for OXCB950 Cardbus
  16950 UART (#33821).
- Forgot to add patches to series file in last commit.
- Added Attansic(R) L2 Gigabit Ethernet Adapter driver (#34281).
- Fix changelog: for some reason I hit the same problem again when
  compiling some stuff on the 8 processor machine cited previously :(. I
  need to investigate more. Also really the problem only showed up
  previously with CFS applied, but probably it helps trigger the issue
  and is not a fault in its code. Sometimes OOM killer is run with
  apparently no reason, and I only experience this on that machine. This
  was the removed changelog part, related to CFS update to v22:
  "This was needed because of a bug discovered in the previous included
   version (20.5), in some situations it would trigger OOM killer in a
   high memory usage scenario without need (still memory available for
   use). This was discovered while trying to compile kdepim in a 8
   processor machine with 8GB of ram available."
  So OOM killer issue still happens, and still under investigation on
  the same machine, but the CFS update changed behaviour in some way
  that makes the problem less likely. With previous CFS version I always
  reproduced OOM killer condition with a kdepim build.
- Updated CFS to version 22. This was needed because of a bug
  discovered in the previous included version (20.5), in some
  situations it would trigger OOM killer in a high memory usage
  scenario without need (still memory available for use). This was
  discovered while trying to compile kdepim in a 8 processor machine
  with 8GB of ram available.
- Fixed mach64 drm support: the existing patch had its build
  disabled because of a bug, and also was broken. Replaced the patch
  with fixed ones (#34473).
- Updated status of patch
  DU22_Add-quirk-broken-ISOC-KY-BT100-Bluetooth-Adapter.patch
- Alsa: fix sound issues on Dell XPS M1210 and M1330 models.
- Revert last commit, disable BadRAM on x86_64 as support for it isn't
  complete yet.
- like on i386, enable BADRAM support too for x86_64 config, reported by
  Per ?\195?\152yvind Karlsen.
- x86_64 config:
  * enable p4-clockmod module, reported by Per ?\195?\152yvind Karlsen;
  * enable abit uguru sensors module.
- Add upstream fix "libata: clean up horkage handling". Probably needed
  to really fix #32076, and we must apply it anyway after adding
  BROKEN_HPA horkage support patch. Some parts were rediffed from
  original 2.6.23 patch because of unrelated code changes.
- Add quirk to disable ISOC transfers for device
  "ID 1131:1001 Integrated System Solution Corp. KY-BT100 Bluetooth
  Adapter" (#30638).
- bcm43xx: fix log flooding with ifplugd when firmware is not
  available (#33969).
- Add the MCP79 support to hda_intel driver, from alsa hg repository
  (reported by Thierry Vignaud).
- Fix build with build_doc enabled.
- Enable build of kernel-doc package, reported by Pacho Ramos on Cooker
  ML.
- Fixed /usr/src/linux symlink check when removing kernel-source
  package, as reported by Andrey Borzenkov on kernel-discuss ML.
- Included ipw3945 in kernel: as reported by many users works better
  than current iwl3945 we use, and we can keep both with current
  mandriva ldetect/module-init-tools (preferred aliases). As talked with
  Olivier Blin seems the better approach right now. Also ipw3945 is
  version 1.2.1 and not newer 1.2.2 because it has some development
  changes and I couldn't test it yet, 1.2.1 seems safer now for 2008.0.
- Updated to 2.6.22.7, security fix only release (CVE-2007-4573).
- Removed Makefile hunk from sched-cfs-v2.6.22.5-v20.5 patch, it
  conflicts with update to 2.6.22.7 and we don't use the modification
  anyway as we overwrite EXTRAVERSION inside spec.
- More changes from 2.6.23-rcX:
  * libata: Update the blacklist with a few more devices;
  * ahci: add ATI SB800 PCI IDs;
  * myri10ge: Add support for PCI device id 9.
- Add d36ee189f392ea89de85124a0b58477bb0f2e0a6 from git:
  "pata_marvell: Add more identifiers".
- Added upstream 2.6.23 fix "i386: Use global flag to disable broken
  local apic timer on AMD CPUs". This seems to fix a real issue here,
  without this patch a turion laptop gets apic/interrupt errors and misc
  kernel panics.
- Upstream bugfixes from 2.6.23-rc7:
  * intel-agp: Fix i830 mask variable that changed with G33 support;
  * pci: fix unterminated pci_device_id lists.
- Alsa: Add missing support ASUS A7J (from alsa repository, commit
  id 5432, reported by Thierry Vignaud).
- More changelog fixes.
- Fixed merge of some changelog entries.
- jmicron: PIO fixes (thanks to Thierry Vignaud for pointing this), can
  fix #33043.
- Added upstream ata_piix fix for pio/mwdma programming.
- Upstream bugfixes/enhancements (already in 2.6.23-rcX):
  * fmvj18x_cs, pcnet_cs: new ids of lan&multifunction cards (NEC
    PK-UG-J001, Panasonic CF-VML201 Panasonic TO-PDL9610,
    MICRO-RESEARCH MC336LAN);
  * sisusbvga: add product ID for Targus ACP50US;
  * run k8t_sound_hostbridge quirk only when needed;
  * unhide SMBus on Compaq Deskpro EP 401963-001 motherboard;
  * ftdi_sio: support new product based on the FTDI 232R USB/Serial
- Alsa hg updates:
  * add support for Asus M2A-VM HDMI and Abit IP35-PRO;
  * sc6000 minor fixes;
  * Dell laptop updates.
- Fix warning when deregistering acpi dock module (#32337). Added
  patches already upstream, thanks to Danny Tholen for tracking one
  of the commits.
- usb device additions (new id/support): Samsung X180 China cellphone,
  cdc subset support for Mavell vendor/product ID, HUAWEI E220 HSDPA
  modem, ACER S10 palm device (visor), Dell HSDPA 5520.
- drm/via: Fix dmablit when blit queue is full
  (http://bugs.freedesktop.org/show_bug.cgi?id=11542).
- VIA P4M900 support for via-agp
  (DV02_agp-Add-device-id-for-P4M900-to-via-agp-module.patch).
- forcedeth: don't rely on bios to get MAC address order, this fixes
  problems with broken bioses on some Asus boards (like M2N) and
  possibly others (DN06_forcedeth-mac-address-correct.patch).
- forcedeth: add mcp73 support (DN05_forcedeth-mcp73-support.patch).
- USB: fix support for Dell Wireless Broadband - aka WWAN
  (DU03_USB-fix-support-for-Dell-Wireless-Broadband-aka-WW.patch).
- usb storage: updates/additions to unusual_devs.h.
  DU21_nikon_d100_unusual_dev_entry.patch,
  DU22_nikon_d50_unusual_dev_entry.patch and
  DU23_nikon_d80_unusual_devs_update.patch
  merged into:
  DU02_unusual-devs-updates.patch
  with more device additions.
- pata_cs5520: fix probe bug regression introduced in 2.6.22
  (DB10_pata_cs5520-Fix-probe-bug-regression-introduced-in.patch).
- sata_mv: add pci ids for Hightpoint RocketRaid 1740 and 1742
  (DB09_sata_mv-PCI-IDs-for-Hightpoint-RocketRaid-1740-1742.patch).
- more pata_hpt{37x|3x2n} clock fixes (removed
  DB34_pata_hpt37x_clock_ppl_regression_fix.patch, merged into
  DB08_pata-hpt-clock-fixes.patch).
- ata_piix: add sata support for Intel Tolapai
  (DB07_ata_piix-IDE-mode-SATA-patch-for-Intel-Tolapai.patch).
- pata_it821x: fix lost interrupt with atapi devices
  (DB06_pata_it821x-fix-lost-interrupt-with-atapi-devices.patch).
- pata_sis timing fixes
  (DB05_pata_sis-fix-MWDMA-for-UDMA66-chipsets-and-UDMA.patch).
- Updated alsa subsystem again, with more bugfixes and new hardware
  support, matches closely alsa 1.0.15rc2 (closes #33489). Also removed
  DA02_hda-intel-codec-detection.patch already in added
  DA03_alsa-git-20070912.patch
- Fix broken pata_via cable detection (from upstream like previously
  added patches).
- 945/965GME and G33 intel-agp fixes.
- Added PATA support for VIA VX800.
- Added upstream bugfix for DMA mode on VT6421 PATA port.
- ATA device blacklist additions (drives with NCQ/DMA issues).
- Removed some patch entries from series file that I forgot earlier when
  removed the patches.
- Added back wireless acx driver (#31539). Thanks to Adam Pigg and Adam
  Williamson for pointers and help.
- We need to set I2O_EXT_ADAPTEC_DMA64 when using HIGHMEM64 on i386.
- create_configs (config_x86_highmem): implement support for highmem
  64GB setting (closes #33585).
- Added bugfixes and Eagle IV support to ueagle-atm, as reported by
  Olivier Blin on kernel-discuss ML.
- Added missing patch entries on series file.
- Fixed b43-updates patch, avoid undesired changes for current 2.6.22.
- Added some fixes for iwlwifi and b43, from wireless-dev.
- Added patch for kvm that fixes solaris guests (upstream sf.net bug
  #1773613).
- Add two more ids for some zd1211rw wireless devices, commits from
  wireless-dev tree.
- Fixed bug in CE02_acpi-dsdt-initrd-v0.8.4-2.6.21.patch: don't load
  initrd twice, as this causes unpredicted behavior.
- Disabled ath5k module, doesn't work now for release, conflicts
  with madwifi.
- Unify MC59_genetlink-dynamic-multicast-groups.patch to avoid breaking
  quilt.
- Updated kvm to version 36.
- Updated wireless subsystem to latest wireless-dev.
- Minor changelog fixup.
- Drop bcm43xx-pci-neuter patch, bcm43xx allowed to be built by now as
  module selection will be ldetect's task.
- Removed disable-zd1211rw-mac80211 patch, just disable
  zd1211rw-mac80211 in config instead (zd1211rw more uptodate, no need
  to keep it enabled).
- Updated to version 2.6.22.5, drop already applied ahci_SB700_support
  patch.
- Fixup RTC selection in i386/x86_64/alpha configs:
  * Disabled CONFIG_RTC to allow rtc_cmos to be used. Enable generic
    rtc emulation (plus RTC_UIE emulation) in its place
  * Don't enable CONFIG_RTC_INTF_PROC because it conflicts with
    /proc/driver/rtc already provided by CONFIG_GEN_RTC
  * Enable RTC UIE emulation on dev interface for new rtc framework
- Added back legacy ralink drivers (the ones softmac based).
- Updated alsa to latest 2.6.23 code, dropped already applied
  patches
- Fixed error in CE01_acpi-ec-updates.patch, I already had fixed this
  but added the wrong version in svn.
- Regenerated configs.
- More wireless updates, fixes/changes for b43 module and ssb
  from wireless-dev.
- Don't allow bcm43xx and b43 coexist for same devices, limit the
  set of devices supported to only one module (patch from fedora).
- Disable zd1211rw-mac80211 module, use only zd1211rw (to avoid the
  same case like b43 x bcm43xx, and zd1211rw probably is more
  stable).
- Update ACPI battery and ec with changes that will come in 2.6.23,
  battery update fixes battery reading status deadlock on some
  notebooks when the machine is turned on without ac cable.
- More changelog info.
- Updated wireless support again, to latest wireless-dev tree. Also
  allow external ssb support now with b44.
- Fixed kernel building with latest wireless patches (updated again
  wireless-dev_drivers_updates patch with the right branch from
  git/wireless-dev). Also Added needed
  genetlink-dynamic-multicast-groups patch.
- Updated wireless subsystem to the current state of upstream Linus
  git and wireless-dev, also this obsoletes some previous added
  patches.
- Added patch for http://bugzilla.kernel.org/show_bug.cgi?id=7995
- Updated iwlwifi to the latest git snapshot
  (06deb1b0e1b9f44ac38c0b0c23a9bb715bb4224f)
- Disabled CONFIG_DEBUG_SHIRQ on arches where it was enabled, as
  this can cause problems with some modules, like r8169 (see
  https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=242572).
- update_configs: fix usage typo.
- While I was about to report the patch r8169_link_down_fix upstream,
  turns out that yesterday a similar fix was already made by Francois
  Romieu on netdev mailing list, and seems his approach is better,
  running the code only on the specific boards (mac_version ==
  RTL_GIGA_MAC_VER_12) that potentially needs special magic to turn phy
  on, so just use his patch that probably will go upstream.
- Provide pci_ids.h to user space, needed by ldetect, reported by
  Thierry Vignaud
- Fix issue of some r8169 boards not activating link, made a patch
  based on realtek open source driver as this change isn't upstream
  yet (DN01_r8169_link_down_fix.patch)
- Added upstream patch "Add a PCI ID for santa rosa's PATA
  controller" (DI11_Add-a-PCI-ID-for-santa-rosa-PATA-controller.patch)
- Fix for 'make prepare' not working anymore on kernel-source-stripped
  after addition of lguest patch.
- Added SR01_serial_reg-header.patch, to export serial_reg.h to user
  space, needed at least for xosview.
- Updated spec changelog entries.
- Added "cherry-picked" upstream hrtimers fixes from
  http://www.tglx.de/projects/hrtimers/2.6.22/broken-out/:
  HR01_i386-hpet-check-if-the-counter-works.patch
  HR02_timekeeping-fixup-shadow-variable-argument.patch
  HR03_clockevents-fix-resume-logic.patch
  HR04_clockevents-fix-device-replacement.patch
  HR05_i386-pit-stop-only-when-in-periodic-or-oneshot-mode.patch
- Added missing changelog entry.

  + Thomas Backlund <tmb@mandriva.org>
    - update kernel-laptop x86_64 description too
    - add support for ENE CB712/4 card readers (#30172)
    - disable mrproper target on -devel rpms to stop 3rdparty installers from
      wiping out needed files and thereby breaking builds (#34672, #34669)
      (based on an initial patch by Danny used in kernel-multimedia series)
    - update kernel-laptop descriptions and summary (#33518)
    - readd netfilter ipset, psd & ifwlog support
      (fixes kernel part of: #26376, #29800, #29982, #31402, #32399, #33069)
    - this is a -uc kernel
    - remove undefined variable
    - update to 2.6.22.10
    - drop AB01, DB01 (merged upstream)
    - rediff DB33
    - have only full kernel-source provide /usr/src/linux symlink
    - fix AppArmor return-code and rejected_mask (from John Johansen @ suse)
    - disable the AnyData cdma id from option module as it does not work (#31631)
    - update drbd to 8.0.6 (#33105)
    - update unionfs to 2.1.3
    - more detailed changelog regarding the #33559 bug
    - Really fix /usr/src/linux symlinking (#33559)
    - fix /usr/src/linux symlink removal check
    - readd /usr/src/linux symlink pointing at latest installed
      source/devel rpm (#33239)
    - readd linux prefix to kernel source/devel tree in /usr/src (#33239)
    - fix AppArmor syslog logging (AppArmor svn rev 961)
    - enable USB_SUSPEND only on laptop kernels, as it causes to much
      regressiona for normal users, but is a tradeoff for laptop users (#33089)
    - redo unionfs AppArmor vfs buildfix (initial patch for 2.1 by
      John Johansen <jjohansen@suse.de>
    - update AppArmor to 2.1.0 prerelease (SuSe 10_3 branch, commit 942)
    - fix typo
    - fix CFS patch to apply cleanly
    - correct versioning
    - update to kernel.org 2.6.22.6
    - add obsoletes/provides to the -latest virtual rpms to allow automatic
      updating to the new kernel-flavours (Big thanks to Anssi for the help):
      * kernel-desktop586-latest obsoletes/provides kernel-legacy-latest
      * kernel-desktop-latest obsoletes/provides kernel-latest
      * kernel-server-latest obsoletes/provides kernel-enterprise-latest
      * kernel-desktop-devel-latest obsoletes/provides kernel-source-stripped-latest
    - Revert: symlink old default /boot/(kernel,initrd.img) to the new flavours, needs to be fixed in bootloader-config instead
    - symlink old default /boot/(kernel,initrd.img) to the new flavours
    - add virtual kernel rpm for the installer to automatically
      install the default kernel-deskop rpm
    - drop xen, xbox and boot support from create_configs as the
      kernel spec does not support them either anymore
    - use defconfig-desktop as default configs/arch.config, and simplify
      create_configs script accordingly
    - fix kernel and kernel-devel post build,source symlinking
    - fix #29744, #29074 in a cleaner way by disabling the sourcing of
      arch/s390/crypto/Kconfig
    - drop MS07: add-above-background patch, merged in CFS
    - update lguest patch for new CFS scheduler
    - update acer_acpi to 0.7
    - update unionfs to 2.1.2
    - update CFS scheduler to v 20.5
    - drop sparc.config as we only build sparc64 kernels
    - drop ia64 support
    - drop alpha support
    - spec cleanups and typo fixes
    - make kernel-doc name unversioned
    - update kernel descriptions and summarys
    - merge kernel-renaming changes
    - fix typo and changelog date
    - add patch DS02: fix ati sb700 and add sb800 smbus support (#32568)
    - add patch AB03: update to kernel.org 2.6.22.3
    - add patch DN03: fix Realtek id due to upstream nVidia PHY renaming.
    - rediff patch SA03 to work with 2.6.22.2
    - drop patches CE07, DI11, HR01, SR01: merged upstream
    - add patch AB02: kernel.org 2.6.22.2
    - add patch CE07: fix acpi dock unload oops (#32337)
    - fix kernel-source-stripped symlinks generation when the -stripped rpm
      is installed before the kernel (#32236)
    - add patch AI02: Toshiba Equium A60 needs pci=assign-busses (#18989)
    - add patch AI01: picopower irq router support
    - disable DEBUG_SLAB, as it's bad for performance, especially
      under heavier loads

  + Luiz Fernando Capitulino <lcapitulino@mandriva.com>
    - Resetting version (preparing to release)
    - 2.6.22.9
    - Resetting date (preparing to release)
    - Revert DU21_remove_anydata_e100a_from_option.patch
      Just removing the ID doesn't fix the real problem and break working devices
      (see #31631 for more information).
    - 2.6.22.8
    - Resetting version (preparing to release)
    - Kill patches-review.txt file
      It's old, and not needed anymore.
    - Add missing patches to series file
    - Enable drbd compilation on kernel-server
      Believe it or not, drd wasn't been compiled due to a problem in
      the 3rdparty's generated Makefile.
      Fixed now, but only enables it on kernel-server flavor.
    - PCI: Fix boot-time hang on G31/G33 PC (#31632 thanks to Pacho Ramos)
    - Fix changelog entry
      drbd update and anydata changes will be release in -4mdv
      and not -3mdv.
    - Reset version and changelog to -3mdv
      We were working on -4mdv because there was a -3mdv release
      on the queue, but that release has been canceled.
      That means we're still in -3mdv.
    - kernel-server: defaults number of uarts to 32 (#24924)
    - Resetting version (preparing to release)
    - Resetting version (preparing to release)
    - hda-intel: fix codec detection (thanks to Danny Tholen)
    - Fix prefix on FS4 and FS5 (should be FS04 and FS05 respectively), also
      some minor changes in the series file
    - USB: Adding support for HTC Smartphones to ipaq (thanks to Pacho Ramos)
    - USB: add unusual_devs for Nikon devices D50, D80 and D100
      (thanks to Pacho Ramos)
    - pata_hpt37x: Fix 2.6.22 clock PLL regression (thanks to Pacho Ramos)
    - libata: implement BROKEN_HPA horkage and apply it to affected drives
      (#32076)
    - Version update
    - drop lguest: current version is buggy, and it would take sometime to
      get it in good shape (missing user-space support too)
    - Kill patches-broken directory
      Upgrade to 2.6.22 is now consolidated, we don't need this
      directory anymore.
    - ext3/4 orphan list debug support and corruption fix (#32527)
    - Add missing changelog entry
    - USB: add the ZTE ZXDSL 852 device ID for cxacru (#32707)
    - Reset version (preparing to release)
    - Reset version (preparing to release)
    - Really use CFQ as the default I/O scheduler (trem <trem@mandriva.org>)
    - HID: fix autocentering of PID devices (Anssi Hannula <anssi@mandriva.org>)
    - Use CFQ as the default I/O scheduler
    - Use standard name for -stable patches
    - Fix version.
      This' -4mdv, not -3mdv.
    - Revert DB01_implement_broken_hpa.patch
      Upstream developer Tejun Heo is not sure whether this fix can
      bring regressions, the best thing to do is to wait the right
      fix reach mainline kernel.
    - Resetting version (preparing to release)
    - Fix ICH6 IDE controller boot problem (#32076)
    - Minor changelog fixes
      Indentation and missing ticket number.
    - Update e1000 driver to version 7.6.5
    - Kill TODO file
      Not needed anymore.
    - Reset version (preparing to release)
    - OOPs, revert debug changes committed by mistake.
    - AHCI: IDs for ATI SB700 (#31884)
    - SMBus: Support for AMD/ATI SB700 chipset (#31450)
    - Add ticket number for kernel-stripped fix in changelog
    - x86_64: Enable saa7134 drivers (#16206)
    - Update spec and series file
    - Usb-audio: another Logitech camera/microphone ID match
      (patch from Daniel Drake <dsd@gentoo.org>)
    - hda-codec: Add quirk for Asus P5LD2
      (path from Claudio Matsuoka <cmatsuoka@gmail.com>)
    - Update changelog (preparing to release)
    - Merge 2.6.22 rebase work from:
      svn+ssh://svn.mandriva.com/svn/packages/branches/cooker/kernel-2.6-rebase-2.6.22
    - Revert commit r49248.
      This commit should have been done in trunk, but in branches instead.
    - Initial patch revamp
      Kill all known series by renaming all the patches.
    - Introduces quilt's series file
      This file will be mainly used to store my personal notes about
      the patches.
      it's a better approach, instead of mangling the patches.
    - Makes kernel-source-stripped usable again for dkms packages
      (patches from Olivier Blin <blino@mandriva.com>)
    - Reset changelog (preparing to release)
    - Alsa usbaudio quirk for Roland Juno-G
      (from Claudio Matsuoka <claudio@mandriva.com>)
    - Alsa HDA codec fixes
      5.1 output on LG LW20 and HP Spartan quirk
      (from Claudio Matsuoka <cmatsuoka@gmail.com>)
    - config file changes
    - Enable CONFIG_SECURITY and friends
    - Disable CONFIG_IRQBALANCE (looks like it drops battery life #31725)
    - create_configs: Disable XEN and KGDB
    - Big rediff
      This change rediff patches that apply with different offsets but
      do not generate fuzz warnings.
      There should be no functional changes.
      This is useful to in order to help me to know which patches needs
      review and which don't.
    - Introduces Ingo Molnar's CFS scheduler -v18
    - Move patches-review.txt into PATCHES/
      So that it gets included in the src.rpm pacakge.
    - First round of dropped patches, moved 26 into the 'patches-to-drop' queue
    - Move some patches to 'needed stuff' section
    - Fix kernel-stripped package.
      According to some reports our kernel-stripped package is completely
      br0ken.
      This change make it works again by (re)defining the files needed
      by the -stripped package.
      I'm don't like this change that much, but according to Thomas it
      fixes the problem and looks like our users really need the -stripped
      package.
      If it really fixes the problem and don't break anything else, I
      don't care.
      Patch from Thomas Backlund <tmb@mandriva.org>
    - Update patches-review.txt file
    - Introduces TODO file
    - Update patches-review.txt file
    - Introduces patches-review.txt file
      Not stable yet, do not trust in its contents.
    - Merge 'cooker/kernel-2.6.21-2mdv' branch
    - Disable XEN build and changelog
    - Build fix.
      We don't have alternatives for module-init-tools anymore.
    - Import fixes.
      The imported kernel package showed some inconsistency problems
      (mainly missing/botched/re-add patches).
      This change sync it up with revision 150712 from the corrupted repository.
      Hopefully it fixes everything.

  + Olivier Blin <blino@mandriva.org>
    - enable Conexant 2388x (bt878 successor) support on x86_64
    - unionfs: do not update mtime if there is no upper branch for the inode (fix bug with live systems)
    - conflict with older drakxtools-backend to ensure ldetect with preferred and fallback aliases support is available in post

  + Pixel <pixel@mandriva.com>
    - call installkernel without -L since we are the main kernel

  + Arnaud Patard <apatard@mandriva.com>
    - Update spec for 2.6.21
    - Update kernel configs for 2.6.21 and switch to pata drivers
    - Update create_configs script for 2.6.21 kernel
    - Update to 2.6.21 acpi fixed events debug patch
    - Remove broken ht disable patch
    - Remove old ifw patch. Updated version in work
    - Remove old, b0rken and no more upstream maintained 3rdparty drivers
    - Dasuko can no more be compiled like this. Drop it
    - linux/config.h removal build bix
    - dxr3 update
    - acerhk update
    - Drop ivtv. It now comes from the v4l-dvb patch and soon from the vanilla kernel
    - Unionfs update
    - Update at76 driver
    - Update ppc mdv patch
    - rfswitch update
    - Drop ipw3945 driver
    - wlan-ng update
    - squashfs update
    - drbd update
    - Add iwlwifi driver
    - Nozomi driver update
    - rt61 update
    - rt73 update
    - Update ndiswrapper
    - RT2570 update
    - RT2500 update
    - RT2400 update
    - lirc update
    - Update HB02 for 2.6.21
    - Remove obselete 64bit fixes
    - supermount even more broken on 2.6.21. Drop it
    - Update "nobadchar" patch for 2.6.21
    - Remove merged fs patches
    - Update ntfs rw module option to 2.6.21
    - Remove old jbd patch
    - Prevent to do some text/console operations when in graphic mode
    - Update pciids for 965GM
    - Remove merged video patches
    - Update mach64 video driver
    - Update DU07 and DU14 to 2.6.21
    - Remove obselete/merged usb patches
    - Update nf cap net admin check patch
    - Wireless update - Add mac80211 support
    - Remove old psd patch
    - Drop old patches
    - Update e1000 driver
    - Remove merged network patches
    - Updated to 2.6.21
    - Remove obseleted by 2.6.21 update IDE patches
    - Add modalias for scsi devices
    - Merge all sata_sis fixes into one
    - Rediffed against 2.6.21
    - Remove DBXX patches superseeded by 2.6.21 update
    - We're using squashfs now. Dropping gzloop patches
    - Rediffed for 2.6.21
    - Superseeded by 2.6.21
    - Remove merged pcmcia fixes
    - Patch superseeded by 2.6.21 update
    - Remove merged ALSA patches
    - RSBAC update to 1.3.4
    - New Xen snapshot
    - KVM update
    - Remove kernel debuggers as nobody's using them
    - Add patch for suspend debugging. Not aimed for the normal user
    - Remove obselete acpi suspend patches
    - acer acpi shipped in 2.6.21 obselete this one
    - More b.k.o #5534 bug fix.
    - Drop acpi=on patch. Broken and not used.
    - Merge the two acpi double video proc fixes in one
    - ACPI button bug vs suspend is merged
    - Remove merged/fixed in other way CVE patches
    - Update dsdt in initrd patch
    - Update bootsplash to 2.6.21
    - Remove merged misc CAXX fixes
    - Driver core dead lock is already present in 2.6.21
    - core2 nmi watchdog is merged in 2.6.21
    - ICH9 support is in 2.6.21 so removing theses patches
    - Removes smp alt patches merged in 2.6.21
    - Remove now merged in 2.6.21 suspend related patches
    - Add ICH9-m lpc pci ids
    - Shows irq stats per handler.
      See http://www.bughost.org/pipermail/power/2007-May/000394.html for its use.
    - NOHZ/timers fixes
    - Theses {i,}stallion checks are not needed anymore. Superseeded by major changes
      in 2.6.21 driver
    - Adds a patch for export paravirt_ops. This has been merged by AK and may be soon
      reverted according to some lkml threads.
    - Add patch to list all available partitions when in panic() due to no root
      partition found.
    - Add coretemp driver. Gives access to the Intel Core CPUs sensors.
    - Drop CA42.
      This was mostly a debug patch. Not really needed anymore
    - Update /dev/mem restriction patch to 2.6.21
    - Update BADram to BADram for 2.6.21
    - Add a snapshot of v4l-dvb
    - Update ALSA to a 1.0.14rc4 snapshot
    - Remove 2.6.17.y patches and add 2.6.21.y patches
    - Update kernel from 2.6.17 to 2.6.21.
    - Copy current 2.6.17 kernel to cooker branch.

